@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __itkImageToVectorContainerFilter_h
-#define __itkImageToVectorContainerFilter_h
+#ifndef itkImageToVectorContainerFilter_h
+#define itkImageToVectorContainerFilter_h
 
 #include "itkVectorContainerSource.h"
 #include "itkPlatformMultiThreader.h"
@@ -30,56 +30,62 @@ namespace itk
  * a vector container.
  */
 
-template< class TInputImage, class TOutputVectorContainer >
-class ImageToVectorContainerFilter :
-  public VectorContainerSource< TOutputVectorContainer >
+template <class TInputImage, class TOutputVectorContainer>
+class ITK_TEMPLATE_EXPORT ImageToVectorContainerFilter : public VectorContainerSource<TOutputVectorContainer>
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(ImageToVectorContainerFilter);
 
   /** Standard ITK-stuff. */
-  typedef ImageToVectorContainerFilter                    Self;
-  typedef VectorContainerSource< TOutputVectorContainer > Superclass;
-  typedef SmartPointer< Self >                            Pointer;
-  typedef SmartPointer< const Self >                      ConstPointer;
+  using Self = ImageToVectorContainerFilter;
+  using Superclass = VectorContainerSource<TOutputVectorContainer>;
+  using Pointer = SmartPointer<Self>;
+  using ConstPointer = SmartPointer<const Self>;
 
   /** Method for creation through the object factory. */
-  itkNewMacro( Self );
+  itkNewMacro(Self);
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( ImageToVectorContainerFilter, VectorContainerSource );
+  itkTypeMacro(ImageToVectorContainerFilter, VectorContainerSource);
 
   /** Typedefs inherited from the superclass. */
-  typedef typename Superclass::DataObjectPointer            DataObjectPointer;
-  typedef typename Superclass::OutputVectorContainerType    OutputVectorContainerType;
-  typedef typename Superclass::OutputVectorContainerPointer OutputVectorContainerPointer;
+  using typename Superclass::DataObjectPointer;
+  using typename Superclass::OutputVectorContainerType;
+  using typename Superclass::OutputVectorContainerPointer;
 
   /** Some Image related typedefs. */
-  typedef TInputImage                           InputImageType;
-  typedef typename InputImageType::Pointer      InputImagePointer;
-  typedef typename InputImageType::ConstPointer InputImageConstPointer;
-  typedef typename InputImageType::RegionType   InputImageRegionType;
-  typedef typename InputImageType::PixelType    InputImagePixelType;
+  using InputImageType = TInputImage;
+  using InputImagePointer = typename InputImageType::Pointer;
+  using InputImageConstPointer = typename InputImageType::ConstPointer;
+  using InputImageRegionType = typename InputImageType::RegionType;
+  using InputImagePixelType = typename InputImageType::PixelType;
 
   /** Create a valid output. */
-  DataObject::Pointer MakeOutput( unsigned int idx ) override;
+  DataObject::Pointer
+  MakeOutput(unsigned int idx) override;
 
   /** Set the input image of this process object.  */
-  void SetInput( unsigned int idx, const InputImageType * input );
+  void
+  SetInput(unsigned int idx, const InputImageType * input);
 
   /** Set the input image of this process object.  */
-  void SetInput( const InputImageType * input );
+  void
+  SetInput(const InputImageType * input);
 
   /** Get the input image of this process object.  */
-  const InputImageType * GetInput( void );
+  const InputImageType *
+  GetInput();
 
   /** Get the input image of this process object.  */
-  const InputImageType * GetInput( unsigned int idx );
+  const InputImageType *
+  GetInput(unsigned int idx);
 
   /** Get the output Mesh of this process object.  */
-  OutputVectorContainerType * GetOutput( void );
+  OutputVectorContainerType *
+  GetOutput();
 
   /** Prepare the output. */
-  //virtual void GenerateOutputInformation( void );
+  // virtual void GenerateOutputInformation();
 
   /** A version of GenerateData() specific for image processing
    * filters.  This implementation will split the processing across
@@ -96,7 +102,8 @@ public:
    * instead.
    *
    * \sa ThreadedGenerateData() */
-  void GenerateData( void ) override;
+  void
+  GenerateData() override;
 
   /** If an imaging filter can be implemented as a multithreaded
    * algorithm, the filter will provide an implementation of
@@ -120,9 +127,8 @@ public:
    * different thread).
    *
    * \sa GenerateData(), SplitRequestedRegion() */
-  virtual void ThreadedGenerateData(
-    const InputImageRegionType & inputRegionForThread,
-    ThreadIdType threadId );
+  virtual void
+  ThreadedGenerateData(const InputImageRegionType & inputRegionForThread, ThreadIdType threadId);
 
   /** If an imaging filter needs to perform processing after the buffer
    * has been allocated but before threads are spawned, the filter can
@@ -134,7 +140,9 @@ public:
    *      4) Call AfterThreadedGenerateData()
    * Note that this flow of control is only available if a filter provides
    * a ThreadedGenerateData() method and NOT a GenerateData() method. */
-  virtual void BeforeThreadedGenerateData( void ) {}
+  virtual void
+  BeforeThreadedGenerateData()
+  {}
 
   /** If an imaging filter needs to perform processing after all
    * processing threads have completed, the filter can can provide an
@@ -146,20 +154,25 @@ public:
    *      4) Call AfterThreadedGenerateData()
    * Note that this flow of control is only available if a filter provides
    * a ThreadedGenerateData() method and NOT a GenerateData() method. */
-  virtual void AfterThreadedGenerateData( void ) {}
+  virtual void
+  AfterThreadedGenerateData()
+  {}
 
   /** Split the output's RequestedRegion into "numberOfSplits" pieces, returning
    * region "i" as "splitRegion". This method is called "numberOfSplits" times. The
    * regions must not overlap. The method returns the number of pieces that
    * the routine is capable of splitting the output RequestedRegion,
    * i.e. return value is less than or equal to "numberOfSplits". */
-  virtual unsigned int SplitRequestedRegion( const ThreadIdType & threadId,
-    const ThreadIdType & numberOfSplits, InputImageRegionType & splitRegion );
+  virtual unsigned int
+  SplitRequestedRegion(const ThreadIdType &   threadId,
+                       const ThreadIdType &   numberOfSplits,
+                       InputImageRegionType & splitRegion);
 
   /** Static function used as a "callback" by the PlatformMultiThreader.  The threading
    * library will call this routine for each thread, which will delegate the
    * control to ThreadedGenerateData(). */
-  static ITK_THREAD_RETURN_FUNCTION_CALL_CONVENTION ThreaderCallback( void * arg );
+  static ITK_THREAD_RETURN_FUNCTION_CALL_CONVENTION
+  ThreaderCallback(void * arg);
 
   /** Internal structure used for passing image data into the threading library */
   struct ThreadStruct //?
@@ -168,28 +181,20 @@ public:
   };
 
 protected:
-
   /** The constructor. */
   ImageToVectorContainerFilter();
   /** The destructor. */
-  ~ImageToVectorContainerFilter() override {}
+  ~ImageToVectorContainerFilter() override = default;
 
   /** PrintSelf. */
-  void PrintSelf( std::ostream & os, Indent indent ) const override;
-
-private:
-
-  /** The private constructor. */
-  ImageToVectorContainerFilter( const Self & );  // purposely not implemented
-  /** The private copy constructor. */
-  void operator=( const Self & );                // purposely not implemented
-
+  void
+  PrintSelf(std::ostream & os, Indent indent) const override;
 };
 
 } // end namespace itk
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "itkImageToVectorContainerFilter.hxx"
+#  include "itkImageToVectorContainerFilter.hxx"
 #endif
 
-#endif // end #ifndef __itkImageToVectorContainerFilter_h
+#endif // end #ifndef itkImageToVectorContainerFilter_h
