@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __itkGPUInterpolatorCopier_h
-#define __itkGPUInterpolatorCopier_h
+#ifndef itkGPUInterpolatorCopier_h
+#define itkGPUInterpolatorCopier_h
 
 #include "itkInterpolateImageFunction.h"
 #include "itkGPUImage.h"
@@ -39,11 +39,11 @@ namespace itk
  *   itkStaticConstMacro( Support3D, bool, true );
  *  };
  *
- *  typedef itk::Image< short, 3 > ImageType;
- *  typedef typelist::MakeTypeList< short, float >::Type OCLImageTypes;
- *  typedef itk::InterpolateImageFunction< ImageType, float > InterpolatorType;
- *  typedef itk::GPUInterpolatorCopier< OCLImageTypes, OCLImageDims, InterpolatorType, float > CopierType;
- *  CopierType::Pointer copier = CopierType::New();
+ *  using ImageType = itk::Image< short, 3 >;
+ *  using OCLImageTypes = typelist::MakeTypeList< short, float >::Type;
+ *  using InterpolatorType = itk::InterpolateImageFunction< ImageType, float >;
+ *  using CopierType = itk::GPUInterpolatorCopier< OCLImageTypes, OCLImageDims, InterpolatorType, float >;
+ *  auto copier = CopierType::New();
  *  copier->SetInputInterpolator(CPUInterpolator);
  *  copier->Update();
  *  TransformType::Pointer GPUInterpolator = copier->GetModifiableOutput();
@@ -61,55 +61,52 @@ namespace itk
  *
  * \ingroup GPUCommon
  */
-template< typename TTypeList, typename NDimensions,
-typename TInterpolator, typename TOutputCoordRep >
-class GPUInterpolatorCopier : public Object
+template <typename TTypeList, typename NDimensions, typename TInterpolator, typename TOutputCoordRep>
+class ITK_TEMPLATE_EXPORT GPUInterpolatorCopier : public Object
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(GPUInterpolatorCopier);
 
   /** Standard class typedefs. */
-  typedef GPUInterpolatorCopier      Self;
-  typedef Object                     Superclass;
-  typedef SmartPointer< Self >       Pointer;
-  typedef SmartPointer< const Self > ConstPointer;
+  using Self = GPUInterpolatorCopier;
+  using Superclass = Object;
+  using Pointer = SmartPointer<Self>;
+  using ConstPointer = SmartPointer<const Self>;
 
   /** Method for creation through the object factory. */
-  itkNewMacro( Self );
+  itkNewMacro(Self);
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( GPUInterpolatorCopier, Object );
+  itkTypeMacro(GPUInterpolatorCopier, Object);
 
   /** Type CPU definitions for the interpolator. */
-  typedef TInterpolator                                CPUInterpolatorType;
-  typedef typename CPUInterpolatorType::ConstPointer   CPUInterpolatorConstPointer;
-  typedef typename CPUInterpolatorType::InputImageType CPUInputImageType;
-  typedef typename CPUInterpolatorType::CoordRepType   CPUCoordRepType;
-  typedef TOutputCoordRep                              GPUCoordRepType;
+  using CPUInterpolatorType = TInterpolator;
+  using CPUInterpolatorConstPointer = typename CPUInterpolatorType::ConstPointer;
+  using CPUInputImageType = typename CPUInterpolatorType::InputImageType;
+  using CPUCoordRepType = typename CPUInterpolatorType::CoordRepType;
+  using GPUCoordRepType = TOutputCoordRep;
 
   /** Typedef's for non explicit GPU interpolator definitions. */
-  typedef InterpolateImageFunction< CPUInputImageType, GPUCoordRepType >
-    GPUInterpolatorType;
-  typedef typename GPUInterpolatorType::Pointer      GPUInterpolatorPointer;
-  typedef typename GPUInterpolatorType::ConstPointer GPUInterpolatorConstPointer;
+  using GPUInterpolatorType = InterpolateImageFunction<CPUInputImageType, GPUCoordRepType>;
+  using GPUInterpolatorPointer = typename GPUInterpolatorType::Pointer;
+  using GPUInterpolatorConstPointer = typename GPUInterpolatorType::ConstPointer;
 
   /** Typedef's for explicit GPU interpolator definitions. */
-  typedef typename CPUInputImageType::PixelType CPUInputImagePixelType;
-  typedef itk::GPUImage< CPUInputImagePixelType, CPUInputImageType::ImageDimension >
-    GPUInputImageType;
-  typedef InterpolateImageFunction< GPUInputImageType, GPUCoordRepType >
-    GPUExplicitInterpolatorType;
-  typedef typename GPUExplicitInterpolatorType::Pointer      GPUExplicitInterpolatorPointer;
-  typedef typename GPUExplicitInterpolatorType::ConstPointer GPUExplicitInterpolatorConstPointer;
+  using CPUInputImagePixelType = typename CPUInputImageType::PixelType;
+  using GPUInputImageType = itk::GPUImage<CPUInputImagePixelType, CPUInputImageType::ImageDimension>;
+  using GPUExplicitInterpolatorType = InterpolateImageFunction<GPUInputImageType, GPUCoordRepType>;
+  using GPUExplicitInterpolatorPointer = typename GPUExplicitInterpolatorType::Pointer;
+  using GPUExplicitInterpolatorConstPointer = typename GPUExplicitInterpolatorType::ConstPointer;
 
   /** Get/Set the input interpolator. */
-  itkSetConstObjectMacro( InputInterpolator, CPUInterpolatorType );
+  itkSetConstObjectMacro(InputInterpolator, CPUInterpolatorType);
 
   /** Compute of the non explicit output interpolator. */
-  itkGetModifiableObjectMacro( Output, GPUInterpolatorType );
+  itkGetModifiableObjectMacro(Output, GPUInterpolatorType);
 
   /** Compute of the explicit output interpolator.
    * This output should be used when ExplicitMode has been set to true. */
-  itkGetModifiableObjectMacro( ExplicitOutput, GPUExplicitInterpolatorType );
+  itkGetModifiableObjectMacro(ExplicitOutput, GPUExplicitInterpolatorType);
 
   /** Get/Set the explicit mode. The default is true.
    * If the explicit mode has been set to false that means that early in the
@@ -117,30 +114,26 @@ public:
    * ObjectFactoryBase::RegisterFactory( GPUNearestNeighborInterpolateImageFunctionFactory::New() );
    * ObjectFactoryBase::RegisterFactory( GPULinearInterpolateImageFunctionFactory::New() );
    * ObjectFactoryBase::RegisterFactory( GPUBSplineInterpolateImageFunctionFactory::New() ); */
-  itkGetConstMacro( ExplicitMode, bool );
-  itkSetMacro( ExplicitMode, bool );
+  itkGetConstMacro(ExplicitMode, bool);
+  itkSetMacro(ExplicitMode, bool);
 
   /** Update method. */
-  void Update( void );
+  void
+  Update();
 
 #ifdef ITK_USE_CONCEPT_CHECKING
   // Begin concept checking
-  itkConceptMacro( OutputCoordRepIsFloatingPointCheck,
-    ( Concept::IsFloatingPoint< TOutputCoordRep > ) );
+  itkConceptMacro(OutputCoordRepIsFloatingPointCheck, (Concept::IsFloatingPoint<TOutputCoordRep>));
   // End concept checking
 #endif
 
 protected:
-
   GPUInterpolatorCopier();
-  ~GPUInterpolatorCopier() override {}
-  void PrintSelf( std::ostream & os, Indent indent ) const override;
+  ~GPUInterpolatorCopier() override = default;
+  void
+  PrintSelf(std::ostream & os, Indent indent) const override;
 
 private:
-
-  GPUInterpolatorCopier( const Self & ); // purposely not implemented
-  void operator=( const Self & );        // purposely not implemented
-
   CPUInterpolatorConstPointer    m_InputInterpolator;
   GPUInterpolatorPointer         m_Output;
   GPUExplicitInterpolatorPointer m_ExplicitOutput;
@@ -151,7 +144,7 @@ private:
 } // end namespace itk
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "itkGPUInterpolatorCopier.hxx"
+#  include "itkGPUInterpolatorCopier.hxx"
 #endif
 
-#endif /* __itkGPUInterpolatorCopier_h */
+#endif /* itkGPUInterpolatorCopier_h */
