@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __itkGPUMatrixOffsetTransformBase_h
-#define __itkGPUMatrixOffsetTransformBase_h
+#ifndef itkGPUMatrixOffsetTransformBase_h
+#define itkGPUMatrixOffsetTransformBase_h
 
 #include "itkGPUTransformBase.h"
 #include "itkMatrix.h"
@@ -24,7 +24,7 @@
 namespace itk
 {
 /** Create a helper GPU Kernel class for itkGPUMatrixOffsetTransformBase */
-itkGPUKernelClassMacro( GPUMatrixOffsetTransformBaseKernel );
+itkGPUKernelClassMacro(GPUMatrixOffsetTransformBaseKernel);
 
 /** \class GPUMatrixOffsetTransformBase
  * \brief Base version of the GPU MatrixOffsetTransform.
@@ -37,74 +37,73 @@ itkGPUKernelClassMacro( GPUMatrixOffsetTransformBaseKernel );
  *
  * \ingroup GPUCommon
  */
-template<
-typename TScalarType           = float, // Data type for scalars
-unsigned int NInputDimensions  = 3,     // Number of dimensions in the input space
-unsigned int NOutputDimensions = 3 >
+template <typename TScalarType = float,      // Data type for scalars
+          unsigned int NInputDimensions = 3, // Number of dimensions in the input space
+          unsigned int NOutputDimensions = 3>
 // Number of dimensions in the output space
 class ITK_EXPORT GPUMatrixOffsetTransformBase : public GPUTransformBase
 {
 public:
-
   /** Standard typedefs   */
-  typedef GPUMatrixOffsetTransformBase Self;
-  typedef GPUTransformBase             GPUSuperclass;
+  using Self = GPUMatrixOffsetTransformBase;
+  using GPUSuperclass = GPUTransformBase;
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( GPUMatrixOffsetTransformBase, GPUSuperclass );
+  itkTypeMacro(GPUMatrixOffsetTransformBase, GPUSuperclass);
 
   /**  */
-  bool IsMatrixOffsetTransform( void ) const override { return true; }
+  bool
+  IsMatrixOffsetTransform() const override
+  {
+    return true;
+  }
 
   /** Type of the scalar representing coordinate and vector elements. */
-  typedef TScalarType ScalarType;
+  using ScalarType = TScalarType;
 
   /** Dimension of the domain space. */
-  itkStaticConstMacro( InputSpaceDimension, unsigned int, NInputDimensions );
-  itkStaticConstMacro( OutputSpaceDimension, unsigned int, NOutputDimensions );
-  itkStaticConstMacro( ParametersDimension, unsigned int, NOutputDimensions * ( NInputDimensions + 1 ) );
+  itkStaticConstMacro(InputSpaceDimension, unsigned int, NInputDimensions);
+  itkStaticConstMacro(OutputSpaceDimension, unsigned int, NOutputDimensions);
+  itkStaticConstMacro(ParametersDimension, unsigned int, NOutputDimensions *(NInputDimensions + 1));
 
   /** Standard matrix type for this class */
-  typedef Matrix< TScalarType, itkGetStaticConstMacro( OutputSpaceDimension ),
-    itkGetStaticConstMacro( InputSpaceDimension ) >  CPUMatrixType;
-  typedef Matrix< TScalarType, itkGetStaticConstMacro( InputSpaceDimension ),
-    itkGetStaticConstMacro( OutputSpaceDimension ) > CPUInverseMatrixType;
-  typedef Vector< TScalarType,
-    itkGetStaticConstMacro( OutputSpaceDimension ) > CPUOutputVectorType;
+  using CPUMatrixType = Matrix<TScalarType, Self::OutputSpaceDimension, Self::InputSpaceDimension>;
+  using CPUInverseMatrixType = Matrix<TScalarType, Self::InputSpaceDimension, Self::OutputSpaceDimension>;
+  using CPUOutputVectorType = Vector<TScalarType, Self::OutputSpaceDimension>;
 
   /** Get CPU matrix of an MatrixOffsetTransformBase. */
-  virtual const CPUMatrixType & GetCPUMatrix( void ) const = 0;
-
-  /** Get CPU inverse matrix of an MatrixOffsetTransformBase. */
-  virtual const CPUInverseMatrixType & GetCPUInverseMatrix( void ) const = 0;
+  virtual const CPUMatrixType &
+  GetCPUMatrix() const = 0;
 
   /** Get CPU offset of an MatrixOffsetTransformBase. */
-  virtual const CPUOutputVectorType & GetCPUOffset( void ) const = 0;
+  virtual const CPUOutputVectorType &
+  GetCPUOffset() const = 0;
 
 protected:
-
   GPUMatrixOffsetTransformBase();
-  ~GPUMatrixOffsetTransformBase() override {}
+  ~GPUMatrixOffsetTransformBase() override = default;
 
   /** Returns OpenCL \a source code for the transform.
    * Returns true if source code was combined, false otherwise. */
-  bool GetSourceCode( std::string & source ) const override;
+  bool
+  GetSourceCode(std::string & source) const override;
 
   /** Returns data manager that stores all settings for the transform. */
-  GPUDataManager::Pointer GetParametersDataManager( void ) const override;
+  GPUDataManager::Pointer
+  GetParametersDataManager() const override;
 
 private:
+  GPUMatrixOffsetTransformBase(const Self & other) = delete;
+  const Self &
+  operator=(const Self &) = delete;
 
-  GPUMatrixOffsetTransformBase( const Self & other ); // purposely not implemented
-  const Self & operator=( const Self & );             // purposely not implemented
-
-  std::vector< std::string > m_Sources;
+  std::vector<std::string> m_Sources;
 };
 
 } // end namespace itk
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "itkGPUMatrixOffsetTransformBase.hxx"
+#  include "itkGPUMatrixOffsetTransformBase.hxx"
 #endif
 
 #endif /* itkGPUMatrixOffsetTransformBase_h */
