@@ -16,24 +16,24 @@
  *
  *=========================================================================*/
 /*=========================================================================
-*
-*  Copyright Insight Software Consortium
-*
-*  Licensed under the Apache License, Version 2.0 (the "License");
-*  you may not use this file except in compliance with the License.
-*  You may obtain a copy of the License at
-*
-*         http://www.apache.org/licenses/LICENSE-2.0.txt
-*
-*  Unless required by applicable law or agreed to in writing, software
-*  distributed under the License is distributed on an "AS IS" BASIS,
-*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-*  See the License for the specific language governing permissions and
-*  limitations under the License.
-*
-*=========================================================================*/
-#ifndef __itkGPUImageDataManager_h
-#define __itkGPUImageDataManager_h
+ *
+ *  Copyright Insight Software Consortium
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *         http://www.apache.org/licenses/LICENSE-2.0.txt
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ *
+ *=========================================================================*/
+#ifndef itkGPUImageDataManager_h
+#define itkGPUImageDataManager_h
 
 #include <itkObject.h>
 #include <itkTimeStamp.h>
@@ -59,54 +59,54 @@ namespace itk
  *
  * \ingroup ITKGPUCommon
  */
-template< typename TPixel, unsigned int NDimension >
-class GPUImage;
+template <typename TPixel, unsigned int NDimension>
+class ITK_TEMPLATE_EXPORT GPUImage;
 
-template< typename ImageType >
-class ITKOpenCL_EXPORT GPUImageDataManager : public GPUDataManager
+template <typename ImageType>
+class ITK_TEMPLATE_EXPORT ITKOpenCL_EXPORT GPUImageDataManager : public GPUDataManager
 {
   // allow GPUKernelManager to access GPU buffer pointer
   friend class OpenCLKernelManager;
-  friend class GPUImage< typename ImageType::PixelType, ImageType::ImageDimension >;
+  friend class GPUImage<typename ImageType::PixelType, ImageType::ImageDimension>;
 
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(GPUImageDataManager);
 
-  typedef GPUImageDataManager        Self;
-  typedef GPUDataManager             Superclass;
-  typedef SmartPointer< Self >       Pointer;
-  typedef SmartPointer< const Self > ConstPointer;
+  using Self = GPUImageDataManager;
+  using Superclass = GPUDataManager;
+  using Pointer = SmartPointer<Self>;
+  using ConstPointer = SmartPointer<const Self>;
 
-  itkNewMacro( Self );
-  itkTypeMacro( GPUImageDataManager, GPUDataManager );
+  itkNewMacro(Self);
+  itkTypeMacro(GPUImageDataManager, GPUDataManager);
 
-  void SetImagePointer( typename ImageType::Pointer img );
+  void
+  SetImagePointer(typename ImageType::Pointer img);
 
   /** actual GPU->CPU memory copy takes place here */
-  void UpdateCPUBuffer() override;
+  void
+  UpdateCPUBuffer() override;
 
   /** actual CPU->GPU memory copy takes place here */
-  void UpdateGPUBuffer() override;
+  void
+  UpdateGPUBuffer() override;
 
   /** Grafting GPU Image Data */
-  virtual void Graft( const GPUImageDataManager * data );
+  virtual void
+  Graft(const GPUImageDataManager * data);
 
 protected:
-
   GPUImageDataManager() { m_Image = nullptr; }
-  ~GPUImageDataManager() override {}
+  ~GPUImageDataManager() override = default;
 
 private:
-
-  GPUImageDataManager( const Self & );   // purposely not implemented
-  void operator=( const Self & );        // purposely not implemented
-
   typename ImageType::Pointer m_Image;
 };
 
 } // namespace itk
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "itkGPUImageDataManager.hxx"
+#  include "itkGPUImageDataManager.hxx"
 #endif
 
 #endif
