@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __itkOpenCLLogger_h
-#define __itkOpenCLLogger_h
+#ifndef itkOpenCLLogger_h
+#define itkOpenCLLogger_h
 
 #include "itkLoggerBase.h"
 #include "itkStdStreamLogOutput.h"
@@ -36,43 +36,52 @@ namespace itk
 class OpenCLLogger : public LoggerBase
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(OpenCLLogger);
 
-  typedef OpenCLLogger               Self;
-  typedef LoggerBase                 Superclass;
-  typedef SmartPointer< Self >       Pointer;
-  typedef SmartPointer< const Self > ConstPointer;
+  using Self = OpenCLLogger;
+  using Superclass = LoggerBase;
+  using Pointer = SmartPointer<Self>;
+  using ConstPointer = SmartPointer<const Self>;
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( OpenCLLogger, Object );
+  itkTypeMacro(OpenCLLogger, Object);
 
   /** This is a singleton pattern New. There will only be ONE
    * reference to a OpenCLLogger object per process. Clients that
    * call this must call Delete on the object so that the reference
    * counting will work. The single instance will be unreferenced when
    * the program exits. */
-  static Pointer New();
+  static Pointer
+  New();
 
   /** Return the singleton instance with no reference counting. */
-  static Pointer GetInstance();
+  static Pointer
+  GetInstance();
 
   /** Set log filename prefix. */
-  void SetLogFileNamePrefix( const std::string & prefix );
+  void
+  SetLogFileNamePrefix(const std::string & prefix);
 
   /** Get the log filename. */
-  std::string GetLogFileName() const { return this->m_FileName; }
+  std::string
+  GetLogFileName() const
+  {
+    return this->m_FileName;
+  }
 
   /** Set output directory for logger. */
-  itkSetStringMacro( OutputDirectory );
+  itkSetStringMacro(OutputDirectory);
 
   /** Returns true if the underlying OpenCL logger has been
    * created, false otherwise. */
-  bool IsCreated() const;
+  bool
+  IsCreated() const;
 
   /** Overloaded. */
-  void Write( PriorityLevelEnum level, std::string const & content ) override;
+  void
+  Write(PriorityLevelEnum level, std::string const & content) override;
 
 protected:
-
   /** Constructor */
   OpenCLLogger();
 
@@ -80,15 +89,12 @@ protected:
   ~OpenCLLogger() override;
 
   /** Initialize */
-  void Initialize();
+  void
+  Initialize();
 
 private:
-
   static Pointer m_Instance;
 
-  OpenCLLogger( const Self & );   //purposely not implemented
-  void operator=( const Self & ); //purposely not implemented
-
   std::string m_FileName;
   std::string m_OutputDirectory;
 
@@ -99,4 +105,4 @@ private:
 
 } // end namespace itk
 
-#endif // end #ifndef __itkOpenCLLogger_h
+#endif // end #ifndef itkOpenCLLogger_h
