@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __itkOpenCLProfilingTimeProbe_h
-#define __itkOpenCLProfilingTimeProbe_h
+#ifndef itkOpenCLProfilingTimeProbe_h
+#define itkOpenCLProfilingTimeProbe_h
 
 #include "itkOpenCLExport.h"
 #include "itkTimeProbe.h"
@@ -34,19 +34,17 @@ namespace itk
 class ITKOpenCL_EXPORT OpenCLProfilingTimeProbe
 {
 public:
-
   /** Constructor */
-  OpenCLProfilingTimeProbe( const std::string & message );
+  OpenCLProfilingTimeProbe(const std::string & message);
 
   /** Destructor */
   ~OpenCLProfilingTimeProbe();
 
 private:
-
   TimeProbe   m_Timer;
   std::string m_ProfilingMessage;
 };
 
 } // end namespace itk
 
-#endif //__itkOpenCLProfilingTimeProbe_h
+#endif // itkOpenCLProfilingTimeProbe_h
