@@ -20,7 +20,6 @@
 
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkAdvancedMatrixOffsetTransformBase.h,v $
-  Language:  C++
   Date:      $Date: 2008-06-29 12:58:58 $
   Version:   $Revision: 1.20 $
 
@@ -32,8 +31,8 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef __itkAdvancedMatrixOffsetTransformBase_h
-#define __itkAdvancedMatrixOffsetTransformBase_h
+#ifndef itkAdvancedMatrixOffsetTransformBase_h
+#define itkAdvancedMatrixOffsetTransformBase_h
 
 #include <iostream>
 
@@ -89,83 +88,71 @@ namespace itk
  *
  */
 
-template<
-class TScalarType              = double, // Data type for scalars
-unsigned int NInputDimensions  = 3,      // Number of dimensions in the input space
-unsigned int NOutputDimensions = 3 >
+template <class TScalarType = double,        // Data type for scalars
+          unsigned int NInputDimensions = 3, // Number of dimensions in the input space
+          unsigned int NOutputDimensions = 3>
 // Number of dimensions in the output space
-class AdvancedMatrixOffsetTransformBase :
-  public AdvancedTransform< TScalarType, NInputDimensions, NOutputDimensions >
+class ITK_TEMPLATE_EXPORT AdvancedMatrixOffsetTransformBase
+  : public AdvancedTransform<TScalarType, NInputDimensions, NOutputDimensions>
 {
 public:
-
   /** Standard typedefs   */
-  typedef AdvancedMatrixOffsetTransformBase Self;
-  typedef AdvancedTransform< TScalarType,
-    NInputDimensions, NOutputDimensions >       Superclass;
-  typedef SmartPointer< Self >       Pointer;
-  typedef SmartPointer< const Self > ConstPointer;
+  using Self = AdvancedMatrixOffsetTransformBase;
+  using Superclass = AdvancedTransform<TScalarType, NInputDimensions, NOutputDimensions>;
+  using Pointer = SmartPointer<Self>;
+  using ConstPointer = SmartPointer<const Self>;
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( AdvancedMatrixOffsetTransformBase, AdvancedTransform );
+  itkTypeMacro(AdvancedMatrixOffsetTransformBase, AdvancedTransform);
 
   /** New macro for creation of through a Smart Pointer. */
-  itkNewMacro( Self );
+  itkNewMacro(Self);
 
   /** Dimension of the domain space. */
-  itkStaticConstMacro( InputSpaceDimension, unsigned int, NInputDimensions );
-  itkStaticConstMacro( OutputSpaceDimension, unsigned int, NOutputDimensions );
-  itkStaticConstMacro( ParametersDimension, unsigned int,
-    NOutputDimensions * ( NInputDimensions + 1 ) );
+  itkStaticConstMacro(InputSpaceDimension, unsigned int, NInputDimensions);
+  itkStaticConstMacro(OutputSpaceDimension, unsigned int, NOutputDimensions);
+  itkStaticConstMacro(ParametersDimension, unsigned int, NOutputDimensions *(NInputDimensions + 1));
 
   /** Typedefs from the Superclass. */
-  typedef typename Superclass::ScalarType          ScalarType;
-  typedef typename Superclass::ParametersType      ParametersType;
-  typedef typename Superclass::FixedParametersType FixedParametersType;
+  using typename Superclass::ScalarType;
+  using typename Superclass::ParametersType;
+  using typename Superclass::FixedParametersType;
 
-  typedef typename Superclass::NumberOfParametersType NumberOfParametersType;
-  typedef typename Superclass::JacobianType           JacobianType;
-  typedef typename Superclass::InputVectorType        InputVectorType;
-  typedef typename Superclass::OutputVectorType       OutputVectorType;
-  typedef typename Superclass
-    ::InputCovariantVectorType InputCovariantVectorType;
-  typedef typename Superclass
-    ::OutputCovariantVectorType OutputCovariantVectorType;
-  typedef typename Superclass::InputVnlVectorType    InputVnlVectorType;
-  typedef typename Superclass::OutputVnlVectorType   OutputVnlVectorType;
-  typedef typename Superclass::InputPointType        InputPointType;
-  typedef typename Superclass::OutputPointType       OutputPointType;
-  typedef typename Superclass::TransformCategoryEnum TransformCategoryEnum;
+  using typename Superclass::NumberOfParametersType;
+  using typename Superclass::JacobianType;
+  using typename Superclass::InputVectorType;
+  using typename Superclass::OutputVectorType;
+  using typename Superclass::InputCovariantVectorType;
+  using typename Superclass::OutputCovariantVectorType;
+  using typename Superclass::InputVnlVectorType;
+  using typename Superclass::OutputVnlVectorType;
+  using typename Superclass::InputPointType;
+  using typename Superclass::OutputPointType;
+  using typename Superclass::TransformCategoryEnum;
 
-  typedef typename Superclass
-    ::NonZeroJacobianIndicesType NonZeroJacobianIndicesType;
-  typedef typename Superclass::SpatialJacobianType SpatialJacobianType;
-  typedef typename Superclass
-    ::JacobianOfSpatialJacobianType JacobianOfSpatialJacobianType;
-  typedef typename Superclass::SpatialHessianType SpatialHessianType;
-  typedef typename Superclass
-    ::JacobianOfSpatialHessianType JacobianOfSpatialHessianType;
-  typedef typename Superclass::InternalMatrixType InternalMatrixType;
+  using typename Superclass::NonZeroJacobianIndicesType;
+  using typename Superclass::SpatialJacobianType;
+  using typename Superclass::JacobianOfSpatialJacobianType;
+  using typename Superclass::SpatialHessianType;
+  using typename Superclass::JacobianOfSpatialHessianType;
+  using typename Superclass::InternalMatrixType;
 
   /** Standard matrix type for this class. */
-  typedef Matrix< TScalarType,
-    itkGetStaticConstMacro( OutputSpaceDimension ),
-    itkGetStaticConstMacro( InputSpaceDimension ) >  MatrixType;
+  using MatrixType = Matrix<TScalarType, Self::OutputSpaceDimension, Self::InputSpaceDimension>;
 
   /** Standard inverse matrix type for this class. */
-  typedef Matrix< TScalarType,
-    itkGetStaticConstMacro( InputSpaceDimension ),
-    itkGetStaticConstMacro( OutputSpaceDimension ) > InverseMatrixType;
+  using InverseMatrixType = Matrix<TScalarType, Self::InputSpaceDimension, Self::OutputSpaceDimension>;
 
   /** Typedefs. */
-  typedef InputPointType   CenterType;
-  typedef OutputVectorType OffsetType;
-  typedef OutputVectorType TranslationType;
+  using CenterType = InputPointType;
+  using OffsetType = OutputVectorType;
+  using TranslationType = OutputVectorType;
 
   /** Set the transformation to an Identity
    * This sets the matrix to identity and the Offset to null.
    */
-  virtual void SetIdentity( void );
+  virtual void
+  SetIdentity();
 
   /** Set matrix of an AdvancedMatrixOffsetTransformBase
    *
@@ -179,7 +166,8 @@ public:
    * To define an affine transform, you must set the matrix,
    * center, and translation OR the matrix and offset.
    */
-  virtual void SetMatrix( const MatrixType & matrix )
+  virtual void
+  SetMatrix(const MatrixType & matrix)
   {
     this->m_Matrix = matrix;
     this->ComputeOffset();
@@ -196,41 +184,13 @@ public:
    * To define an affine transform, you must set the matrix,
    * center, and translation OR the matrix and offset.
    */
-  const MatrixType & GetMatrix( void ) const
+  const MatrixType &
+  GetMatrix() const
   {
     return this->m_Matrix;
   }
 
 
-  /** Set offset (origin) of an MatrixOffset TransformBase.
-   *
-   * This method sets the offset of an AdvancedMatrixOffsetTransformBase to a
-   * value specified by the user.
-   * This updates Translation wrt current center.  See the warning regarding
-   * offset-versus-translation in the documentation for SetCenter.
-   * To define an affine transform, you must set the matrix,
-   * center, and translation OR the matrix and offset.
-   */
-  void SetOffset( const OutputVectorType & offset )
-  {
-    this->m_Offset = offset;
-    this->ComputeTranslation();
-    this->Modified();
-  }
-
-
-  /** Get offset of an AdvancedMatrixOffsetTransformBase
-   *
-   * This method returns the offset value of the AdvancedMatrixOffsetTransformBase.
-   * To define an affine transform, you must set the matrix,
-   * center, and translation OR the matrix and offset.
-   */
-  const OutputVectorType & GetOffset( void ) const
-  {
-    return this->m_Offset;
-  }
-
-
   /** Set center of rotation of an AdvancedMatrixOffsetTransformBase
    *
    * This method sets the center of rotation of an AdvancedMatrixOffsetTransformBase
@@ -254,7 +214,8 @@ public:
    * To define an affine transform, you must set the matrix,
    * center, and translation OR the matrix and offset.
    */
-  void SetCenter( const InputPointType & center )
+  void
+  SetCenter(const InputPointType & center)
   {
     this->m_Center = center;
     this->ComputeOffset();
@@ -269,7 +230,8 @@ public:
    * To define an affine transform, you must set the matrix,
    * center, and translation OR the matrix and offset.
    */
-  const InputPointType & GetCenter( void ) const
+  const InputPointType &
+  GetCenter() const
   {
     return this->m_Center;
   }
@@ -282,7 +244,8 @@ public:
    * To define an affine transform, you must set the matrix,
    * center, and translation OR the matrix and offset.
    */
-  void SetTranslation( const OutputVectorType & translation )
+  void
+  SetTranslation(const OutputVectorType & translation)
   {
     this->m_Translation = translation;
     this->ComputeOffset();
@@ -297,7 +260,8 @@ public:
    * To define an affine transform, you must set the matrix,
    * center, and translation OR the matrix and offset.
    */
-  const OutputVectorType & GetTranslation( void ) const
+  const OutputVectorType &
+  GetTranslation() const
   {
     return this->m_Translation;
   }
@@ -308,30 +272,20 @@ public:
    * matrix and the last NOutputDimension parameters the translation.
    * Offset is updated based on current center.
    */
-  void SetParameters( const ParametersType & parameters ) override;
+  void
+  SetParameters(const ParametersType & parameters) override;
 
   /** Get the Transformation Parameters. */
-  const ParametersType & GetParameters( void ) const override;
+  const ParametersType &
+  GetParameters() const override;
 
   /** Set the fixed parameters and update internal transformation. */
-  void SetFixedParameters( const FixedParametersType & ) override;
+  void
+  SetFixedParameters(const FixedParametersType &) override;
 
   /** Get the Fixed Parameters. */
-  const FixedParametersType & GetFixedParameters( void ) const override;
-
-  /** Compose with another AdvancedMatrixOffsetTransformBase
-   *
-   * This method composes self with another AdvancedMatrixOffsetTransformBase of the
-   * same dimension, modifying self to be the composition of self
-   * and other.  If the argument pre is true, then other is
-   * precomposed with self; that is, the resulting transformation
-   * consists of first applying other to the source, followed by
-   * self.  If pre is false or omitted, then other is post-composed
-   * with self; that is the resulting transformation consists of
-   * first applying self to the source, followed by other.
-   * This updates the Translation based on current center.
-   */
-  void Compose( const Self * other, bool pre = 0 );
+  const FixedParametersType &
+  GetFixedParameters() const override;
 
   /** Transform by an affine transformation
    *
@@ -341,45 +295,25 @@ public:
    * an affine point, whereas the TransformVector method transforms
    * its argument as a vector.
    */
-  OutputPointType     TransformPoint( const InputPointType & point ) const override;
+  OutputPointType
+  TransformPoint(const InputPointType & point) const override;
 
-  OutputVectorType    TransformVector( const InputVectorType & vector ) const override;
+  OutputVectorType
+  TransformVector(const InputVectorType & vector) const override;
 
-  OutputVnlVectorType TransformVector( const InputVnlVectorType & vector ) const override;
+  OutputVnlVectorType
+  TransformVector(const InputVnlVectorType & vector) const override;
 
-  OutputCovariantVectorType TransformCovariantVector(
-    const InputCovariantVectorType & vector ) const override;
-
-  /** Create inverse of an affine transformation
-    *
-    * This populates the parameters an affine transform such that
-    * the transform is the inverse of self. If self is not invertible,
-    * an exception is thrown.
-    * Note that by default the inverese transform is centered at
-    * the origin. If you need to compute the inverse centered at a point, p,
-    *
-    * \code
-    * transform2->SetCenter( p );
-    * transform1->GetInverse( transform2 );
-    * \endcode
-    *
-    * transform2 will now contain the inverse of transform1 and will
-    * with its center set to p. Flipping the two statements will produce an
-    * incorrect transform.
-    */
-  bool GetInverse( Self * inverse ) const;
-
-  /** \deprecated Use GetInverse instead.
-   *
-   * Method will eventually be made a protected member function. */
-  const InverseMatrixType & GetInverseMatrix( void ) const;
+  OutputCovariantVectorType
+  TransformCovariantVector(const InputCovariantVectorType & vector) const override;
 
   /** Indicates that this transform is linear. That is, given two
    * points P and Q, and scalar coefficients a and b, then
    *
    *           T( a*P + b*Q ) = a * T(P) + b * T(Q)
    */
-  bool IsLinear( void ) const override
+  bool
+  IsLinear() const override
   {
     return true;
   }
@@ -388,57 +322,53 @@ public:
   /** Indicates the category transform.
    *  e.g. an affine transform, or a local one, e.g. a deformation field.
    */
-  TransformCategoryEnum GetTransformCategory() const override
+  TransformCategoryEnum
+  GetTransformCategory() const override
   {
     return TransformCategoryEnum::Linear;
   }
 
 
   /** Compute the Jacobian of the transformation. */
-  void GetJacobian(
-    const InputPointType &,
-    JacobianType &,
-    NonZeroJacobianIndicesType & ) const override;
+  void
+  GetJacobian(const InputPointType &, JacobianType &, NonZeroJacobianIndicesType &) const override;
 
   /** Compute the spatial Jacobian of the transformation. */
-  void GetSpatialJacobian(
-    const InputPointType &,
-    SpatialJacobianType & ) const override;
+  void
+  GetSpatialJacobian(const InputPointType &, SpatialJacobianType &) const override;
 
   /** Compute the spatial Hessian of the transformation. */
-  void GetSpatialHessian(
-    const InputPointType &,
-    SpatialHessianType & ) const override;
+  void
+  GetSpatialHessian(const InputPointType &, SpatialHessianType &) const override;
 
   /** Compute the Jacobian of the spatial Jacobian of the transformation. */
-  void GetJacobianOfSpatialJacobian(
-    const InputPointType &,
-    JacobianOfSpatialJacobianType &,
-    NonZeroJacobianIndicesType & ) const override;
+  void
+  GetJacobianOfSpatialJacobian(const InputPointType &,
+                               JacobianOfSpatialJacobianType &,
+                               NonZeroJacobianIndicesType &) const override;
 
   /** Compute the Jacobian of the spatial Jacobian of the transformation. */
-  void GetJacobianOfSpatialJacobian(
-    const InputPointType &,
-    SpatialJacobianType &,
-    JacobianOfSpatialJacobianType &,
-    NonZeroJacobianIndicesType & ) const override;
+  void
+  GetJacobianOfSpatialJacobian(const InputPointType &,
+                               SpatialJacobianType &,
+                               JacobianOfSpatialJacobianType &,
+                               NonZeroJacobianIndicesType &) const override;
 
   /** Compute the Jacobian of the spatial Hessian of the transformation. */
-  void GetJacobianOfSpatialHessian(
-    const InputPointType &,
-    JacobianOfSpatialHessianType &,
-    NonZeroJacobianIndicesType & ) const override;
+  void
+  GetJacobianOfSpatialHessian(const InputPointType &,
+                              JacobianOfSpatialHessianType &,
+                              NonZeroJacobianIndicesType &) const override;
 
   /** Compute both the spatial Hessian and the Jacobian of the
    * spatial Hessian of the transformation. */
-  void GetJacobianOfSpatialHessian(
-    const InputPointType & ipp,
-    SpatialHessianType & sh,
-    JacobianOfSpatialHessianType & jsh,
-    NonZeroJacobianIndicesType & nonZeroJacobianIndices ) const override;
+  void
+  GetJacobianOfSpatialHessian(const InputPointType &         inputPoint,
+                              SpatialHessianType &           sh,
+                              JacobianOfSpatialHessianType & jsh,
+                              NonZeroJacobianIndicesType &   nonZeroJacobianIndices) const override;
 
 protected:
-
   /** Construct an AdvancedMatrixOffsetTransformBase object
    *
    * This method constructs a new AdvancedMatrixOffsetTransformBase object and
@@ -447,79 +377,52 @@ protected:
    * omitted, then the AdvancedMatrixOffsetTransformBase is initialized to an identity
    * transformation in the appropriate number of dimensions.
    */
-  AdvancedMatrixOffsetTransformBase( const MatrixType & matrix,
-    const OutputVectorType & offset );
-  AdvancedMatrixOffsetTransformBase( unsigned int paramDims );
-  AdvancedMatrixOffsetTransformBase();
-
-  /** Called by constructors: */
-  virtual void PrecomputeJacobians( unsigned int paramDims );
+  explicit AdvancedMatrixOffsetTransformBase(const unsigned int paramDims = ParametersDimension);
 
   /** Destroy an AdvancedMatrixOffsetTransformBase object. */
-  ~AdvancedMatrixOffsetTransformBase() override {}
+  ~AdvancedMatrixOffsetTransformBase() override = default;
 
   /** Print contents of an AdvancedMatrixOffsetTransformBase. */
-  void PrintSelf( std::ostream & s, Indent indent ) const override;
+  void
+  PrintSelf(std::ostream & s, Indent indent) const override;
 
-  const InverseMatrixType & GetVarInverseMatrix( void ) const
-  {
-    return this->m_InverseMatrix;
-  }
+  virtual void
+  ComputeMatrixParameters();
 
+  virtual void
+  ComputeMatrix();
 
-  void SetVarInverseMatrix( const InverseMatrixType & matrix ) const
-  {
-    this->m_InverseMatrix = matrix;
-    this->m_InverseMatrixMTime.Modified();
-  }
-
-
-  bool InverseMatrixIsOld( void ) const
-  {
-    if( this->m_MatrixMTime != this->m_InverseMatrixMTime )
-    {
-      return true;
-    }
-    else
-    {
-      return false;
-    }
-  }
-
-
-  virtual void ComputeMatrixParameters( void );
-
-  virtual void ComputeMatrix( void );
-
-  void SetVarMatrix( const MatrixType & matrix )
+  void
+  SetVarMatrix(const MatrixType & matrix)
   {
     this->m_Matrix = matrix;
     this->m_MatrixMTime.Modified();
   }
 
+  void
+  ComputeTranslation();
 
-  virtual void ComputeTranslation( void );
-
-  void SetVarTranslation( const OutputVectorType & translation )
+  void
+  SetVarTranslation(const OutputVectorType & translation)
   {
     this->m_Translation = translation;
   }
 
+  virtual void
+  ComputeOffset();
 
-  virtual void ComputeOffset( void );
-
-  void SetVarOffset( const OutputVectorType & offset )
+  /** Get offset of an AdvancedMatrixOffsetTransformBase
+   *
+   * This method returns the offset value of the AdvancedMatrixOffsetTransformBase.
+   * To define an affine transform, you must set the matrix,
+   * center, and translation OR the matrix and offset.
+   */
+  const OutputVectorType &
+  GetOffset() const
   {
-    this->m_Offset = offset;
+    return this->m_Offset;
   }
 
-
-  void SetVarCenter( const InputPointType & center )
-  {
-    this->m_Center = center;
-  }
-
-
   /** (spatial) Jacobians and Hessians can mostly be precomputed by this transform.
    * Store them in these member variables.
    * SpatialJacobian is simply m_Matrix */
@@ -529,33 +432,36 @@ protected:
   JacobianOfSpatialHessianType  m_JacobianOfSpatialHessian;
 
 private:
+  AdvancedMatrixOffsetTransformBase(const Self & other);
+  const Self &
+  operator=(const Self &);
+
+  /** Called by constructors: */
+  void
+  PrecomputeJacobians(unsigned int paramDims);
+
+  const InverseMatrixType &
+  GetInverseMatrix() const;
 
-  AdvancedMatrixOffsetTransformBase( const Self & other );
-  const Self & operator=( const Self & );
 
   /** Member variables. */
-  MatrixType                m_Matrix;           // Matrix of the transformation
-  OutputVectorType          m_Offset;           // Offset of the transformation
-  mutable InverseMatrixType m_InverseMatrix;    // Inverse of the matrix
-  mutable bool              m_Singular;         // Is m_Inverse singular?
+  MatrixType                m_Matrix{ MatrixType::GetIdentity() };               // Matrix of the transformation
+  OutputVectorType          m_Offset{};                                          // Offset of the transformation
+  mutable InverseMatrixType m_InverseMatrix{ InverseMatrixType::GetIdentity() }; // Inverse of the matrix
+  mutable bool              m_Singular{ false };                                 // Is m_Inverse singular?
 
-  InputPointType   m_Center;
-  OutputVectorType m_Translation;
+  InputPointType   m_Center{};
+  OutputVectorType m_Translation{};
 
   /** To avoid recomputation of the inverse if not needed. */
   TimeStamp         m_MatrixMTime;
   mutable TimeStamp m_InverseMatrixMTime;
-
-  /** Used by the GetJacobian() function which returns the
-   * Jacobian as an output variable. */
-  mutable NonZeroJacobianIndicesType m_NonZeroJacobianIndicesTemp;
-
 };
 
-}  // namespace itk
+} // namespace itk
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "itkAdvancedMatrixOffsetTransformBase.hxx"
+#  include "itkAdvancedMatrixOffsetTransformBase.hxx"
 #endif
 
-#endif /* __itkAdvancedMatrixOffsetTransformBase_h */
+#endif /* itkAdvancedMatrixOffsetTransformBase_h */
