@@ -19,7 +19,6 @@
 
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkTransform.h,v $
-  Language:  C++
   Date:      $Date: 2008-06-29 12:58:58 $
   Version:   $Revision: 1.64 $
 
@@ -31,8 +30,8 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef __itkAdvancedTransform_h
-#define __itkAdvancedTransform_h
+#ifndef itkAdvancedTransform_h
+#define itkAdvancedTransform_h
 
 #include "itkTransform.h"
 #include "itkMatrix.h"
@@ -79,91 +78,81 @@ namespace itk
  * \ingroup Transforms
  *
  */
-template< class TScalarType,
-unsigned int NInputDimensions  = 3,
-unsigned int NOutputDimensions = 3 >
-class AdvancedTransform :
-  public Transform< TScalarType, NInputDimensions, NOutputDimensions >
+template <class TScalarType, unsigned int NInputDimensions = 3, unsigned int NOutputDimensions = 3>
+class ITK_TEMPLATE_EXPORT AdvancedTransform : public Transform<TScalarType, NInputDimensions, NOutputDimensions>
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(AdvancedTransform);
 
   /** Standard class typedefs. */
-  typedef AdvancedTransform Self;
-  typedef Transform< TScalarType,
-    NInputDimensions,
-    NOutputDimensions >               Superclass;
-  typedef SmartPointer< Self >       Pointer;
-  typedef SmartPointer< const Self > ConstPointer;
+  using Self = AdvancedTransform;
+  using Superclass = Transform<TScalarType, NInputDimensions, NOutputDimensions>;
+  using Pointer = SmartPointer<Self>;
+  using ConstPointer = SmartPointer<const Self>;
 
   /** New method for creating an object using a factory. */
-  //itkNewMacro( Self );
+  // itkNewMacro( Self );
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( AdvancedTransform, Transform );
+  itkTypeMacro(AdvancedTransform, Transform);
 
   /** Dimension of the domain space. */
-  itkStaticConstMacro( InputSpaceDimension, unsigned int, NInputDimensions );
-  itkStaticConstMacro( OutputSpaceDimension, unsigned int, NOutputDimensions );
+  itkStaticConstMacro(InputSpaceDimension, unsigned int, NInputDimensions);
+  itkStaticConstMacro(OutputSpaceDimension, unsigned int, NOutputDimensions);
 
   /** Typedefs from the Superclass. */
-  typedef typename Superclass::ScalarType             ScalarType;
-  typedef typename Superclass::ParametersType         ParametersType;
-  typedef typename Superclass::FixedParametersType    FixedParametersType;
-  typedef typename Superclass::ParametersValueType    ParametersValueType;
-  typedef typename Superclass::NumberOfParametersType NumberOfParametersType;
-  typedef typename Superclass::DerivativeType         DerivativeType;
-  typedef typename Superclass::JacobianType           JacobianType;
-  typedef typename Superclass::InputVectorType        InputVectorType;
-  typedef typename Superclass::OutputVectorType       OutputVectorType;
-  typedef typename Superclass
-    ::InputCovariantVectorType InputCovariantVectorType;
-  typedef typename Superclass
-    ::OutputCovariantVectorType OutputCovariantVectorType;
-  typedef typename Superclass::InputVnlVectorType  InputVnlVectorType;
-  typedef typename Superclass::OutputVnlVectorType OutputVnlVectorType;
-  typedef typename Superclass::InputPointType      InputPointType;
-  typedef typename Superclass::OutputPointType     OutputPointType;
+  using typename Superclass::ScalarType;
+  using typename Superclass::ParametersType;
+  using typename Superclass::FixedParametersType;
+  using typename Superclass::ParametersValueType;
+  using typename Superclass::NumberOfParametersType;
+  using typename Superclass::DerivativeType;
+  using typename Superclass::JacobianType;
+  using typename Superclass::InputVectorType;
+  using typename Superclass::OutputVectorType;
+  using typename Superclass::InputCovariantVectorType;
+  using typename Superclass::OutputCovariantVectorType;
+  using typename Superclass::InputVnlVectorType;
+  using typename Superclass::OutputVnlVectorType;
+  using typename Superclass::InputPointType;
+  using typename Superclass::OutputPointType;
 
-  typedef typename Superclass::InverseTransformBaseType    InverseTransformBaseType;
-  typedef typename Superclass::InverseTransformBasePointer InverseTransformBasePointer;
+  using InverseTransformBaseType = typename Superclass::InverseTransformBaseType;
+  using typename Superclass::InverseTransformBasePointer;
 
   /** Transform typedefs for the from Superclass. */
-  typedef Transform< TScalarType,
-    NInputDimensions,
-    NOutputDimensions >                             TransformType;
-  typedef typename TransformType::Pointer      TransformTypePointer;
-  typedef typename TransformType::ConstPointer TransformTypeConstPointer;
+  using TransformType = Transform<TScalarType, NInputDimensions, NOutputDimensions>;
+  using TransformTypePointer = typename TransformType::Pointer;
+  using TransformTypeConstPointer = typename TransformType::ConstPointer;
 
   /** Types for the (Spatial)Jacobian/Hessian.
    * Using an itk::FixedArray instead of an std::vector gives a performance
    * gain for the SpatialHessianType.
    */
-  typedef std::vector< unsigned long > NonZeroJacobianIndicesType;
-  typedef Matrix< ScalarType,
-    OutputSpaceDimension, InputSpaceDimension >     SpatialJacobianType;
-  typedef std::vector< SpatialJacobianType > JacobianOfSpatialJacobianType;
+  using NonZeroJacobianIndicesType = std::vector<unsigned long>;
+  using SpatialJacobianType = Matrix<ScalarType, OutputSpaceDimension, InputSpaceDimension>;
+  using JacobianOfSpatialJacobianType = std::vector<SpatialJacobianType>;
   // \todo: think about the SpatialHessian type, should be a 3D native type
-  typedef FixedArray<
-    Matrix< ScalarType,
-    InputSpaceDimension, InputSpaceDimension >,
-    OutputSpaceDimension >                          SpatialHessianType;
-  typedef std::vector< SpatialHessianType >                JacobianOfSpatialHessianType;
-  typedef typename SpatialJacobianType::InternalMatrixType InternalMatrixType;
+  using SpatialHessianType =
+    FixedArray<Matrix<ScalarType, InputSpaceDimension, InputSpaceDimension>, OutputSpaceDimension>;
+  using JacobianOfSpatialHessianType = std::vector<SpatialHessianType>;
+  using InternalMatrixType = typename SpatialJacobianType::InternalMatrixType;
 
   /** Typedef for the moving image gradient type.
    * This type is defined by the B-spline interpolator as
    * typedef CovariantVector< RealType, ImageDimension >
    * As we cannot access this type we simply re-construct it to be identical.
    */
-  typedef OutputCovariantVectorType                   MovingImageGradientType;
-  typedef typename MovingImageGradientType::ValueType MovingImageGradientValueType;
+  using MovingImageGradientType = OutputCovariantVectorType;
+  using MovingImageGradientValueType = typename MovingImageGradientType::ValueType;
 
   /** Get the number of nonzero Jacobian indices. By default all. */
-  virtual NumberOfParametersType GetNumberOfNonZeroJacobianIndices( void ) const;
+  virtual NumberOfParametersType
+  GetNumberOfNonZeroJacobianIndices() const;
 
   /** Whether the advanced transform has nonzero matrices. */
-  itkGetConstMacro( HasNonZeroSpatialHessian, bool );
-  itkGetConstMacro( HasNonZeroJacobianOfSpatialHessian, bool );
+  itkGetConstMacro(HasNonZeroSpatialHessian, bool);
+  itkGetConstMacro(HasNonZeroJacobianOfSpatialHessian, bool);
 
   /** This returns a sparse version of the Jacobian of the transformation.
    *
@@ -191,19 +180,19 @@ public:
    * with \f$m\f$ the number of parameters, i.e. the size of \f$\mu\f$, and \f$d\f$
    * the dimension of the image.
    */
-  virtual void GetJacobian(
-    const InputPointType & ipp,
-    JacobianType & j,
-    NonZeroJacobianIndicesType & nonZeroJacobianIndices ) const = 0;
+  virtual void
+  GetJacobian(const InputPointType &       inputPoint,
+              JacobianType &               j,
+              NonZeroJacobianIndicesType & nonZeroJacobianIndices) const = 0;
 
   /** Compute the inner product of the Jacobian with the moving image gradient.
    * The Jacobian is (partially) constructed inside this function, but not returned.
    */
-  virtual void EvaluateJacobianWithImageGradientProduct(
-    const InputPointType & ipp,
-    const MovingImageGradientType & movingImageGradient,
-    DerivativeType & imageJacobian,
-    NonZeroJacobianIndicesType & nonZeroJacobianIndices ) const;
+  virtual void
+  EvaluateJacobianWithImageGradientProduct(const InputPointType &          inputPoint,
+                                           const MovingImageGradientType & movingImageGradient,
+                                           DerivativeType &                imageJacobian,
+                                           NonZeroJacobianIndicesType &    nonZeroJacobianIndices) const;
 
   /** Compute the spatial Jacobian of the transformation.
    *
@@ -231,15 +220,15 @@ public:
    * with \f$m\f$ the number of parameters, i.e. the size of \f$\mu\f$, and \f$d\f$
    * the dimension of the image.
    */
-  virtual void GetSpatialJacobian(
-    const InputPointType & ipp,
-    SpatialJacobianType & sj ) const = 0;
+  virtual void
+  GetSpatialJacobian(const InputPointType & inputPoint, SpatialJacobianType & sj) const = 0;
 
   /** Override some pure virtual ITK4 functions. */
-  void ComputeJacobianWithRespectToParameters(
-    const InputPointType & itkNotUsed( p ), JacobianType & itkNotUsed( j ) ) const override
+  void
+  ComputeJacobianWithRespectToParameters(const InputPointType & itkNotUsed(p),
+                                         JacobianType &         itkNotUsed(j)) const override
   {
-    itkExceptionMacro( << "This ITK4 function is currently not used in elastix." );
+    itkExceptionMacro(<< "This ITK4 function is currently not used in elastix.");
   }
 
 
@@ -259,9 +248,8 @@ public:
    * \f]
    * with i the i-th component of the transformation.
    */
-  virtual void GetSpatialHessian(
-    const InputPointType & ipp,
-    SpatialHessianType & sh ) const = 0;
+  virtual void
+  GetSpatialHessian(const InputPointType & inputPoint, SpatialHessianType & sh) const = 0;
 
   /** Compute the Jacobian of the spatial Jacobian of the transformation.
    *
@@ -269,19 +257,19 @@ public:
    * Jacobian to the transformation parameters \f$\mu\f$, evaluated at
    * a point \f$p\f$.
    */
-  virtual void GetJacobianOfSpatialJacobian(
-    const InputPointType & ipp,
-    JacobianOfSpatialJacobianType & jsj,
-    NonZeroJacobianIndicesType & nonZeroJacobianIndices ) const = 0;
+  virtual void
+  GetJacobianOfSpatialJacobian(const InputPointType &          inputPoint,
+                               JacobianOfSpatialJacobianType & jsj,
+                               NonZeroJacobianIndicesType &    nonZeroJacobianIndices) const = 0;
 
   /** Compute both the spatial Jacobian and the Jacobian of the
    * spatial Jacobian of the transformation.
    */
-  virtual void GetJacobianOfSpatialJacobian(
-    const InputPointType & ipp,
-    SpatialJacobianType & sj,
-    JacobianOfSpatialJacobianType & jsj,
-    NonZeroJacobianIndicesType & nonZeroJacobianIndices ) const = 0;
+  virtual void
+  GetJacobianOfSpatialJacobian(const InputPointType &          inputPoint,
+                               SpatialJacobianType &           sj,
+                               JacobianOfSpatialJacobianType & jsj,
+                               NonZeroJacobianIndicesType &    nonZeroJacobianIndices) const = 0;
 
   /** Compute the Jacobian of the spatial Hessian of the transformation.
    *
@@ -289,40 +277,36 @@ public:
    * Hessian to the transformation parameters \f$\mu\f$, evaluated at
    * a point \f$p\f$.
    */
-  virtual void GetJacobianOfSpatialHessian(
-    const InputPointType & ipp,
-    JacobianOfSpatialHessianType & jsh,
-    NonZeroJacobianIndicesType & nonZeroJacobianIndices ) const = 0;
+  virtual void
+  GetJacobianOfSpatialHessian(const InputPointType &         inputPoint,
+                              JacobianOfSpatialHessianType & jsh,
+                              NonZeroJacobianIndicesType &   nonZeroJacobianIndices) const = 0;
 
   /** Compute both the spatial Hessian and the Jacobian of the
    * spatial Hessian of the transformation.
    */
-  virtual void GetJacobianOfSpatialHessian(
-    const InputPointType & ipp,
-    SpatialHessianType & sh,
-    JacobianOfSpatialHessianType & jsh,
-    NonZeroJacobianIndicesType & nonZeroJacobianIndices ) const = 0;
+  virtual void
+  GetJacobianOfSpatialHessian(const InputPointType &         inputPoint,
+                              SpatialHessianType &           sh,
+                              JacobianOfSpatialHessianType & jsh,
+                              NonZeroJacobianIndicesType &   nonZeroJacobianIndices) const = 0;
 
 protected:
+  AdvancedTransform() = default;
 
-  AdvancedTransform();
-  AdvancedTransform( NumberOfParametersType numberOfParameters );
-  ~AdvancedTransform() override {}
+  // Inherit the other (non-default) constructor from itk::Transform.
+  using Superclass::Superclass;
 
-  bool m_HasNonZeroSpatialHessian;
-  bool m_HasNonZeroJacobianOfSpatialHessian;
-
-private:
-
-  AdvancedTransform( const Self & ); // purposely not implemented
-  void operator=( const Self & );    // purposely not implemented
+  ~AdvancedTransform() override = default;
 
+  bool m_HasNonZeroSpatialHessian{ true };
+  bool m_HasNonZeroJacobianOfSpatialHessian{ true };
 };
 
 } // end namespace itk
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "itkAdvancedTransform.hxx"
+#  include "itkAdvancedTransform.hxx"
 #endif
 
 #endif
