@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __itkBSplineInterpolationDerivativeWeightFunction_h
-#define __itkBSplineInterpolationDerivativeWeightFunction_h
+#ifndef itkBSplineInterpolationDerivativeWeightFunction_h
+#define itkBSplineInterpolationDerivativeWeightFunction_h
 
 #include "itkBSplineInterpolationWeightFunctionBase.h"
 
@@ -40,56 +40,51 @@ namespace itk
  * \ingroup Functions ImageInterpolators
  */
 
-template< class TCoordRep    = float,
-unsigned int VSpaceDimension = 2,
-unsigned int VSplineOrder    = 3 >
-class BSplineInterpolationDerivativeWeightFunction :
-  public BSplineInterpolationWeightFunctionBase<
-  TCoordRep, VSpaceDimension, VSplineOrder >
+template <class TCoordRep = float, unsigned int VSpaceDimension = 2, unsigned int VSplineOrder = 3>
+class ITK_TEMPLATE_EXPORT BSplineInterpolationDerivativeWeightFunction
+  : public BSplineInterpolationWeightFunctionBase<TCoordRep, VSpaceDimension, VSplineOrder>
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(BSplineInterpolationDerivativeWeightFunction);
 
   /** Standard class typedefs. */
-  typedef BSplineInterpolationDerivativeWeightFunction Self;
-  typedef BSplineInterpolationWeightFunctionBase<
-    TCoordRep, VSpaceDimension, VSplineOrder >      Superclass;
-  typedef SmartPointer< Self >       Pointer;
-  typedef SmartPointer< const Self > ConstPointer;
+  using Self = BSplineInterpolationDerivativeWeightFunction;
+  using Superclass = BSplineInterpolationWeightFunctionBase<TCoordRep, VSpaceDimension, VSplineOrder>;
+  using Pointer = SmartPointer<Self>;
+  using ConstPointer = SmartPointer<const Self>;
 
   /** New macro for creation of through the object factory. */
-  itkNewMacro( Self );
+  itkNewMacro(Self);
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( BSplineInterpolationDerivativeWeightFunction,
-    BSplineInterpolationWeightFunctionBase );
+  itkTypeMacro(BSplineInterpolationDerivativeWeightFunction, BSplineInterpolationWeightFunctionBase);
 
   /** Space dimension. */
-  itkStaticConstMacro( SpaceDimension, unsigned int, VSpaceDimension );
+  itkStaticConstMacro(SpaceDimension, unsigned int, VSpaceDimension);
 
   /** Spline order. */
-  itkStaticConstMacro( SplineOrder, unsigned int, VSplineOrder );
+  itkStaticConstMacro(SplineOrder, unsigned int, VSplineOrder);
 
   /** Typedefs from Superclass. */
-  typedef typename Superclass::WeightsType         WeightsType;
-  typedef typename Superclass::IndexType           IndexType;
-  typedef typename Superclass::SizeType            SizeType;
-  typedef typename Superclass::ContinuousIndexType ContinuousIndexType;
+  using typename Superclass::WeightsType;
+  using typename Superclass::IndexType;
+  using typename Superclass::SizeType;
+  using typename Superclass::ContinuousIndexType;
 
   /** Set the first order derivative direction. */
-  virtual void SetDerivativeDirection( unsigned int dir );
+  virtual void
+  SetDerivativeDirection(unsigned int dir);
 
 protected:
-
   BSplineInterpolationDerivativeWeightFunction();
-  ~BSplineInterpolationDerivativeWeightFunction() override {}
+  ~BSplineInterpolationDerivativeWeightFunction() override = default;
 
   /** Interpolation kernel types. */
-  typedef typename Superclass::KernelType           KernelType;
-  typedef typename Superclass::DerivativeKernelType DerivativeKernelType;
-  typedef typename Superclass
-    ::SecondOrderDerivativeKernelType SecondOrderDerivativeKernelType;
-  typedef typename Superclass::TableType       TableType;
-  typedef typename Superclass::OneDWeightsType OneDWeightsType;
+  using typename Superclass::KernelType;
+  using typename Superclass::DerivativeKernelType;
+  using typename Superclass::SecondOrderDerivativeKernelType;
+  using typename Superclass::TableType;
+  using typename Superclass::OneDWeightsType;
 
   /** Compute the 1D weights, which are:
    * \f[ \beta( x[i] - startIndex[i] ), \beta( x[i] - startIndex[i] - 1 ),
@@ -98,28 +93,24 @@ protected:
    * derivative direction, and just \f$\beta(x) = \beta^3(x)\f$ for the non-derivative
    * directions.
    */
-  void Compute1DWeights(
-    const ContinuousIndexType & index,
-    const IndexType & startIndex,
-    OneDWeightsType & weights1D ) const override;
+  void
+  Compute1DWeights(const ContinuousIndexType & index,
+                   const IndexType &           startIndex,
+                   OneDWeightsType &           weights1D) const override;
 
   /** Print the member variables. */
-  void PrintSelf( std::ostream & os, Indent indent ) const override;
+  void
+  PrintSelf(std::ostream & os, Indent indent) const override;
 
 private:
-
-  BSplineInterpolationDerivativeWeightFunction( const Self & ); // purposely not implemented
-  void operator=( const Self & );                               // purposely not implemented
-
   /** Member variables. */
   unsigned int m_DerivativeDirection;
-
 };
 
 } // end namespace itk
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "itkBSplineInterpolationDerivativeWeightFunction.hxx"
+#  include "itkBSplineInterpolationDerivativeWeightFunction.hxx"
 #endif
 
 #endif
