@@ -15,11 +15,11 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __itkBSplineInterpolationSecondOrderDerivativeWeightFunction_h
-#define __itkBSplineInterpolationSecondOrderDerivativeWeightFunction_h
+#ifndef itkBSplineInterpolationSecondOrderDerivativeWeightFunction_h
+#define itkBSplineInterpolationSecondOrderDerivativeWeightFunction_h
 
 #include "itkBSplineInterpolationWeightFunctionBase.h"
-#include "vnl/vnl_vector_fixed.h"
+#include <vnl/vnl_vector_fixed.h>
 
 namespace itk
 {
@@ -41,56 +41,51 @@ namespace itk
  * \ingroup Functions ImageInterpolators
  */
 
-template< class TCoordRep    = float,
-unsigned int VSpaceDimension = 2,
-unsigned int VSplineOrder    = 3 >
-class BSplineInterpolationSecondOrderDerivativeWeightFunction :
-  public BSplineInterpolationWeightFunctionBase<
-  TCoordRep, VSpaceDimension, VSplineOrder >
+template <class TCoordRep = float, unsigned int VSpaceDimension = 2, unsigned int VSplineOrder = 3>
+class ITK_TEMPLATE_EXPORT BSplineInterpolationSecondOrderDerivativeWeightFunction
+  : public BSplineInterpolationWeightFunctionBase<TCoordRep, VSpaceDimension, VSplineOrder>
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(BSplineInterpolationSecondOrderDerivativeWeightFunction);
 
   /** Standard class typedefs. */
-  typedef BSplineInterpolationSecondOrderDerivativeWeightFunction Self;
-  typedef BSplineInterpolationWeightFunctionBase<
-    TCoordRep, VSpaceDimension, VSplineOrder >      Superclass;
-  typedef SmartPointer< Self >       Pointer;
-  typedef SmartPointer< const Self > ConstPointer;
+  using Self = BSplineInterpolationSecondOrderDerivativeWeightFunction;
+  using Superclass = BSplineInterpolationWeightFunctionBase<TCoordRep, VSpaceDimension, VSplineOrder>;
+  using Pointer = SmartPointer<Self>;
+  using ConstPointer = SmartPointer<const Self>;
 
   /** New macro for creation of through the object factory. */
-  itkNewMacro( Self );
+  itkNewMacro(Self);
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( BSplineInterpolationSecondOrderDerivativeWeightFunction,
-    BSplineInterpolationWeightFunctionBase );
+  itkTypeMacro(BSplineInterpolationSecondOrderDerivativeWeightFunction, BSplineInterpolationWeightFunctionBase);
 
   /** Space dimension. */
-  itkStaticConstMacro( SpaceDimension, unsigned int, VSpaceDimension );
+  itkStaticConstMacro(SpaceDimension, unsigned int, VSpaceDimension);
 
   /** Spline order. */
-  itkStaticConstMacro( SplineOrder, unsigned int, VSplineOrder );
+  itkStaticConstMacro(SplineOrder, unsigned int, VSplineOrder);
 
   /** Typedefs from Superclass. */
-  typedef typename Superclass::WeightsType         WeightsType;
-  typedef typename Superclass::IndexType           IndexType;
-  typedef typename Superclass::SizeType            SizeType;
-  typedef typename Superclass::ContinuousIndexType ContinuousIndexType;
+  using typename Superclass::WeightsType;
+  using typename Superclass::IndexType;
+  using typename Superclass::SizeType;
+  using typename Superclass::ContinuousIndexType;
 
   /** Set the second order derivative directions. */
-  virtual void SetDerivativeDirections( unsigned int dir0, unsigned int dir1 );
+  virtual void
+  SetDerivativeDirections(unsigned int dir0, unsigned int dir1);
 
 protected:
-
   BSplineInterpolationSecondOrderDerivativeWeightFunction();
-  ~BSplineInterpolationSecondOrderDerivativeWeightFunction() override {}
+  ~BSplineInterpolationSecondOrderDerivativeWeightFunction() override = default;
 
   /** Interpolation kernel types. */
-  typedef typename Superclass::KernelType           KernelType;
-  typedef typename Superclass::DerivativeKernelType DerivativeKernelType;
-  typedef typename Superclass
-    ::SecondOrderDerivativeKernelType SecondOrderDerivativeKernelType;
-  typedef typename Superclass::TableType       TableType;
-  typedef typename Superclass::OneDWeightsType OneDWeightsType;
+  using typename Superclass::KernelType;
+  using typename Superclass::DerivativeKernelType;
+  using typename Superclass::SecondOrderDerivativeKernelType;
+  using typename Superclass::TableType;
+  using typename Superclass::OneDWeightsType;
 
   /** Compute the 1D weights, which are:
    * \f[ \beta( x[i] - startIndex[i] ), \beta( x[i] - startIndex[i] - 1 ),
@@ -101,28 +96,24 @@ protected:
    * in case of equal derivative directions,
    * with \f$\beta(x) = \beta^3(x)\f$ for the non-derivative directions.
    */
-  void Compute1DWeights(
-    const ContinuousIndexType & index,
-    const IndexType & startIndex,
-    OneDWeightsType & weights1D ) const override;
+  void
+  Compute1DWeights(const ContinuousIndexType & index,
+                   const IndexType &           startIndex,
+                   OneDWeightsType &           weights1D) const override;
 
   /** Print the member variables. */
-  void PrintSelf( std::ostream & os, Indent indent ) const override;
+  void
+  PrintSelf(std::ostream & os, Indent indent) const override;
 
 private:
-
-  BSplineInterpolationSecondOrderDerivativeWeightFunction( const Self & ); // purposely not implemented
-  void operator=( const Self & );                                          // purposely not implemented
-
-  vnl_vector_fixed< double, 2 > m_DerivativeDirections;
-  bool                          m_EqualDerivativeDirections;
-
+  vnl_vector_fixed<double, 2> m_DerivativeDirections;
+  bool                        m_EqualDerivativeDirections;
 };
 
 } // end namespace itk
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "itkBSplineInterpolationSecondOrderDerivativeWeightFunction.hxx"
+#  include "itkBSplineInterpolationSecondOrderDerivativeWeightFunction.hxx"
 #endif
 
 #endif
