@@ -19,7 +19,6 @@
 
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkTransformToDeterminantOfSpatialJacobianSource.h,v $
-  Language:  C++
   Date:      $Date: 2008-08-01 13:42:00 $
   Version:   $Revision: 1.3 $
 
@@ -31,10 +30,11 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef __itkTransformToDeterminantOfSpatialJacobianSource_h
-#define __itkTransformToDeterminantOfSpatialJacobianSource_h
+#ifndef itkTransformToDeterminantOfSpatialJacobianSource_h
+#define itkTransformToDeterminantOfSpatialJacobianSource_h
 
 #include "itkAdvancedTransform.h"
+#include "itkAdvancedIdentityTransform.h"
 #include "itkImageSource.h"
 
 namespace itk
@@ -70,54 +70,50 @@ namespace itk
  *
  * \ingroup GeometricTransforms
  */
-template< class TOutputImage,
-class TTransformPrecisionType = double >
-class TransformToDeterminantOfSpatialJacobianSource :
-  public ImageSource< TOutputImage >
+template <class TOutputImage, class TTransformPrecisionType = double>
+class ITK_TEMPLATE_EXPORT TransformToDeterminantOfSpatialJacobianSource : public ImageSource<TOutputImage>
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(TransformToDeterminantOfSpatialJacobianSource);
 
   /** Standard class typedefs. */
-  typedef TransformToDeterminantOfSpatialJacobianSource Self;
-  typedef ImageSource< TOutputImage >                   Superclass;
-  typedef SmartPointer< Self >                          Pointer;
-  typedef SmartPointer< const Self >                    ConstPointer;
+  using Self = TransformToDeterminantOfSpatialJacobianSource;
+  using Superclass = ImageSource<TOutputImage>;
+  using Pointer = SmartPointer<Self>;
+  using ConstPointer = SmartPointer<const Self>;
 
-  typedef TOutputImage                           OutputImageType;
-  typedef typename OutputImageType::Pointer      OutputImagePointer;
-  typedef typename OutputImageType::ConstPointer OutputImageConstPointer;
-  typedef typename OutputImageType::RegionType   OutputImageRegionType;
+  using OutputImageType = TOutputImage;
+  using OutputImagePointer = typename OutputImageType::Pointer;
+  using OutputImageConstPointer = typename OutputImageType::ConstPointer;
+  using OutputImageRegionType = typename OutputImageType::RegionType;
 
   /** Method for creation through the object factory. */
-  itkNewMacro( Self );
+  itkNewMacro(Self);
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( TransformToDeterminantOfSpatialJacobianSource, ImageSource );
+  itkTypeMacro(TransformToDeterminantOfSpatialJacobianSource, ImageSource);
 
   /** Number of dimensions. */
-  itkStaticConstMacro( ImageDimension, unsigned int,
-    TOutputImage::ImageDimension );
+  itkStaticConstMacro(ImageDimension, unsigned int, TOutputImage::ImageDimension);
 
   /** Typedefs for transform. */
-  typedef AdvancedTransform< TTransformPrecisionType,
-    itkGetStaticConstMacro( ImageDimension ),
-    itkGetStaticConstMacro( ImageDimension ) >     TransformType;
-  typedef typename TransformType::ConstPointer        TransformPointerType;
-  typedef typename TransformType::SpatialJacobianType SpatialJacobianType;
+  using TransformType = AdvancedTransform<TTransformPrecisionType, Self::ImageDimension, Self::ImageDimension>;
+  using TransformPointerType = typename TransformType::ConstPointer;
+  using SpatialJacobianType = typename TransformType::SpatialJacobianType;
 
   /** Typedefs for output image. */
-  typedef typename OutputImageType::PixelType PixelType;
-  //typedef typename PixelType::ValueType           PixelValueType;
-  typedef typename OutputImageType::RegionType    RegionType;
-  typedef typename RegionType::SizeType           SizeType;
-  typedef typename OutputImageType::IndexType     IndexType;
-  typedef typename OutputImageType::PointType     PointType;
-  typedef typename OutputImageType::SpacingType   SpacingType;
-  typedef typename OutputImageType::PointType     OriginType;
-  typedef typename OutputImageType::DirectionType DirectionType;
+  using PixelType = typename OutputImageType::PixelType;
+  // typedef typename PixelType::ValueType           PixelValueType;
+  using RegionType = typename OutputImageType::RegionType;
+  using SizeType = typename RegionType::SizeType;
+  using IndexType = typename OutputImageType::IndexType;
+  using PointType = typename OutputImageType::PointType;
+  using SpacingType = typename OutputImageType::SpacingType;
+  using OriginType = typename OutputImageType::PointType;
+  using DirectionType = typename OutputImageType::DirectionType;
 
   /** Typedefs for base image. */
-  typedef ImageBase< itkGetStaticConstMacro( ImageDimension ) > ImageBaseType;
+  using ImageBaseType = ImageBase<Self::ImageDimension>;
 
   /** Set the coordinate transformation.
    * Set the coordinate transform to use for resampling.  Note that this must
@@ -126,104 +122,110 @@ public:
    * the filter uses an Identity transform. You must provide a different
    * transform here, before attempting to run the filter, if you do not want to
    * use the default Identity transform. */
-  itkSetConstObjectMacro( Transform, TransformType );
+  itkSetConstObjectMacro(Transform, TransformType);
 
   /** Get a pointer to the coordinate transform. */
-  itkGetConstObjectMacro( Transform, TransformType );
+  itkGetConstObjectMacro(Transform, TransformType);
 
   /** Set the size of the output image. */
-  virtual void SetOutputSize( const SizeType & size );
+  virtual void
+  SetOutputSize(const SizeType & size);
 
   /** Get the size of the output image. */
-  virtual const SizeType & GetOutputSize();
+  virtual const SizeType &
+  GetOutputSize();
 
   /** Set the start index of the output largest possible region.
-  * The default is an index of all zeros. */
-  virtual void SetOutputIndex( const IndexType & index );
+   * The default is an index of all zeros. */
+  virtual void
+  SetOutputIndex(const IndexType & index);
 
   /** Get the start index of the output largest possible region. */
-  virtual const IndexType & GetOutputIndex();
+  virtual const IndexType &
+  GetOutputIndex();
 
   /** Set the region of the output image. */
-  itkSetMacro( OutputRegion, OutputImageRegionType );
+  itkSetMacro(OutputRegion, OutputImageRegionType);
 
   /** Get the region of the output image. */
-  itkGetConstReferenceMacro( OutputRegion, OutputImageRegionType );
+  itkGetConstReferenceMacro(OutputRegion, OutputImageRegionType);
 
   /** Set the output image spacing. */
-  itkSetMacro( OutputSpacing, SpacingType );
-  virtual void SetOutputSpacing( const double * values );
+  itkSetMacro(OutputSpacing, SpacingType);
+  virtual void
+  SetOutputSpacing(const double * values);
 
   /** Get the output image spacing. */
-  itkGetConstReferenceMacro( OutputSpacing, SpacingType );
+  itkGetConstReferenceMacro(OutputSpacing, SpacingType);
 
   /** Set the output image origin. */
-  itkSetMacro( OutputOrigin, OriginType );
-  virtual void SetOutputOrigin( const double * values );
+  itkSetMacro(OutputOrigin, OriginType);
+  virtual void
+  SetOutputOrigin(const double * values);
 
   /** Get the output image origin. */
-  itkGetConstReferenceMacro( OutputOrigin, OriginType );
+  itkGetConstReferenceMacro(OutputOrigin, OriginType);
 
   /** Set the output direction cosine matrix. */
-  itkSetMacro( OutputDirection, DirectionType );
-  itkGetConstReferenceMacro( OutputDirection, DirectionType );
+  itkSetMacro(OutputDirection, DirectionType);
+  itkGetConstReferenceMacro(OutputDirection, DirectionType);
 
   /** Helper method to set the output parameters based on this image */
-  void SetOutputParametersFromImage( const ImageBaseType * image );
+  void
+  SetOutputParametersFromImage(const ImageBaseType * image);
 
   /** TransformToDeterminantOfSpatialJacobianSource produces a floating value image. */
-  void GenerateOutputInformation( void ) override;
+  void
+  GenerateOutputInformation() override;
 
   /** Checking if transform is set. In case of linear transformations,
    * the LinearGenerateData is called. */
-  void BeforeThreadedGenerateData( void ) override;
+  void
+  BeforeThreadedGenerateData() override;
 
   /** Compute the Modified Time based on changes to the components. */
-  ModifiedTimeType GetMTime( void ) const override;
+  ModifiedTimeType
+  GetMTime() const override;
 
 protected:
-
   TransformToDeterminantOfSpatialJacobianSource();
-  ~TransformToDeterminantOfSpatialJacobianSource() override {}
+  ~TransformToDeterminantOfSpatialJacobianSource() override = default;
 
-  void PrintSelf( std::ostream & os, Indent indent ) const override;
+  void
+  PrintSelf(std::ostream & os, Indent indent) const override;
 
   /** TransformToDeterminantOfSpatialJacobianSource can be implemented as a multithreaded
    * filter.
    */
-  void ThreadedGenerateData(
-    const OutputImageRegionType & outputRegionForThread,
-    ThreadIdType threadId ) override;
+  void
+  ThreadedGenerateData(const OutputImageRegionType & outputRegionForThread, ThreadIdType threadId) override;
 
   /** Default implementation for resampling that works for any
    * transformation type.
    */
-  void NonlinearThreadedGenerateData(
-    const OutputImageRegionType & outputRegionForThread,
-    ThreadIdType threadId );
+  void
+  NonlinearThreadedGenerateData(const OutputImageRegionType & outputRegionForThread, ThreadIdType threadId);
 
   /** Faster implementation for resampling that works for with linear
    *  transformation types. Unthreaded. */
-  void LinearGenerateData( void );
+  void
+  LinearGenerateData();
 
 private:
-
-  TransformToDeterminantOfSpatialJacobianSource( const Self & ); // purposely not implemented
-  void operator=( const Self & );                                // purposely not implemented
-
   /** Member variables. */
-  RegionType           m_OutputRegion;         // region of the output image
-  TransformPointerType m_Transform;            // Coordinate transform to use
-  SpacingType          m_OutputSpacing;        // output image spacing
-  OriginType           m_OutputOrigin;         // output image origin
-  DirectionType        m_OutputDirection;      // output image direction cosines
-
+  RegionType           m_OutputRegion{}; // region of the output image
+  TransformPointerType m_Transform{
+    AdvancedIdentityTransform<TTransformPrecisionType, ImageDimension>::New()
+  };                                                               // Coordinate transform to use
+  SpacingType   m_OutputSpacing{ 1.0 };                            // output image spacing
+  OriginType    m_OutputOrigin{};                                  // output image origin
+  DirectionType m_OutputDirection{ DirectionType::GetIdentity() }; // output image direction cosines
 };
 
 } // end namespace itk
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "itkTransformToDeterminantOfSpatialJacobianSource.hxx"
+#  include "itkTransformToDeterminantOfSpatialJacobianSource.hxx"
 #endif
 
-#endif // end #ifndef __itkTransformToDeterminantOfSpatialJacobianSource_h
+#endif // end #ifndef itkTransformToDeterminantOfSpatialJacobianSource_h
