@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __itkAdvancedLinearInterpolateImageFunction_h
-#define __itkAdvancedLinearInterpolateImageFunction_h
+#ifndef itkAdvancedLinearInterpolateImageFunction_h
+#define itkAdvancedLinearInterpolateImageFunction_h
 
 #include "itkLinearInterpolateImageFunction.h"
 
@@ -59,124 +59,117 @@ namespace itk
  * \wikiexample{ImageProcessing/LinearInterpolateImageFunction,Linearly interpolate a position in an image}
  * \endwiki
  */
-template< class TInputImage, class TCoordRep = double >
-class AdvancedLinearInterpolateImageFunction :
-  public LinearInterpolateImageFunction< TInputImage, TCoordRep >
+template <class TInputImage, class TCoordRep = double>
+class ITK_TEMPLATE_EXPORT AdvancedLinearInterpolateImageFunction
+  : public LinearInterpolateImageFunction<TInputImage, TCoordRep>
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(AdvancedLinearInterpolateImageFunction);
 
   /** Standard class typedefs. */
-  typedef AdvancedLinearInterpolateImageFunction                   Self;
-  typedef LinearInterpolateImageFunction< TInputImage, TCoordRep > Superclass;
-  typedef SmartPointer< Self >                                     Pointer;
-  typedef SmartPointer< const Self >                               ConstPointer;
+  using Self = AdvancedLinearInterpolateImageFunction;
+  using Superclass = LinearInterpolateImageFunction<TInputImage, TCoordRep>;
+  using Pointer = SmartPointer<Self>;
+  using ConstPointer = SmartPointer<const Self>;
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( AdvancedLinearInterpolateImageFunction, LinearInterpolateImageFunction );
+  itkTypeMacro(AdvancedLinearInterpolateImageFunction, LinearInterpolateImageFunction);
 
   /** Method for creation through the object factory. */
-  itkNewMacro( Self );
+  itkNewMacro(Self);
 
   /** OutputType typedef support. */
-  typedef typename Superclass::OutputType OutputType;
+  using typename Superclass::OutputType;
 
   /** InputImageType typedef support. */
-  typedef typename Superclass::InputImageType  InputImageType;
-  typedef typename InputImageType::SpacingType InputImageSpacingType;
+  using typename Superclass::InputImageType;
+  using InputImageSpacingType = typename InputImageType::SpacingType;
 
   /** InputPixelType typedef support. */
-  typedef typename Superclass::InputPixelType InputPixelType;
+  using typename Superclass::InputPixelType;
 
   /** RealType typedef support. */
-  typedef typename Superclass::RealType RealType;
+  using typename Superclass::RealType;
 
   /** Dimension underlying input image. */
-  itkStaticConstMacro( ImageDimension, unsigned int, Superclass::ImageDimension );
+  itkStaticConstMacro(ImageDimension, unsigned int, Superclass::ImageDimension);
 
   /** Index typedef support. */
-  typedef typename Superclass::IndexType IndexType;
+  using typename Superclass::IndexType;
 
   /** ContinuousIndex typedef support. */
-  typedef typename Superclass::ContinuousIndexType ContinuousIndexType;
-  typedef typename ContinuousIndexType::ValueType  ContinuousIndexValueType;
+  using typename Superclass::ContinuousIndexType;
+  using ContinuousIndexValueType = typename ContinuousIndexType::ValueType;
 
   /** Derivative typedef support */
-  typedef CovariantVector< OutputType,
-    itkGetStaticConstMacro( ImageDimension ) >        CovariantVectorType;
+  using CovariantVectorType = CovariantVector<OutputType, Self::ImageDimension>;
 
   /** Method to compute the derivative. */
-  CovariantVectorType EvaluateDerivativeAtContinuousIndex(
-    const ContinuousIndexType & x ) const;
+  CovariantVectorType
+  EvaluateDerivativeAtContinuousIndex(const ContinuousIndexType & x) const;
 
   /** Method to compute both the value and the derivative. */
-  void EvaluateValueAndDerivativeAtContinuousIndex(
-    const ContinuousIndexType & x,
-    OutputType & value,
-    CovariantVectorType & deriv ) const
+  void
+  EvaluateValueAndDerivativeAtContinuousIndex(const ContinuousIndexType & x,
+                                              OutputType &                value,
+                                              CovariantVectorType &       deriv) const
   {
-    return this->EvaluateValueAndDerivativeOptimized(
-      Dispatch< ImageDimension >(), x, value, deriv );
+    return this->EvaluateValueAndDerivativeOptimized(Dispatch<ImageDimension>(), x, value, deriv);
   }
 
 
 protected:
-
-  AdvancedLinearInterpolateImageFunction();
-  ~AdvancedLinearInterpolateImageFunction() override{}
+  AdvancedLinearInterpolateImageFunction() = default;
+  ~AdvancedLinearInterpolateImageFunction() override = default;
 
 private:
-
-  AdvancedLinearInterpolateImageFunction( const Self & ); // purposely not implemented
-  void operator=( const Self & );                         // purposely not implemented
-
   /** Helper struct to select the correct dimension. */
-  struct DispatchBase {};
-  template< unsigned int >
-  struct Dispatch : public DispatchBase {};
+  struct DispatchBase
+  {};
+  template <unsigned int>
+  struct Dispatch : public DispatchBase
+  {};
 
   /** Method to compute both the value and the derivative. 2D specialization. */
-  inline void EvaluateValueAndDerivativeOptimized(
-    const Dispatch< 2 > &,
-    const ContinuousIndexType & x,
-    OutputType & value,
-    CovariantVectorType & deriv ) const;
+  void
+  EvaluateValueAndDerivativeOptimized(const Dispatch<2> &,
+                                      const ContinuousIndexType & x,
+                                      OutputType &                value,
+                                      CovariantVectorType &       deriv) const;
 
   /** Method to compute both the value and the derivative. 3D specialization. */
-  inline void EvaluateValueAndDerivativeOptimized(
-    const Dispatch< 3 > &,
-    const ContinuousIndexType & x,
-    OutputType & value,
-    CovariantVectorType & deriv ) const;
+  void
+  EvaluateValueAndDerivativeOptimized(const Dispatch<3> &,
+                                      const ContinuousIndexType & x,
+                                      OutputType &                value,
+                                      CovariantVectorType &       deriv) const;
 
   /** Method to compute both the value and the derivative. Generic. */
-  inline void EvaluateValueAndDerivativeOptimized(
-    const DispatchBase &,
-    const ContinuousIndexType & x,
-    OutputType & value,
-    CovariantVectorType & deriv ) const
+  void
+  EvaluateValueAndDerivativeOptimized(const DispatchBase &,
+                                      const ContinuousIndexType & x,
+                                      OutputType &                value,
+                                      CovariantVectorType &       deriv) const
   {
-    return this->EvaluateValueAndDerivativeUnOptimized( x, value, deriv );
+    return this->EvaluateValueAndDerivativeUnOptimized(x, value, deriv);
   }
 
 
   /** Method to compute both the value and the derivative. Generic. */
-  inline void EvaluateValueAndDerivativeUnOptimized(
-    const ContinuousIndexType & x,
-    OutputType & value,
-    CovariantVectorType & deriv ) const
+  void
+  EvaluateValueAndDerivativeUnOptimized(const ContinuousIndexType & x,
+                                        OutputType &                value,
+                                        CovariantVectorType &       deriv) const
   {
-    itkExceptionMacro( << "ERROR: EvaluateValueAndDerivativeAtContinuousIndex() "
-                       << "is not implemented for this dimension ("
-                       << ImageDimension << ")." );
+    itkExceptionMacro(<< "ERROR: EvaluateValueAndDerivativeAtContinuousIndex() is not implemented for this dimension ("
+                      << ImageDimension << ").");
   }
-
-
 };
 
 } // end namespace itk
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "itkAdvancedLinearInterpolateImageFunction.hxx"
+#  include "itkAdvancedLinearInterpolateImageFunction.hxx"
 #endif
 
 #endif
