@@ -31,8 +31,8 @@ the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef __itkAdvancedRayCastInterpolateImageFunction_h
-#define __itkAdvancedRayCastInterpolateImageFunction_h
+#ifndef itkAdvancedRayCastInterpolateImageFunction_h
+#define itkAdvancedRayCastInterpolateImageFunction_h
 
 #include "itkInterpolateImageFunction.h"
 #include "itkTransform.h"
@@ -52,71 +52,71 @@ namespace itk
  *
  * \ingroup ImageFunctions
  */
-template< class TInputImage, class TCoordRep = double >
-class AdvancedRayCastInterpolateImageFunction :
-  public InterpolateImageFunction< TInputImage, TCoordRep >
+template <class TInputImage, class TCoordRep = double>
+class ITK_TEMPLATE_EXPORT AdvancedRayCastInterpolateImageFunction
+  : public InterpolateImageFunction<TInputImage, TCoordRep>
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(AdvancedRayCastInterpolateImageFunction);
 
   /** Standard class typedefs. */
-  typedef AdvancedRayCastInterpolateImageFunction            Self;
-  typedef InterpolateImageFunction< TInputImage, TCoordRep > Superclass;
-  typedef SmartPointer< Self >                               Pointer;
-  typedef SmartPointer< const Self >                         ConstPointer;
+  using Self = AdvancedRayCastInterpolateImageFunction;
+  using Superclass = InterpolateImageFunction<TInputImage, TCoordRep>;
+  using Pointer = SmartPointer<Self>;
+  using ConstPointer = SmartPointer<const Self>;
 
   /** Constants for the image dimensions */
-  itkStaticConstMacro( InputImageDimension, unsigned int,
-    TInputImage::ImageDimension );
+  itkStaticConstMacro(InputImageDimension, unsigned int, TInputImage::ImageDimension);
 
   /**
    * Type of the Transform Base class
    * The fixed image should be a 3D image
    */
-  typedef Transform< TCoordRep, InputImageDimension, InputImageDimension > TransformType;
+  using TransformType = Transform<TCoordRep, InputImageDimension, InputImageDimension>;
 
-  typedef typename TransformType::Pointer         TransformPointer;
-  typedef typename TransformType::InputPointType  InputPointType;
-  typedef typename TransformType::OutputPointType OutputPointType;
-  typedef typename TransformType::ParametersType  TransformParametersType;
-  typedef typename TransformType::JacobianType    TransformJacobianType;
+  using TransformPointer = typename TransformType::Pointer;
+  using InputPointType = typename TransformType::InputPointType;
+  using OutputPointType = typename TransformType::OutputPointType;
+  using TransformParametersType = typename TransformType::ParametersType;
+  using TransformJacobianType = typename TransformType::JacobianType;
 
-  typedef typename Superclass::InputPixelType PixelType;
+  using PixelType = typename Superclass::InputPixelType;
 
-  typedef typename TInputImage::SizeType SizeType;
+  using SizeType = typename TInputImage::SizeType;
 
-  typedef Vector< TCoordRep, InputImageDimension > DirectionType;
+  using DirectionType = Vector<TCoordRep, InputImageDimension>;
 
   /**  Type of the Interpolator Base class */
-  typedef InterpolateImageFunction< TInputImage, TCoordRep > InterpolatorType;
+  using InterpolatorType = InterpolateImageFunction<TInputImage, TCoordRep>;
 
-  typedef typename InterpolatorType::Pointer InterpolatorPointer;
+  using InterpolatorPointer = typename InterpolatorType::Pointer;
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( AdvancedRayCastInterpolateImageFunction, InterpolateImageFunction );
+  itkTypeMacro(AdvancedRayCastInterpolateImageFunction, InterpolateImageFunction);
 
   /** Method for creation through the object factory. */
-  itkNewMacro( Self );
+  itkNewMacro(Self);
 
   /** OutputType typedef support. */
-  typedef typename Superclass::OutputType OutputType;
+  using typename Superclass::OutputType;
 
   /** InputImageType typedef support. */
-  typedef typename Superclass::InputImageType InputImageType;
+  using typename Superclass::InputImageType;
 
   /** RealType typedef support. */
-  typedef typename Superclass::RealType RealType;
+  using typename Superclass::RealType;
 
   /** Dimension underlying input image. */
-  itkStaticConstMacro( ImageDimension, unsigned int, Superclass::ImageDimension );
+  itkStaticConstMacro(ImageDimension, unsigned int, Superclass::ImageDimension);
 
   /** Point typedef support. */
-  typedef typename Superclass::PointType PointType;
+  using typename Superclass::PointType;
 
   /** Index typedef support. */
-  typedef typename Superclass::IndexType IndexType;
+  using typename Superclass::IndexType;
 
   /** ContinuousIndex typedef support. */
-  typedef typename Superclass::ContinuousIndexType ContinuousIndexType;
+  using typename Superclass::ContinuousIndexType;
 
   /** \brief
    * Interpolate the image at a point position.
@@ -128,7 +128,8 @@ public:
    * ImageFunction::IsInsideBuffer() can be used to check bounds before
    * calling the method.
    */
-  OutputType Evaluate( const PointType & point ) const override;
+  OutputType
+  Evaluate(const PointType & point) const override;
 
   /** Interpolate the image at a continuous index position
    *
@@ -141,94 +142,93 @@ public:
    * ImageFunction::IsInsideBuffer() can be used to check bounds before
    * calling the method.
    */
-  OutputType EvaluateAtContinuousIndex(
-    const ContinuousIndexType & index ) const override;
+  OutputType
+  EvaluateAtContinuousIndex(const ContinuousIndexType & index) const override;
 
   /** Connect the Transform. */
-  itkSetObjectMacro( Transform, TransformType );
+  itkSetObjectMacro(Transform, TransformType);
   /** Get a pointer to the Transform.  */
-  itkGetModifiableObjectMacro( Transform, TransformType );
+  itkGetModifiableObjectMacro(Transform, TransformType);
 
   /** Connect the Interpolator. */
-  itkSetObjectMacro( Interpolator, InterpolatorType );
+  itkSetObjectMacro(Interpolator, InterpolatorType);
   /** Get a pointer to the Interpolator.  */
-  itkGetModifiableObjectMacro( Interpolator, InterpolatorType );
+  itkGetModifiableObjectMacro(Interpolator, InterpolatorType);
 
   /** Connect the Interpolator. */
-  itkSetMacro( FocalPoint, InputPointType );
+  itkSetMacro(FocalPoint, InputPointType);
   /** Get a pointer to the Interpolator.  */
-  itkGetConstMacro( FocalPoint, InputPointType );
+  itkGetConstMacro(FocalPoint, InputPointType);
 
   /** Connect the Transform. */
-  itkSetMacro( Threshold, double );
+  itkSetMacro(Threshold, double);
   /** Get a pointer to the Transform.  */
-  itkGetConstMacro( Threshold, double );
+  itkGetConstMacro(Threshold, double);
 
   /** Check if a point is inside the image buffer.
    * \warning For efficiency, no validity checking of
    * the input image pointer is done. */
-  inline bool IsInsideBuffer( const PointType & ) const override
+  bool
+  IsInsideBuffer(const PointType &) const override
   {
     return true;
   }
 
 
-  bool IsInsideBuffer( const ContinuousIndexType &  ) const override
+  bool
+  IsInsideBuffer(const ContinuousIndexType &) const override
   {
     return true;
   }
 
 
-  bool IsInsideBuffer( const IndexType &  ) const override
+  bool
+  IsInsideBuffer(const IndexType &) const override
   {
     return true;
   }
 
 
 protected:
-
   /// Constructor
-  AdvancedRayCastInterpolateImageFunction();
+  AdvancedRayCastInterpolateImageFunction() = default;
 
   /// Destructor
-  ~AdvancedRayCastInterpolateImageFunction() override{}
+  ~AdvancedRayCastInterpolateImageFunction() override = default;
 
   /// Print the object
-  void PrintSelf( std::ostream & os, Indent indent ) const override;
+  void
+  PrintSelf(std::ostream & os, Indent indent) const override;
 
   /// Transformation used to calculate the new focal point position
   TransformPointer m_Transform;
 
   /// The focal point or position of the ray source
-  InputPointType m_FocalPoint;
+  InputPointType m_FocalPoint{};
 
   /// The threshold above which voxels along the ray path are integrated.
-  double m_Threshold;
+  double m_Threshold{ 0.0 };
 
   /// Pointer to the interpolator
   InterpolatorPointer m_Interpolator;
 
 private:
-
-  AdvancedRayCastInterpolateImageFunction( const Self & ); // purposely not implemented
-  void operator=( const Self & );                          // purposely not implemented
-
-  SizeType GetRadius() const override
+  SizeType
+  GetRadius() const override
   {
-    const InputImageType* const input = this->GetInputImage();
+    const InputImageType * const input = this->GetInputImage();
     if (!input)
     {
       itkExceptionMacro("Input image required!");
     }
     return input->GetLargestPossibleRegion().GetSize();
   }
-
 };
 
 } // namespace itk
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "itkAdvancedRayCastInterpolateImageFunction.hxx"
+#  include "itkAdvancedRayCastInterpolateImageFunction.hxx"
 #endif
 
 #endif
