@@ -15,12 +15,10 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-
 /*=========================================================================
 
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkReducedDimBSplineInterpolateImageFunction.h,v $
-  Language:  C++
   Date:      $Date: 2009-04-25 12:27:05 $
   Version:   $Revision: 1.24 $
 
@@ -35,14 +33,13 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef __itkReducedDimensionBSplineInterpolateImageFunction_h
-#define __itkReducedDimensionBSplineInterpolateImageFunction_h
+#ifndef itkReducedDimensionBSplineInterpolateImageFunction_h
+#define itkReducedDimensionBSplineInterpolateImageFunction_h
 
 #include <vector>
 
-#include "itkImageLinearIteratorWithIndex.h"
 #include "itkInterpolateImageFunction.h"
-#include "vnl/vnl_matrix.h"
+#include <vnl/vnl_matrix.h>
 
 #include "itkMultiOrderBSplineDecompositionImageFilter.h"
 #include "itkConceptChecking.h"
@@ -84,61 +81,53 @@ namespace itk
  *
  * \ingroup ImageFunctions
  */
-template<
-class TImageType,
-class TCoordRep        = double,
-class TCoefficientType = double >
-class ITK_EXPORT ReducedDimensionBSplineInterpolateImageFunction :
-  public         InterpolateImageFunction< TImageType, TCoordRep >
+template <class TImageType, class TCoordRep = double, class TCoefficientType = double>
+class ITK_TEMPLATE_EXPORT ReducedDimensionBSplineInterpolateImageFunction
+  : public InterpolateImageFunction<TImageType, TCoordRep>
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(ReducedDimensionBSplineInterpolateImageFunction);
 
   /** Standard class typedefs. */
-  typedef ReducedDimensionBSplineInterpolateImageFunction   Self;
-  typedef InterpolateImageFunction< TImageType, TCoordRep > Superclass;
-  typedef SmartPointer< Self >                              Pointer;
-  typedef SmartPointer< const Self >                        ConstPointer;
+  using Self = ReducedDimensionBSplineInterpolateImageFunction;
+  using Superclass = InterpolateImageFunction<TImageType, TCoordRep>;
+  using Pointer = SmartPointer<Self>;
+  using ConstPointer = SmartPointer<const Self>;
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( ReducedDimensionBSplineInterpolateImageFunction, InterpolateImageFunction );
+  itkTypeMacro(ReducedDimensionBSplineInterpolateImageFunction, InterpolateImageFunction);
 
   /** New macro for creation of through a Smart Pointer */
-  itkNewMacro( Self );
+  itkNewMacro(Self);
 
   /** OutputType typedef support. */
-  typedef typename Superclass::OutputType OutputType;
+  using typename Superclass::OutputType;
 
   using SizeType = typename TImageType::SizeType;
 
   /** InputImageType typedef support. */
-  typedef typename Superclass::InputImageType InputImageType;
+  using typename Superclass::InputImageType;
 
   /** Dimension underlying input image. */
-  itkStaticConstMacro( ImageDimension, unsigned int, Superclass::ImageDimension );
+  itkStaticConstMacro(ImageDimension, unsigned int, Superclass::ImageDimension);
 
   /** Index typedef support. */
-  typedef typename Superclass::IndexType IndexType;
+  using typename Superclass::IndexType;
 
   /** ContinuousIndex typedef support. */
-  typedef typename Superclass::ContinuousIndexType ContinuousIndexType;
+  using typename Superclass::ContinuousIndexType;
 
   /** PointType typedef support */
-  typedef typename Superclass::PointType PointType;
-
-  /** Iterator typedef support */
-  typedef ImageLinearIteratorWithIndex< TImageType > Iterator;
+  using typename Superclass::PointType;
 
   /** Internal Coefficient typedef support */
-  typedef TCoefficientType CoefficientDataType;
-  typedef Image< CoefficientDataType,
-    itkGetStaticConstMacro( ImageDimension )
-    >                      CoefficientImageType;
+  using CoefficientDataType = TCoefficientType;
+  using CoefficientImageType = Image<CoefficientDataType, Self::ImageDimension>;
 
   /** Define filter for calculating the BSpline coefficients */
-  typedef MultiOrderBSplineDecompositionImageFilter< TImageType, CoefficientImageType >
-    CoefficientFilter;
+  using CoefficientFilter = MultiOrderBSplineDecompositionImageFilter<TImageType, CoefficientImageType>;
 
-  typedef typename CoefficientFilter::Pointer CoefficientFilterPointer;
+  using CoefficientFilterPointer = typename CoefficientFilter::Pointer;
 
   /** Evaluate the function at a ContinuousIndex position.
    *
@@ -148,33 +137,33 @@ public:
    *
    * ImageFunction::IsInsideBuffer() can be used to check bounds before
    * calling the method. */
-  OutputType EvaluateAtContinuousIndex(
-    const ContinuousIndexType & index ) const override;
+  OutputType
+  EvaluateAtContinuousIndex(const ContinuousIndexType & index) const override;
 
   /** Derivative typedef support */
-  typedef CovariantVector< OutputType,
-    itkGetStaticConstMacro( ImageDimension )
-    > CovariantVectorType;
+  using CovariantVectorType = CovariantVector<OutputType, Self::ImageDimension>;
 
-  CovariantVectorType EvaluateDerivative( const PointType & point ) const
+  CovariantVectorType
+  EvaluateDerivative(const PointType & point) const
   {
-    ContinuousIndexType index;
-    this->GetInputImage()->TransformPhysicalPointToContinuousIndex( point, index );
-    return ( this->EvaluateDerivativeAtContinuousIndex( index ) );
+    const auto index = this->GetInputImage()->template TransformPhysicalPointToContinuousIndex<TCoordRep>(point);
+    return (this->EvaluateDerivativeAtContinuousIndex(index));
   }
 
 
-  CovariantVectorType EvaluateDerivativeAtContinuousIndex(
-    const ContinuousIndexType & x ) const;
+  CovariantVectorType
+  EvaluateDerivativeAtContinuousIndex(const ContinuousIndexType & x) const;
 
   /** Get/Sets the Spline Order, supports 0th - 5th order splines. The default
    *  is a 3rd order spline. */
-  void SetSplineOrder( unsigned int SplineOrder );
+  void
+  SetSplineOrder(unsigned int SplineOrder);
 
-  itkGetConstMacro( SplineOrder, int );
+  itkGetConstMacro(SplineOrder, int);
 
   /** Set the input image.  This must be set by the user. */
-  void SetInputImage( const TImageType * inputData ) override;
+  void
+  SetInputImage(const TImageType * inputData) override;
 
   /** The UseImageDirection flag determines whether image derivatives are
    * computed with respect to the image grid or with respect to the physical
@@ -188,75 +177,72 @@ public:
    * ITK_IMAGE_BEHAVES_AS_ORIENTED_IMAGE (i.e ON by default when ITK_IMAGE_BEHAVES_AS_ORIENTED_IMAGE is ON,
    * and  OFF by default when ITK_IMAGE_BEHAVES_AS_ORIENTED_IMAGE is
    * OFF). */
-  itkSetMacro( UseImageDirection, bool );
-  itkGetConstMacro( UseImageDirection, bool );
-  itkBooleanMacro( UseImageDirection );
+  itkSetMacro(UseImageDirection, bool);
+  itkGetConstMacro(UseImageDirection, bool);
+  itkBooleanMacro(UseImageDirection);
 
 protected:
-
   ReducedDimensionBSplineInterpolateImageFunction();
-  ~ReducedDimensionBSplineInterpolateImageFunction() override {}
-  void PrintSelf( std::ostream & os, Indent indent ) const override;
+  ~ReducedDimensionBSplineInterpolateImageFunction() override = default;
+  void
+  PrintSelf(std::ostream & os, Indent indent) const override;
 
   // These are needed by the smoothing spline routine.
-  std::vector< CoefficientDataType > m_Scratch;      // temp storage for processing of Coefficients
-  typename TImageType::SizeType m_DataLength;        // Image size
-  unsigned int m_SplineOrder;                        // User specified spline order (3rd or cubic is the default)
+  typename TImageType::SizeType m_DataLength;  // Image size
+  unsigned int                  m_SplineOrder; // User specified spline order (3rd or cubic is the default)
 
-  typename CoefficientImageType::ConstPointer m_Coefficients;       // Spline coefficients
+  typename CoefficientImageType::ConstPointer m_Coefficients; // Spline coefficients
 
 private:
-
-  ReducedDimensionBSplineInterpolateImageFunction( const Self & ); //purposely not implemented
-  void operator=( const Self & );                                  //purposely not implemented
-
-  SizeType GetRadius() const override
+  SizeType
+  GetRadius() const override
   {
     return SizeType::Filled(m_SplineOrder + 1);
   }
 
   /** Determines the weights for interpolation of the value x */
-  void SetInterpolationWeights( const ContinuousIndexType & x,
-    const vnl_matrix< long > & EvaluateIndex,
-    vnl_matrix< double > & weights,
-    unsigned int splineOrder ) const;
+  void
+  SetInterpolationWeights(const ContinuousIndexType & x,
+                          const vnl_matrix<long> &    EvaluateIndex,
+                          vnl_matrix<double> &        weights,
+                          unsigned int                splineOrder) const;
 
   /** Determines the weights for the derivative portion of the value x */
-  void SetDerivativeWeights( const ContinuousIndexType & x,
-    const vnl_matrix< long > & EvaluateIndex,
-    vnl_matrix< double > & weights,
-    unsigned int splineOrder ) const;
+  void
+  SetDerivativeWeights(const ContinuousIndexType & x,
+                       const vnl_matrix<long> &    EvaluateIndex,
+                       vnl_matrix<double> &        weights,
+                       unsigned int                splineOrder) const;
 
   /** Precomputation for converting the 1D index of the interpolation neighborhood
-    * to an N-dimensional index. */
-  void GeneratePointsToIndex();
+   * to an N-dimensional index. */
+  void
+  GeneratePointsToIndex();
 
   /** Determines the indicies to use give the splines region of support */
-  void DetermineRegionOfSupport( vnl_matrix< long > & evaluateIndex,
-    const ContinuousIndexType & x,
-    unsigned int splineOrder ) const;
+  void
+  DetermineRegionOfSupport(vnl_matrix<long> &          evaluateIndex,
+                           const ContinuousIndexType & x,
+                           unsigned int                splineOrder) const;
 
   /** Set the indicies in evaluateIndex at the boundaries based on mirror
-    * boundary conditions. */
-  void ApplyMirrorBoundaryConditions( vnl_matrix< long > & evaluateIndex,
-    unsigned int splineOrder ) const;
+   * boundary conditions. */
+  void
+  ApplyMirrorBoundaryConditions(vnl_matrix<long> & evaluateIndex, unsigned int splineOrder) const;
 
-  Iterator                 m_CIterator;                    // Iterator for traversing spline coefficients.
-  unsigned long            m_MaxNumberInterpolationPoints; // number of neighborhood points used for interpolation
-  std::vector< IndexType > m_PointsToIndex;                // Preallocation of interpolation neighborhood indicies
+  std::vector<IndexType> m_PointsToIndex; // Preallocation of interpolation neighborhood indicies
 
   CoefficientFilterPointer m_CoefficientFilter;
 
   // flag to take or not the image direction into account when computing the
   // derivatives.
   bool m_UseImageDirection;
-
 };
 
 } // namespace itk
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "itkReducedDimensionBSplineInterpolateImageFunction.hxx"
+#  include "itkReducedDimensionBSplineInterpolateImageFunction.hxx"
 #endif
 
 #endif
