@@ -15,33 +15,19 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __xoutmain_cxx
-#define __xoutmain_cxx
 
 #include "xoutmain.h"
 
 namespace xoutlibrary
 {
-static xoutbase_type * local_xout = 0;
-
-xoutbase_type &
-get_xout( void )
+xoutmain &
+get_xout()
 {
-  return *local_xout;
+  // Note: C++11 "magic statics" ensures that the construction of a local
+  // static variable like this is thread-safe.
+  static xoutmain local_xout;
+
+  return local_xout;
 }
 
-
-void
-set_xout( xoutbase_type * arg )
-{
-  local_xout = arg;
-}
-
-bool xout_valid() {
-  return local_xout != 0;
-}
-
-
-} // end namespace
-
-#endif // end #ifndef __xoutmain_cxx
+} // namespace xoutlibrary
