@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __xoutmain_h
-#define __xoutmain_h
+#ifndef xoutmain_h
+#define xoutmain_h
 
 /** Necessary includes for using xout. */
 #include "xoutbase.h"
@@ -32,17 +32,14 @@ namespace xl = xoutlibrary;
 /** Typedefs for the most common use of xout */
 namespace xoutlibrary
 {
-typedef xoutbase< char >   xoutbase_type;
-typedef xoutsimple< char > xoutsimple_type;
-typedef xoutrow< char >    xoutrow_type;
-typedef xoutcell< char >   xoutcell_type;
 
-xoutbase_type & get_xout( void );
+/** The main xout class */
+class xoutmain : public xoutbase
+{};
 
-void set_xout( xoutbase_type * arg );
-
-bool xout_valid();
+xoutmain &
+get_xout();
 
 } // end namespace xoutlibrary
 
-#endif // end #ifndef __xoutmain_h
+#endif // end #ifndef xoutmain_h
