@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __elxAdvancedMattesMutualInformationMetric_H__
-#define __elxAdvancedMattesMutualInformationMetric_H__
+#ifndef elxAdvancedMattesMutualInformationMetric_h
+#define elxAdvancedMattesMutualInformationMetric_h
 
 #include "elxIncludes.h" // include first to avoid MSVS warning
 #include "itkParzenWindowMutualInformationImageToImageMetric.h"
@@ -96,158 +96,143 @@ namespace elastix
  * \ingroup Metrics
  */
 
-template< class TElastix >
-class AdvancedMattesMutualInformationMetric :
-  public
-  itk::ParzenWindowMutualInformationImageToImageMetric<
-  typename MetricBase< TElastix >::FixedImageType,
-  typename MetricBase< TElastix >::MovingImageType >,
-  public MetricBase< TElastix >
+template <class TElastix>
+class ITK_TEMPLATE_EXPORT AdvancedMattesMutualInformationMetric
+  : public itk::ParzenWindowMutualInformationImageToImageMetric<typename MetricBase<TElastix>::FixedImageType,
+                                                                typename MetricBase<TElastix>::MovingImageType>
+  , public MetricBase<TElastix>
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(AdvancedMattesMutualInformationMetric);
 
   /** Standard ITK-stuff. */
-  typedef AdvancedMattesMutualInformationMetric Self;
-  typedef itk::ParzenWindowMutualInformationImageToImageMetric<
-    typename MetricBase< TElastix >::FixedImageType,
-    typename MetricBase< TElastix >::MovingImageType >    Superclass1;
-  typedef MetricBase< TElastix >          Superclass2;
-  typedef itk::SmartPointer< Self >       Pointer;
-  typedef itk::SmartPointer< const Self > ConstPointer;
+  using Self = AdvancedMattesMutualInformationMetric;
+  using Superclass1 =
+    itk::ParzenWindowMutualInformationImageToImageMetric<typename MetricBase<TElastix>::FixedImageType,
+                                                         typename MetricBase<TElastix>::MovingImageType>;
+  using Superclass2 = MetricBase<TElastix>;
+  using Pointer = itk::SmartPointer<Self>;
+  using ConstPointer = itk::SmartPointer<const Self>;
 
   /** Method for creation through the object factory. */
-  itkNewMacro( Self );
+  itkNewMacro(Self);
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( AdvancedMattesMutualInformationMetric,
-    itk::ParzenWindowMutualInformationImageToImageMetric );
+  itkTypeMacro(AdvancedMattesMutualInformationMetric, itk::ParzenWindowMutualInformationImageToImageMetric);
 
   /** Name of this class.
    * Use this name in the parameter file to select this specific metric. \n
    * example: <tt>(Metric "AdvancedMattesMutualInformation")</tt>\n
    */
-  elxClassNameMacro( "AdvancedMattesMutualInformation" );
+  elxClassNameMacro("AdvancedMattesMutualInformation");
 
   /** Typedefs from the superclass. */
-  typedef typename
-    Superclass1::CoordinateRepresentationType CoordinateRepresentationType;
-  typedef typename Superclass1::MovingImageType            MovingImageType;
-  typedef typename Superclass1::MovingImagePixelType       MovingImagePixelType;
-  typedef typename Superclass1::MovingImageConstPointer    MovingImageConstPointer;
-  typedef typename Superclass1::FixedImageType             FixedImageType;
-  typedef typename Superclass1::FixedImageConstPointer     FixedImageConstPointer;
-  typedef typename Superclass1::FixedImageRegionType       FixedImageRegionType;
-  typedef typename Superclass1::TransformType              TransformType;
-  typedef typename Superclass1::TransformPointer           TransformPointer;
-  typedef typename Superclass1::InputPointType             InputPointType;
-  typedef typename Superclass1::OutputPointType            OutputPointType;
-  typedef typename Superclass1::TransformParametersType    TransformParametersType;
-  typedef typename Superclass1::TransformJacobianType      TransformJacobianType;
-  typedef typename Superclass1::InterpolatorType           InterpolatorType;
-  typedef typename Superclass1::InterpolatorPointer        InterpolatorPointer;
-  typedef typename Superclass1::RealType                   RealType;
-  typedef typename Superclass1::GradientPixelType          GradientPixelType;
-  typedef typename Superclass1::GradientImageType          GradientImageType;
-  typedef typename Superclass1::GradientImagePointer       GradientImagePointer;
-  typedef typename Superclass1::GradientImageFilterType    GradientImageFilterType;
-  typedef typename Superclass1::GradientImageFilterPointer GradientImageFilterPointer;
-  typedef typename Superclass1::FixedImageMaskType         FixedImageMaskType;
-  typedef typename Superclass1::FixedImageMaskPointer      FixedImageMaskPointer;
-  typedef typename Superclass1::MovingImageMaskType        MovingImageMaskType;
-  typedef typename Superclass1::MovingImageMaskPointer     MovingImageMaskPointer;
-  typedef typename Superclass1::MeasureType                MeasureType;
-  typedef typename Superclass1::DerivativeType             DerivativeType;
-  typedef typename Superclass1::ParametersType             ParametersType;
-  typedef typename Superclass1::FixedImagePixelType        FixedImagePixelType;
-  typedef typename Superclass1::MovingImageRegionType      MovingImageRegionType;
-  typedef typename Superclass1::ImageSamplerType           ImageSamplerType;
-  typedef typename Superclass1::ImageSamplerPointer        ImageSamplerPointer;
-  typedef typename Superclass1::ImageSampleContainerType   ImageSampleContainerType;
-  typedef typename
-    Superclass1::ImageSampleContainerPointer ImageSampleContainerPointer;
-  typedef typename Superclass1::FixedImageLimiterType  FixedImageLimiterType;
-  typedef typename Superclass1::MovingImageLimiterType MovingImageLimiterType;
-  typedef typename
-    Superclass1::FixedImageLimiterOutputType FixedImageLimiterOutputType;
-  typedef typename
-    Superclass1::MovingImageLimiterOutputType MovingImageLimiterOutputType;
-  typedef typename
-    Superclass1::MovingImageDerivativeScalesType MovingImageDerivativeScalesType;
+  using typename Superclass1::CoordinateRepresentationType;
+  using typename Superclass1::MovingImageType;
+  using typename Superclass1::MovingImagePixelType;
+  using typename Superclass1::MovingImageConstPointer;
+  using typename Superclass1::FixedImageType;
+  using typename Superclass1::FixedImageConstPointer;
+  using typename Superclass1::FixedImageRegionType;
+  using typename Superclass1::TransformType;
+  using typename Superclass1::TransformPointer;
+  using typename Superclass1::InputPointType;
+  using typename Superclass1::OutputPointType;
+  using typename Superclass1::TransformParametersType;
+  using typename Superclass1::TransformJacobianType;
+  using typename Superclass1::InterpolatorType;
+  using typename Superclass1::InterpolatorPointer;
+  using typename Superclass1::RealType;
+  using typename Superclass1::GradientPixelType;
+  using typename Superclass1::GradientImageType;
+  using typename Superclass1::GradientImagePointer;
+  using typename Superclass1::GradientImageFilterType;
+  using typename Superclass1::GradientImageFilterPointer;
+  using typename Superclass1::FixedImageMaskType;
+  using typename Superclass1::FixedImageMaskPointer;
+  using typename Superclass1::MovingImageMaskType;
+  using typename Superclass1::MovingImageMaskPointer;
+  using typename Superclass1::MeasureType;
+  using typename Superclass1::DerivativeType;
+  using typename Superclass1::ParametersType;
+  using typename Superclass1::FixedImagePixelType;
+  using typename Superclass1::MovingImageRegionType;
+  using typename Superclass1::ImageSamplerType;
+  using typename Superclass1::ImageSamplerPointer;
+  using typename Superclass1::ImageSampleContainerType;
+  using typename Superclass1::ImageSampleContainerPointer;
+  using typename Superclass1::FixedImageLimiterType;
+  using typename Superclass1::MovingImageLimiterType;
+  using typename Superclass1::FixedImageLimiterOutputType;
+  using typename Superclass1::MovingImageLimiterOutputType;
+  using typename Superclass1::MovingImageDerivativeScalesType;
 
   /** The fixed image dimension. */
-  itkStaticConstMacro( FixedImageDimension, unsigned int,
-    FixedImageType::ImageDimension );
+  itkStaticConstMacro(FixedImageDimension, unsigned int, FixedImageType::ImageDimension);
 
   /** The moving image dimension. */
-  itkStaticConstMacro( MovingImageDimension, unsigned int,
-    MovingImageType::ImageDimension );
+  itkStaticConstMacro(MovingImageDimension, unsigned int, MovingImageType::ImageDimension);
 
   /** Typedef's inherited from Elastix. */
-  typedef typename Superclass2::ElastixType          ElastixType;
-  typedef typename Superclass2::ElastixPointer       ElastixPointer;
-  typedef typename Superclass2::ConfigurationType    ConfigurationType;
-  typedef typename Superclass2::ConfigurationPointer ConfigurationPointer;
-  typedef typename Superclass2::RegistrationType     RegistrationType;
-  typedef typename Superclass2::RegistrationPointer  RegistrationPointer;
-  typedef typename Superclass2::ITKBaseType          ITKBaseType;
+  using typename Superclass2::ElastixType;
+  using typename Superclass2::RegistrationType;
+  using ITKBaseType = typename Superclass2::ITKBaseType;
 
   /** Execute stuff before each new pyramid resolution:
    * \li Set the number of histogram bins.
    * \li Set the CheckNumberOfSamples option.
    * \li Set the fixed/moving LimitRangeRatio
    * \li Set the fixed/moving limiter. */
-  void BeforeEachResolution( void ) override;
+  void
+  BeforeEachResolution() override;
 
   /** Update the CurrenIteration. This is only important
    * if a finite difference derivative estimation is used
    * (selected by the experimental parameter FiniteDifferenceDerivative)  */
-  void AfterEachIteration( void ) override;
+  void
+  AfterEachIteration() override;
 
   /** Set up a timer to measure the initialization time and
    * call the Superclass' implementation. */
-  void Initialize( void ) override;
+  void
+  Initialize() override;
 
   /** Set/Get c. For finite difference derivative estimation */
-  itkSetMacro( Param_c, double );
-  itkGetConstMacro( Param_c, double );
+  itkSetMacro(Param_c, double);
+  itkGetConstMacro(Param_c, double);
 
   /** Set/Get gamma. For finite difference derivative estimation */
-  itkSetMacro( Param_gamma, double );
-  itkGetConstMacro( Param_gamma, double );
+  itkSetMacro(Param_gamma, double);
+  itkGetConstMacro(Param_gamma, double);
 
   /** Set/Get the current iteration. For finite difference derivative estimation */
-  itkSetMacro( CurrentIteration, unsigned int );
-  itkGetConstMacro( CurrentIteration, unsigned int );
+  itkSetMacro(CurrentIteration, unsigned int);
+  itkGetConstMacro(CurrentIteration, unsigned int);
 
 protected:
-
   /** The constructor. */
   AdvancedMattesMutualInformationMetric();
 
   /** The destructor. */
-  ~AdvancedMattesMutualInformationMetric() override {}
+  ~AdvancedMattesMutualInformationMetric() override = default;
 
   unsigned long m_CurrentIteration;
 
   /** A function to compute the finite difference perturbation in each iteration */
-  double Compute_c( unsigned long k ) const;
+  double
+  Compute_c(unsigned long k) const;
 
 private:
-
-  /** The private constructor. */
-  AdvancedMattesMutualInformationMetric( const Self & );  // purposely not implemented
-  /** The private copy constructor. */
-  void operator=( const Self & );                 // purposely not implemented
+  elxOverrideGetSelfMacro;
 
   double m_Param_c;
   double m_Param_gamma;
-
 };
 
 } // end namespace elastix
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "elxAdvancedMattesMutualInformationMetric.hxx"
+#  include "elxAdvancedMattesMutualInformationMetric.hxx"
 #endif
 
-#endif // end #ifndef __elxAdvancedMattesMutualInformationMetric_H__
+#endif // end #ifndef elxAdvancedMattesMutualInformationMetric_h
