@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __itkBinaryTreeBase_h
-#define __itkBinaryTreeBase_h
+#ifndef itkBinaryTreeBase_h
+#define itkBinaryTreeBase_h
 
 #include "itkDataObject.h"
 
@@ -32,69 +32,69 @@ namespace itk
  * \ingroup ANNwrap
  */
 
-template< class TListSample >
-class BinaryTreeBase : public DataObject
+template <class TListSample>
+class ITK_TEMPLATE_EXPORT BinaryTreeBase : public DataObject
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(BinaryTreeBase);
 
   /** Standard itk. */
-  typedef BinaryTreeBase             Self;
-  typedef DataObject                 Superclass;
-  typedef SmartPointer< Self >       Pointer;
-  typedef SmartPointer< const Self > ConstPointer;
+  using Self = BinaryTreeBase;
+  using Superclass = DataObject;
+  using Pointer = SmartPointer<Self>;
+  using ConstPointer = SmartPointer<const Self>;
 
   /** ITK type info. */
-  itkTypeMacro( BinaryTreeBase, DataObject );
+  itkTypeMacro(BinaryTreeBase, DataObject);
 
   /** Typedef's. */
-  typedef TListSample SampleType;
+  using SampleType = TListSample;
 
   /** Typedef's. */
-  typedef typename SampleType::MeasurementVectorType      MeasurementVectorType;
-  typedef typename SampleType::MeasurementVectorSizeType  MeasurementVectorSizeType;
-  typedef typename SampleType::TotalAbsoluteFrequencyType TotalAbsoluteFrequencyType;
+  using MeasurementVectorType = typename SampleType::MeasurementVectorType;
+  using MeasurementVectorSizeType = typename SampleType::MeasurementVectorSizeType;
+  using TotalAbsoluteFrequencyType = typename SampleType::TotalAbsoluteFrequencyType;
 
   /** Set and get the samples: the array of points. */
-  itkSetObjectMacro( Sample, SampleType );
-  itkGetConstObjectMacro( Sample, SampleType );
+  itkSetObjectMacro(Sample, SampleType);
+  itkGetConstObjectMacro(Sample, SampleType);
 
   /** Get the number of data points. */
-  TotalAbsoluteFrequencyType GetNumberOfDataPoints( void ) const;
+  TotalAbsoluteFrequencyType
+  GetNumberOfDataPoints() const;
 
   /** Get the actual number of data points. */
-  TotalAbsoluteFrequencyType GetActualNumberOfDataPoints( void ) const;
+  TotalAbsoluteFrequencyType
+  GetActualNumberOfDataPoints() const;
 
   /** Get the dimension of the input data. */
-  MeasurementVectorSizeType GetDataDimension( void ) const;
+  MeasurementVectorSizeType
+  GetDataDimension() const;
 
   /** Generate the tree. */
-  virtual void GenerateTree( void ) = 0;
+  virtual void
+  GenerateTree() = 0;
 
 protected:
-
   /** Constructor. */
   BinaryTreeBase();
 
   /** Destructor. */
-  ~BinaryTreeBase() override {}
+  ~BinaryTreeBase() override = default;
 
   /** PrintSelf. */
-  void PrintSelf( std::ostream & os, Indent indent ) const override;
+  void
+  PrintSelf(std::ostream & os, Indent indent) const override;
 
 private:
-
-  BinaryTreeBase( const Self & );   // purposely not implemented
-  void operator=( const Self & );   // purposely not implemented
-
   /** Store the samples. */
   typename SampleType::Pointer m_Sample;
-
 };
 
 } // end namespace itk
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "itkBinaryTreeBase.hxx"
+#  include "itkBinaryTreeBase.hxx"
 #endif
 
-#endif // end #ifndef __itkBinaryTreeBase_h
+#endif // end #ifndef itkBinaryTreeBase_h
