@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __elxAdaptiveStochasticGradientDescent_h
-#define __elxAdaptiveStochasticGradientDescent_h
+#ifndef elxAdaptiveStochasticGradientDescent_h
+#define elxAdaptiveStochasticGradientDescent_h
 
 #include "elxIncludes.h" // include first to avoid MSVS warning
 #include "itkAdaptiveStochasticGradientDescentOptimizer.h"
@@ -63,7 +63,7 @@ namespace elastix
  * [3] Y. Qiao, B. van Lew, B.P.F. Lelieveldt and M. Staring
  * "Fast Automatic Step Size Estimation for Gradient Descent Optimization of Image Registration,"
  * IEEE Transactions on Medical Imaging, vol. 35, no. 2, pp. 391 - 403, February 2016.
- * http://elastix.isi.uu.nl/marius/publications/2016_j_TMIa.php
+ * http://elastix.lumc.nl/marius/publications/2016_j_TMIa.php
  *
  * The parameters used in this class are:
  * \parameter Optimizer: Select this optimizer as follows:\n
@@ -189,77 +189,81 @@ namespace elastix
  * \ingroup Optimizers
  */
 
-template< class TElastix >
-class AdaptiveStochasticGradientDescent :
-  public itk::AdaptiveStochasticGradientDescentOptimizer,
-  public OptimizerBase< TElastix >
+template <class TElastix>
+class ITK_TEMPLATE_EXPORT AdaptiveStochasticGradientDescent
+  : public itk::AdaptiveStochasticGradientDescentOptimizer
+  , public OptimizerBase<TElastix>
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(AdaptiveStochasticGradientDescent);
 
   /** Standard ITK. */
-  typedef AdaptiveStochasticGradientDescent          Self;
-  typedef AdaptiveStochasticGradientDescentOptimizer Superclass1;
-  typedef OptimizerBase< TElastix >                  Superclass2;
-  typedef itk::SmartPointer< Self >                  Pointer;
-  typedef itk::SmartPointer< const Self >            ConstPointer;
+  using Self = AdaptiveStochasticGradientDescent;
+  using Superclass1 = AdaptiveStochasticGradientDescentOptimizer;
+  using Superclass2 = OptimizerBase<TElastix>;
+  using Pointer = itk::SmartPointer<Self>;
+  using ConstPointer = itk::SmartPointer<const Self>;
 
   /** Method for creation through the object factory. */
-  itkNewMacro( Self );
+  itkNewMacro(Self);
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( AdaptiveStochasticGradientDescent,
-    AdaptiveStochasticGradientDescentOptimizer );
+  itkTypeMacro(AdaptiveStochasticGradientDescent, AdaptiveStochasticGradientDescentOptimizer);
 
   /** Name of this class.
    * Use this name in the parameter file to select this specific optimizer.
    * example: <tt>(Optimizer "AdaptiveStochasticGradientDescent")</tt>\n
    */
-  elxClassNameMacro( "AdaptiveStochasticGradientDescent" );
+  elxClassNameMacro("AdaptiveStochasticGradientDescent");
 
   /** Typedef's inherited from Superclass1. */
-  typedef Superclass1::CostFunctionType    CostFunctionType;
-  typedef Superclass1::CostFunctionPointer CostFunctionPointer;
-  typedef Superclass1::StopConditionType   StopConditionType;
+  using Superclass1::CostFunctionType;
+  using Superclass1::CostFunctionPointer;
+  using Superclass1::StopConditionType;
 
   /** Typedef's inherited from Superclass2. */
-  typedef typename Superclass2::ElastixType          ElastixType;
-  typedef typename Superclass2::ElastixPointer       ElastixPointer;
-  typedef typename Superclass2::ConfigurationType    ConfigurationType;
-  typedef typename Superclass2::ConfigurationPointer ConfigurationPointer;
-  typedef typename Superclass2::RegistrationType     RegistrationType;
-  typedef typename Superclass2::RegistrationPointer  RegistrationPointer;
-  typedef typename Superclass2::ITKBaseType          ITKBaseType;
-  typedef itk::SizeValueType                         SizeValueType;
+  using typename Superclass2::ElastixType;
+  using typename Superclass2::RegistrationType;
+  using ITKBaseType = typename Superclass2::ITKBaseType;
+  using SizeValueType = itk::SizeValueType;
 
   /** Typedef for the ParametersType. */
-  typedef typename Superclass1::ParametersType ParametersType;
+  using typename Superclass1::ParametersType;
 
   /** Methods invoked by elastix, in which parameters can be set and
    * progress information can be printed.
    */
-  void BeforeRegistration( void ) override;
+  void
+  BeforeRegistration() override;
 
-  void BeforeEachResolution( void ) override;
+  void
+  BeforeEachResolution() override;
 
-  void AfterEachResolution( void ) override;
+  void
+  AfterEachResolution() override;
 
-  void AfterEachIteration( void ) override;
+  void
+  AfterEachIteration() override;
 
-  void AfterRegistration( void ) override;
+  void
+  AfterRegistration() override;
 
   /** Check if any scales are set, and set the UseScales flag on or off;
    * after that call the superclass' implementation.
    */
-  void StartOptimization( void ) override;
+  void
+  StartOptimization() override;
 
   /** If automatic gain estimation is desired, then estimate SP_a, SP_alpha
    * SigmoidScale, SigmoidMax, SigmoidMin.
    * After that call Superclass' implementation.
    */
-  void ResumeOptimization( void ) override;
+  void
+  ResumeOptimization() override;
 
   /** Stop optimization and pass on exception. */
-  void MetricErrorResponse( itk::ExceptionObject & err ) override;
+  void
+  MetricErrorResponse(itk::ExceptionObject & err) override;
 
   /** Set/Get whether automatic parameter estimation is desired.
    * If true, make sure to set the maximum step length.
@@ -270,77 +274,70 @@ public:
    * A usually suitable value for SP_A is 20, which is the
    * default setting, if not specified by the user.
    */
-  itkSetMacro( AutomaticParameterEstimation, bool );
-  itkGetConstMacro( AutomaticParameterEstimation, bool );
+  itkSetMacro(AutomaticParameterEstimation, bool);
+  itkGetConstMacro(AutomaticParameterEstimation, bool);
 
   /** Set/Get maximum step length. */
-  itkSetMacro( MaximumStepLength, double );
-  itkGetConstMacro( MaximumStepLength, double );
+  itkSetMacro(MaximumStepLength, double);
+  itkGetConstMacro(MaximumStepLength, double);
 
   /** Set the MaximumNumberOfSamplingAttempts. */
-  itkSetMacro( MaximumNumberOfSamplingAttempts, SizeValueType );
+  itkSetMacro(MaximumNumberOfSamplingAttempts, SizeValueType);
 
   /** Get the MaximumNumberOfSamplingAttempts. */
-  itkGetConstReferenceMacro( MaximumNumberOfSamplingAttempts, SizeValueType );
+  itkGetConstReferenceMacro(MaximumNumberOfSamplingAttempts, SizeValueType);
 
 protected:
-
   /** Protected typedefs */
-  typedef typename RegistrationType::FixedImageType   FixedImageType;
-  typedef typename RegistrationType::MovingImageType  MovingImageType;
+  using FixedImageType = typename RegistrationType::FixedImageType;
+  using MovingImageType = typename RegistrationType::MovingImageType;
 
-  typedef typename FixedImageType::RegionType         FixedImageRegionType;
-  typedef typename FixedImageType::IndexType          FixedImageIndexType;
-  typedef typename FixedImageType::PointType          FixedImagePointType;
-  typedef typename RegistrationType::ITKBaseType      itkRegistrationType;
-  typedef typename itkRegistrationType::TransformType TransformType;
-  typedef typename TransformType::JacobianType        JacobianType;
-  typedef itk::ComputeJacobianTerms<
-    FixedImageType, TransformType >                    ComputeJacobianTermsType;
-  typedef typename JacobianType::ValueType JacobianValueType;
-  struct SettingsType { double a, A, alpha, fmax, fmin, omega; };
-  typedef typename std::vector< SettingsType > SettingsVectorType;
+  using FixedImageRegionType = typename FixedImageType::RegionType;
+  using FixedImageIndexType = typename FixedImageType::IndexType;
+  using FixedImagePointType = typename FixedImageType::PointType;
+  using itkRegistrationType = typename RegistrationType::ITKBaseType;
+  using TransformType = typename itkRegistrationType::TransformType;
+  using JacobianType = typename TransformType::JacobianType;
+  using ComputeJacobianTermsType = itk::ComputeJacobianTerms<FixedImageType, TransformType>;
+  using JacobianValueType = typename JacobianType::ValueType;
+  struct SettingsType
+  {
+    double a, A, alpha, fmax, fmin, omega;
+  };
+  using SettingsVectorType = typename std::vector<SettingsType>;
 
-  typedef itk::ComputeDisplacementDistribution<
-    FixedImageType, TransformType >                    ComputeDisplacementDistributionType;
+  using ComputeDisplacementDistributionType = itk::ComputeDisplacementDistribution<FixedImageType, TransformType>;
 
   /** Samplers: */
-  typedef itk::ImageSamplerBase< FixedImageType >       ImageSamplerBaseType;
-  typedef typename ImageSamplerBaseType::Pointer        ImageSamplerBasePointer;
-  typedef itk::ImageRandomSamplerBase< FixedImageType > ImageRandomSamplerBaseType;
-  typedef typename
-    ImageRandomSamplerBaseType::Pointer ImageRandomSamplerBasePointer;
-  typedef
-    itk::ImageRandomCoordinateSampler< FixedImageType > ImageRandomCoordinateSamplerType;
-  typedef typename
-    ImageRandomCoordinateSamplerType::Pointer ImageRandomCoordinateSamplerPointer;
-  typedef itk::ImageGridSampler< FixedImageType > ImageGridSamplerType;
-  typedef typename ImageGridSamplerType::Pointer  ImageGridSamplerPointer;
-  typedef typename
-    ImageGridSamplerType::ImageSampleContainerType ImageSampleContainerType;
-  typedef typename ImageSampleContainerType::Pointer ImageSampleContainerPointer;
+  using ImageSamplerBaseType = itk::ImageSamplerBase<FixedImageType>;
+  using ImageSamplerBasePointer = typename ImageSamplerBaseType::Pointer;
+  using ImageRandomSamplerBaseType = itk::ImageRandomSamplerBase<FixedImageType>;
+  using ImageRandomSamplerBasePointer = typename ImageRandomSamplerBaseType::Pointer;
+  using ImageRandomCoordinateSamplerType = itk::ImageRandomCoordinateSampler<FixedImageType>;
+  using ImageRandomCoordinateSamplerPointer = typename ImageRandomCoordinateSamplerType::Pointer;
+  using ImageGridSamplerType = itk::ImageGridSampler<FixedImageType>;
+  using ImageGridSamplerPointer = typename ImageGridSamplerType::Pointer;
+  using ImageSampleContainerType = typename ImageGridSamplerType::ImageSampleContainerType;
+  using ImageSampleContainerPointer = typename ImageSampleContainerType::Pointer;
 
   /** Other protected typedefs */
-  typedef itk::Statistics::MersenneTwisterRandomVariateGenerator RandomGeneratorType;
-  typedef typename RandomGeneratorType::Pointer                  RandomGeneratorPointer;
-  typedef ProgressCommand                                        ProgressCommandType;
-  typedef typename ProgressCommand::Pointer                      ProgressCommandPointer;
+  using RandomGeneratorType = itk::Statistics::MersenneTwisterRandomVariateGenerator;
+  using RandomGeneratorPointer = typename RandomGeneratorType::Pointer;
+  using ProgressCommandType = ProgressCommand;
+  using ProgressCommandPointer = typename ProgressCommand::Pointer;
 
   /** Typedefs for support of sparse Jacobians and AdvancedTransforms. */
-  typedef JacobianType TransformJacobianType;
-  itkStaticConstMacro( FixedImageDimension, unsigned int, FixedImageType::ImageDimension );
-  itkStaticConstMacro( MovingImageDimension, unsigned int, MovingImageType::ImageDimension );
-  typedef typename TransformType::ScalarType CoordinateRepresentationType;
-  typedef itk::AdvancedTransform<
-    CoordinateRepresentationType,
-    itkGetStaticConstMacro( FixedImageDimension ),
-    itkGetStaticConstMacro( MovingImageDimension ) >    AdvancedTransformType;
-  typedef typename AdvancedTransformType::Pointer AdvancedTransformPointer;
-  typedef typename
-    AdvancedTransformType::NonZeroJacobianIndicesType NonZeroJacobianIndicesType;
+  using TransformJacobianType = JacobianType;
+  itkStaticConstMacro(FixedImageDimension, unsigned int, FixedImageType::ImageDimension);
+  itkStaticConstMacro(MovingImageDimension, unsigned int, MovingImageType::ImageDimension);
+  using CoordinateRepresentationType = typename TransformType::ScalarType;
+  using AdvancedTransformType =
+    itk::AdvancedTransform<CoordinateRepresentationType, Self::FixedImageDimension, Self::MovingImageDimension>;
+  using AdvancedTransformPointer = typename AdvancedTransformType::Pointer;
+  using NonZeroJacobianIndicesType = typename AdvancedTransformType::NonZeroJacobianIndicesType;
 
   AdaptiveStochasticGradientDescent();
-  ~AdaptiveStochasticGradientDescent() override {}
+  ~AdaptiveStochasticGradientDescent() override = default;
 
   /** Variable to store the automatically determined settings for each resolution. */
   SettingsVectorType m_SettingsVector;
@@ -358,28 +355,29 @@ protected:
 
   double m_SigmoidScaleFactor;
 
-  /** Check if the transform is an advanced transform. Called by Initialize. */
-  virtual void CheckForAdvancedTransform( void );
-
   /** Print the contents of the settings vector to elxout. */
-  virtual void PrintSettingsVector( const SettingsVectorType & settings ) const;
+  virtual void
+  PrintSettingsVector(const SettingsVectorType & settings) const;
 
   /** Select different method to estimate some reasonable values for the parameters
    * SP_a, SP_alpha (=1), SigmoidMin, SigmoidMax (=1), and
    * SigmoidScale.
    */
-  virtual void AutomaticParameterEstimation( void );
+  virtual void
+  AutomaticParameterEstimation();
 
   /** Original estimation method to get the reasonable values for the parameters
    * SP_a, SP_alpha (=1), SigmoidMin, SigmoidMax (=1), and
    * SigmoidScale.
    */
-  virtual void AutomaticParameterEstimationOriginal( void );
+  virtual void
+  AutomaticParameterEstimationOriginal();
 
   /** Estimates some reasonable values for the parameters using displacement distribution
    * SP_a, SP_alpha (=1)
    */
-  virtual void AutomaticParameterEstimationUsingDisplacementDistribution( void );
+  virtual void
+  AutomaticParameterEstimationUsingDisplacementDistribution();
 
   /** Measure some derivatives, exact and approximated. Returns
    * the squared magnitude of the gradient and approximation error.
@@ -388,24 +386,23 @@ protected:
    * mu_n - mu_0 ~ N(0, perturbationSigma^2 I );
    * gg = g^T g, etc.
    */
-  virtual void SampleGradients( const ParametersType & mu0,
-    double perturbationSigma, double & gg, double & ee );
+  virtual void
+  SampleGradients(const ParametersType & mu0, double perturbationSigma, double & gg, double & ee);
 
   /** Helper function, which calls GetScaledValueAndDerivative and does
    * some exception handling. Used by SampleGradients.
    */
-  virtual void GetScaledDerivativeWithExceptionHandling(
-    const ParametersType & parameters, DerivativeType & derivative );
+  virtual void
+  GetScaledDerivativeWithExceptionHandling(const ParametersType & parameters, DerivativeType & derivative);
 
   /** Helper function that adds a random perturbation delta to the input
    * parameters, with delta ~ sigma * N(0,I). Used by SampleGradients.
    */
-  virtual void AddRandomPerturbation( ParametersType & parameters, double sigma );
+  virtual void
+  AddRandomPerturbation(ParametersType & parameters, double sigma);
 
 private:
-
-  AdaptiveStochasticGradientDescent( const Self & );  // purposely not implemented
-  void operator=( const Self & );                     // purposely not implemented
+  elxOverrideGetSelfMacro;
 
   bool   m_AutomaticParameterEstimation;
   double m_MaximumStepLength;
@@ -424,13 +421,12 @@ private:
   /** The flag of using noise compensation. */
   bool m_UseNoiseCompensation;
   bool m_OriginalButSigmoidToDefault;
-
 };
 
 } // end namespace elastix
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "elxAdaptiveStochasticGradientDescent.hxx"
+#  include "elxAdaptiveStochasticGradientDescent.hxx"
 #endif
 
-#endif // end #ifndef __elxAdaptiveStochasticGradientDescent_h
+#endif // end #ifndef elxAdaptiveStochasticGradientDescent_h
