@@ -16,8 +16,8 @@
  *
  *=========================================================================*/
 
-#ifndef __itkAdaptiveStochasticGradientDescentOptimizer_h
-#define __itkAdaptiveStochasticGradientDescentOptimizer_h
+#ifndef itkAdaptiveStochasticGradientDescentOptimizer_h
+#define itkAdaptiveStochasticGradientDescentOptimizer_h
 
 #include "../StandardGradientDescent/itkStandardGradientDescentOptimizer.h"
 
@@ -69,84 +69,78 @@ namespace itk
 * \ingroup Optimizers
 */
 
-class AdaptiveStochasticGradientDescentOptimizer :
-  public StandardGradientDescentOptimizer
+class AdaptiveStochasticGradientDescentOptimizer : public StandardGradientDescentOptimizer
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(AdaptiveStochasticGradientDescentOptimizer);
 
   /** Standard ITK.*/
-  typedef AdaptiveStochasticGradientDescentOptimizer Self;
-  typedef StandardGradientDescentOptimizer           Superclass;
+  using Self = AdaptiveStochasticGradientDescentOptimizer;
+  using Superclass = StandardGradientDescentOptimizer;
 
-  typedef SmartPointer< Self >       Pointer;
-  typedef SmartPointer< const Self > ConstPointer;
+  using Pointer = SmartPointer<Self>;
+  using ConstPointer = SmartPointer<const Self>;
 
   /** Method for creation through the object factory. */
-  itkNewMacro( Self );
+  itkNewMacro(Self);
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( AdaptiveStochasticGradientDescentOptimizer,
-    StandardGradientDescentOptimizer );
+  itkTypeMacro(AdaptiveStochasticGradientDescentOptimizer, StandardGradientDescentOptimizer);
 
   /** Typedefs inherited from the superclass. */
-  typedef Superclass::MeasureType               MeasureType;
-  typedef Superclass::ParametersType            ParametersType;
-  typedef Superclass::DerivativeType            DerivativeType;
-  typedef Superclass::CostFunctionType          CostFunctionType;
-  typedef Superclass::ScalesType                ScalesType;
-  typedef Superclass::ScaledCostFunctionType    ScaledCostFunctionType;
-  typedef Superclass::ScaledCostFunctionPointer ScaledCostFunctionPointer;
-  typedef Superclass::StopConditionType         StopConditionType;
+  using Superclass::MeasureType;
+  using Superclass::ParametersType;
+  using Superclass::DerivativeType;
+  using Superclass::CostFunctionType;
+  using Superclass::ScalesType;
+  using Superclass::ScaledCostFunctionType;
+  using Superclass::ScaledCostFunctionPointer;
+  using Superclass::StopConditionType;
 
   /** Set/Get whether the adaptive step size mechanism is desired. Default: true */
-  itkSetMacro( UseAdaptiveStepSizes, bool );
-  itkGetConstMacro( UseAdaptiveStepSizes, bool );
+  itkSetMacro(UseAdaptiveStepSizes, bool);
+  itkGetConstMacro(UseAdaptiveStepSizes, bool);
 
   /** Set/Get the maximum of the sigmoid.
-  * Should be >0. Default: 1.0 */
-  itkSetMacro( SigmoidMax, double );
-  itkGetConstMacro( SigmoidMax, double );
+   * Should be >0. Default: 1.0 */
+  itkSetMacro(SigmoidMax, double);
+  itkGetConstMacro(SigmoidMax, double);
 
   /** Set/Get the maximum of the sigmoid.
-  * Should be <0. Default: -0.8 */
-  itkSetMacro( SigmoidMin, double );
-  itkGetConstMacro( SigmoidMin, double );
+   * Should be <0. Default: -0.8 */
+  itkSetMacro(SigmoidMin, double);
+  itkGetConstMacro(SigmoidMin, double);
 
   /** Set/Get the scaling of the sigmoid width. Large values
-  * cause a more wide sigmoid. Default: 1e-8. Should be >0. */
-  itkSetMacro( SigmoidScale, double );
-  itkGetConstMacro( SigmoidScale, double );
+   * cause a more wide sigmoid. Default: 1e-8. Should be >0. */
+  itkSetMacro(SigmoidScale, double);
+  itkGetConstMacro(SigmoidScale, double);
 
 protected:
-
   AdaptiveStochasticGradientDescentOptimizer();
-  ~AdaptiveStochasticGradientDescentOptimizer() override {}
+  ~AdaptiveStochasticGradientDescentOptimizer() override = default;
 
   /** Function to update the current time
-  * If UseAdaptiveStepSizes is false this function just increments
-  * the CurrentTime by \f$E_0 = (sigmoid_{max} + sigmoid_{min})/2\f$.
-  * Else, the CurrentTime is updated according to:\n
-  * time = max[ 0, time + sigmoid( -gradient*previousgradient) ]\n
-  * In that case, also the m_PreviousGradient is updated.
-  */
-  void UpdateCurrentTime( void ) override;
+   * If UseAdaptiveStepSizes is false this function just increments
+   * the CurrentTime by \f$E_0 = (sigmoid_{max} + sigmoid_{min})/2\f$.
+   * Else, the CurrentTime is updated according to:\n
+   * time = max[ 0, time + sigmoid( -gradient*previousgradient) ]\n
+   * In that case, also the m_PreviousGradient is updated.
+   */
+  void
+  UpdateCurrentTime() override;
 
   /** The PreviousGradient, necessary for the CruzAcceleration */
   DerivativeType m_PreviousGradient;
 
 private:
-
-  AdaptiveStochasticGradientDescentOptimizer( const Self & ); // purposely not implemented
-  void operator=( const Self & );                             // purposely not implemented
-
   /** Settings */
-  bool   m_UseAdaptiveStepSizes;
-  double m_SigmoidMax;
-  double m_SigmoidMin;
-  double m_SigmoidScale;
-
+  bool   m_UseAdaptiveStepSizes{ true };
+  double m_SigmoidMax{ 1.0 };
+  double m_SigmoidMin{ -0.8 };
+  double m_SigmoidScale{ 1e-8 };
 };
 
 } // end namespace itk
 
-#endif // end #ifndef __itkAdaptiveStochasticGradientDescentOptimizer_h
+#endif // end #ifndef itkAdaptiveStochasticGradientDescentOptimizer_h
