@@ -16,8 +16,8 @@
  *
  *=========================================================================*/
 
-#ifndef __itkFullSearchOptimizer_h
-#define __itkFullSearchOptimizer_h
+#ifndef itkFullSearchOptimizer_h
+#define itkFullSearchOptimizer_h
 
 #include "itkSingleValuedNonLinearOptimizer.h"
 #include "itkMapContainer.h"
@@ -46,63 +46,77 @@ namespace itk
 class FullSearchOptimizer : public SingleValuedNonLinearOptimizer
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(FullSearchOptimizer);
 
   /** Standard class typedefs. */
-  typedef FullSearchOptimizer            Self;
-  typedef SingleValuedNonLinearOptimizer Superclass;
-  typedef SmartPointer< Self >           Pointer;
-  typedef SmartPointer< const Self >     ConstPointer;
+  using Self = FullSearchOptimizer;
+  using Superclass = SingleValuedNonLinearOptimizer;
+  using Pointer = SmartPointer<Self>;
+  using ConstPointer = SmartPointer<const Self>;
 
   /** Method for creation through the object factory. */
-  itkNewMacro( Self );
+  itkNewMacro(Self);
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( FullSearchOptimizer, SingleValuedNonLinearOptimizer );
+  itkTypeMacro(FullSearchOptimizer, SingleValuedNonLinearOptimizer);
 
   /** Codes of stopping conditions */
-  typedef enum {
+  enum StopConditionType
+  {
     FullRangeSearched,
     MetricError
-  } StopConditionType;
+  };
 
   /* Typedefs inherited from superclass */
-  typedef Superclass::ParametersType      ParametersType;
-  typedef Superclass::CostFunctionType    CostFunctionType;
-  typedef Superclass::CostFunctionPointer CostFunctionPointer;
-  typedef Superclass::MeasureType         MeasureType;
+  using Superclass::ParametersType;
+  using Superclass::CostFunctionType;
+  using Superclass::CostFunctionPointer;
+  using Superclass::MeasureType;
 
-  typedef ParametersType::ValueType               ParameterValueType;     // = double
-  typedef ParameterValueType                      RangeValueType;
-  typedef FixedArray< RangeValueType, 3 >         RangeType;
-  typedef MapContainer< unsigned int, RangeType > SearchSpaceType;
-  typedef SearchSpaceType::Pointer                SearchSpacePointer;
-  typedef SearchSpaceType::ConstIterator          SearchSpaceIteratorType;
+  using ParameterValueType = ParametersType::ValueType; // = double
+  using RangeValueType = ParameterValueType;
+  using RangeType = FixedArray<RangeValueType, 3>;
+  using SearchSpaceType = MapContainer<unsigned int, RangeType>;
+  using SearchSpacePointer = SearchSpaceType::Pointer;
+  using SearchSpaceIteratorType = SearchSpaceType::ConstIterator;
 
   /** Type that stores the parameter values of the parameters to be optimized.
-  * Updated every iteration. */
-  typedef Array< ParameterValueType > SearchSpacePointType;
+   * Updated every iteration. */
+  using SearchSpacePointType = Array<ParameterValueType>;
 
   /** The same values, but transformed to integer indices.
-  * These can be used to create an image visualizing the search space. */
-  typedef Array< IndexValueType > SearchSpaceIndexType;
+   * These can be used to create an image visualizing the search space. */
+  using SearchSpaceIndexType = Array<IndexValueType>;
 
   /** The size of each dimension to be searched ((max-min)/step)) */
-  typedef Array< SizeValueType > SearchSpaceSizeType;
+  using SearchSpaceSizeType = Array<SizeValueType>;
 
   /** NB: The methods SetScales has no influence! */
 
   /** Methods to configure the cost function. */
-  itkGetConstMacro( Maximize, bool );
-  itkSetMacro( Maximize, bool );
-  itkBooleanMacro( Maximize );
-  bool GetMinimize() const
-  { return !m_Maximize; }
-  void SetMinimize( bool v )
-  { this->SetMaximize( !v ); }
-  void MinimizeOn()
-  { this->MaximizeOff(); }
-  void MinimizeOff()
-  { this->MaximizeOn(); }
+  itkGetConstMacro(Maximize, bool);
+  itkSetMacro(Maximize, bool);
+  itkBooleanMacro(Maximize);
+  bool
+  GetMinimize() const
+  {
+    return !m_Maximize;
+  }
+  void
+  SetMinimize(bool v)
+  {
+    this->SetMaximize(!v);
+  }
+  void
+  MinimizeOn()
+  {
+    this->MaximizeOff();
+  }
+  void
+  MinimizeOff()
+  {
+    this->MaximizeOn();
+  }
 
   /** Set the CurrentPosition, CurrentPoint and CurrentIndex to the next point
    * in the search space.
@@ -118,22 +132,26 @@ public:
    *
    * Then the appropriate parameters in the ParameterArray are updated.
    */
-  virtual void UpdateCurrentPosition( void );
+  virtual void
+  UpdateCurrentPosition();
 
   /** Start optimization.
    * Make sure to set the initial position before starting the optimization
    */
-  void StartOptimization( void ) override;
+  void
+  StartOptimization() override;
 
   /** Resume previously stopped optimization with current parameters
    * \sa StopOptimization.
    */
-  virtual void ResumeOptimization( void );
+  virtual void
+  ResumeOptimization();
 
   /** Stop optimization.
    * \sa ResumeOptimization
    */
-  virtual void StopOptimization( void );
+  virtual void
+  StopOptimization();
 
   /**
    * Set/Get the SearchSpace, which is defined by a pointer to an
@@ -145,83 +163,85 @@ public:
    * Instead of using this function, the Add/RemoveSearchDimension methods can be used,
    * to define a search space.
    */
-  itkSetObjectMacro( SearchSpace, SearchSpaceType );
-  itkGetModifiableObjectMacro( SearchSpace, SearchSpaceType );
+  itkSetObjectMacro(SearchSpace, SearchSpaceType);
+  itkGetModifiableObjectMacro(SearchSpace, SearchSpaceType);
 
   /** Add/Remove a dimension to/from the SearchSpace */
-  virtual void AddSearchDimension( unsigned int param_nr,
-    RangeValueType minimum, RangeValueType maximum, RangeValueType step );
+  virtual void
+  AddSearchDimension(unsigned int param_nr, RangeValueType minimum, RangeValueType maximum, RangeValueType step);
 
-  virtual void RemoveSearchDimension( unsigned int param_nr );
+  virtual void
+  RemoveSearchDimension(unsigned int param_nr);
 
   /** Get the total number of iterations = sizes[0]*sizes[1]*sizes[2]* etc..... */
-  virtual unsigned long GetNumberOfIterations( void );
+  virtual unsigned long
+  GetNumberOfIterations();
 
   /** Get the Dimension of the SearchSpace. Calculated from the SearchSpace. */
-  virtual unsigned int GetNumberOfSearchSpaceDimensions( void );
+  virtual unsigned int
+  GetNumberOfSearchSpaceDimensions();
 
   /** Returns an array containing trunc((max-min)/step) for each SearchSpaceDimension) */
-  virtual const SearchSpaceSizeType & GetSearchSpaceSize( void );
+  virtual const SearchSpaceSizeType &
+  GetSearchSpaceSize();
 
   /** Convert an index to a full parameter array. Requires a valid InitialPosition! */
-  virtual ParametersType PointToPosition( const SearchSpacePointType & point );
+  virtual ParametersType
+  PointToPosition(const SearchSpacePointType & point);
 
-  virtual ParametersType IndexToPosition( const SearchSpaceIndexType & index );
+  virtual ParametersType
+  IndexToPosition(const SearchSpaceIndexType & index);
 
   /** Convert an index to a point */
-  virtual SearchSpacePointType IndexToPoint( const SearchSpaceIndexType & index );
+  virtual SearchSpacePointType
+  IndexToPoint(const SearchSpaceIndexType & index);
 
   /** Get the current iteration number. */
-  itkGetConstMacro( CurrentIteration, unsigned long );
+  itkGetConstMacro(CurrentIteration, unsigned long);
 
   /** Get the point in SearchSpace that is currently evaluated */
-  itkGetConstReferenceMacro( CurrentPointInSearchSpace, SearchSpacePointType );
-  itkGetConstReferenceMacro( CurrentIndexInSearchSpace, SearchSpaceIndexType );
+  itkGetConstReferenceMacro(CurrentPointInSearchSpace, SearchSpacePointType);
+  itkGetConstReferenceMacro(CurrentIndexInSearchSpace, SearchSpaceIndexType);
 
   /** Get the point in SearchSpace that is currently the most optimal */
-  itkGetConstReferenceMacro( BestPointInSearchSpace, SearchSpacePointType );
-  itkGetConstReferenceMacro( BestIndexInSearchSpace, SearchSpaceIndexType );
+  itkGetConstReferenceMacro(BestPointInSearchSpace, SearchSpacePointType);
+  itkGetConstReferenceMacro(BestIndexInSearchSpace, SearchSpaceIndexType);
 
   /** Get the current value. */
-  itkGetConstMacro( Value, double );
+  itkGetConstMacro(Value, double);
 
   /** Get the best value. */
-  itkGetConstMacro( BestValue, double );
+  itkGetConstMacro(BestValue, double);
 
   /** Get Stop condition. */
-  itkGetConstMacro( StopCondition, StopConditionType );
+  itkGetConstMacro(StopCondition, StopConditionType);
 
 protected:
-
   FullSearchOptimizer();
-  ~FullSearchOptimizer() override {}
+  ~FullSearchOptimizer() override = default;
 
-  //void PrintSelf(std::ostream& os, Indent indent) const;
+  // void PrintSelf(std::ostream& os, Indent indent) const;
 
-  bool              m_Maximize;
-  bool              m_Stop;
-  double            m_Value;
-  double            m_BestValue;
-  StopConditionType m_StopCondition;
+  bool              m_Maximize{ false };
+  bool              m_Stop{ false };
+  double            m_Value{ 0.0 };
+  double            m_BestValue{ 0.0 };
+  StopConditionType m_StopCondition{ FullRangeSearched };
 
-  SearchSpacePointer   m_SearchSpace;
+  SearchSpacePointer   m_SearchSpace{ nullptr };
   SearchSpacePointType m_CurrentPointInSearchSpace;
   SearchSpaceIndexType m_CurrentIndexInSearchSpace;
   SearchSpacePointType m_BestPointInSearchSpace;
   SearchSpaceIndexType m_BestIndexInSearchSpace;
   SearchSpaceSizeType  m_SearchSpaceSize;
-  unsigned int         m_NumberOfSearchSpaceDimensions;
+  unsigned int         m_NumberOfSearchSpaceDimensions{ 0 };
 
-  unsigned long m_LastSearchSpaceChanges;
-  virtual void ProcessSearchSpaceChanges( void );
+  unsigned long m_LastSearchSpaceChanges{ 0 };
+  virtual void
+  ProcessSearchSpaceChanges();
 
 private:
-
-  FullSearchOptimizer( const Self & ); // purposely not implemented
-  void operator=( const Self & );      // purposely not implemented
-
-  unsigned long m_CurrentIteration;
-
+  unsigned long m_CurrentIteration{ 0 };
 };
 
 } // end namespace itk
