@@ -16,8 +16,8 @@
  *
  *=========================================================================*/
 
-#ifndef __itkQuasiNewtonLBFGSOptimizer_h
-#define __itkQuasiNewtonLBFGSOptimizer_h
+#ifndef itkQuasiNewtonLBFGSOptimizer_h
+#define itkQuasiNewtonLBFGSOptimizer_h
 
 #include "itkScaledSingleValuedNonLinearOptimizer.h"
 #include "itkLineSearchOptimizer.h"
@@ -58,31 +58,33 @@ namespace itk
 class QuasiNewtonLBFGSOptimizer : public ScaledSingleValuedNonLinearOptimizer
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(QuasiNewtonLBFGSOptimizer);
 
-  typedef QuasiNewtonLBFGSOptimizer            Self;
-  typedef ScaledSingleValuedNonLinearOptimizer Superclass;
-  typedef SmartPointer< Self >                 Pointer;
-  typedef SmartPointer< const Self >           ConstPointer;
+  using Self = QuasiNewtonLBFGSOptimizer;
+  using Superclass = ScaledSingleValuedNonLinearOptimizer;
+  using Pointer = SmartPointer<Self>;
+  using ConstPointer = SmartPointer<const Self>;
 
-  itkNewMacro( Self );
-  itkTypeMacro( QuasiNewtonLBFGSOptimizer, ScaledSingleValuedNonLinearOptimizer );
+  itkNewMacro(Self);
+  itkTypeMacro(QuasiNewtonLBFGSOptimizer, ScaledSingleValuedNonLinearOptimizer);
 
-  typedef Superclass::ParametersType         ParametersType;
-  typedef Superclass::DerivativeType         DerivativeType;
-  typedef Superclass::CostFunctionType       CostFunctionType;
-  typedef Superclass::ScaledCostFunctionType ScaledCostFunctionType;
-  typedef Superclass::MeasureType            MeasureType;
-  typedef Superclass::ScalesType             ScalesType;
+  using Superclass::ParametersType;
+  using Superclass::DerivativeType;
+  using Superclass::CostFunctionType;
+  using Superclass::ScaledCostFunctionType;
+  using Superclass::MeasureType;
+  using Superclass::ScalesType;
 
-  typedef Array< double >               RhoType;
-  typedef std::vector< ParametersType > SType;
-  typedef std::vector< DerivativeType > YType;
-  typedef Array< double >               DiagonalMatrixType;
-  typedef LineSearchOptimizer           LineSearchOptimizerType;
+  using RhoType = Array<double>;
+  using SType = std::vector<ParametersType>;
+  using YType = std::vector<DerivativeType>;
+  using DiagonalMatrixType = Array<double>;
+  using LineSearchOptimizerType = LineSearchOptimizer;
 
-  typedef LineSearchOptimizerType::Pointer LineSearchOptimizerPointer;
+  using LineSearchOptimizerPointer = LineSearchOptimizerType::Pointer;
 
-  typedef enum {
+  enum StopConditionType
+  {
     MetricError,
     LineSearchError,
     MaximumNumberOfIterations,
@@ -90,78 +92,82 @@ public:
     GradientMagnitudeTolerance,
     ZeroStep,
     Unknown
-  }                                   StopConditionType;
+  };
 
-  void StartOptimization( void ) override;
+  void
+  StartOptimization() override;
 
-  virtual void ResumeOptimization( void );
+  virtual void
+  ResumeOptimization();
 
-  virtual void StopOptimization( void );
+  virtual void
+  StopOptimization();
 
   /** Get information about optimization process: */
-  itkGetConstMacro( CurrentIteration, unsigned long );
-  itkGetConstMacro( CurrentValue, MeasureType );
-  itkGetConstReferenceMacro( CurrentGradient, DerivativeType );
-  itkGetConstMacro( InLineSearch, bool );
-  itkGetConstReferenceMacro( StopCondition, StopConditionType );
-  itkGetConstMacro( CurrentStepLength, double );
+  itkGetConstMacro(CurrentIteration, unsigned long);
+  itkGetConstMacro(CurrentValue, MeasureType);
+  itkGetConstReferenceMacro(CurrentGradient, DerivativeType);
+  itkGetConstMacro(InLineSearch, bool);
+  itkGetConstReferenceMacro(StopCondition, StopConditionType);
+  itkGetConstMacro(CurrentStepLength, double);
 
   /** Setting: the line search optimizer */
-  itkSetObjectMacro( LineSearchOptimizer, LineSearchOptimizerType );
-  itkGetModifiableObjectMacro( LineSearchOptimizer, LineSearchOptimizerType );
+  itkSetObjectMacro(LineSearchOptimizer, LineSearchOptimizerType);
+  itkGetModifiableObjectMacro(LineSearchOptimizer, LineSearchOptimizerType);
 
   /** Setting: the maximum number of iterations */
-  itkGetConstMacro( MaximumNumberOfIterations, unsigned long );
-  itkSetClampMacro( MaximumNumberOfIterations, unsigned long,
-    1, NumericTraits< unsigned long >::max() );
+  itkGetConstMacro(MaximumNumberOfIterations, unsigned long);
+  itkSetClampMacro(MaximumNumberOfIterations, unsigned long, 1, NumericTraits<unsigned long>::max());
 
   /** Setting: the mininum gradient magnitude.
    *
    * The optimizer stops when:
    * ||CurrentGradient|| < GradientMagnitudeTolerance * max(1, ||CurrentPosition||)
    */
-  itkGetConstMacro( GradientMagnitudeTolerance, double );
-  itkSetMacro( GradientMagnitudeTolerance, double );
+  itkGetConstMacro(GradientMagnitudeTolerance, double);
+  itkSetMacro(GradientMagnitudeTolerance, double);
 
   /** Setting: the memory. The number of iterations that are used
    * to estimate the Hessian. 5 by default. 0 results in (normalised) gradient
    * descent search directions */
-  itkSetMacro( Memory, unsigned int );
-  itkGetConstMacro( Memory, unsigned int );
+  itkSetMacro(Memory, unsigned int);
+  itkGetConstMacro(Memory, unsigned int);
 
 protected:
-
   QuasiNewtonLBFGSOptimizer();
-  ~QuasiNewtonLBFGSOptimizer() override{}
+  ~QuasiNewtonLBFGSOptimizer() override = default;
 
   // \todo: should be implemented
-  void PrintSelf( std::ostream & os, Indent indent ) const override {}
+  void
+  PrintSelf(std::ostream & os, Indent indent) const override
+  {}
 
   DerivativeType    m_CurrentGradient;
-  MeasureType       m_CurrentValue;
-  unsigned long     m_CurrentIteration;
-  StopConditionType m_StopCondition;
-  bool              m_Stop;
-  double            m_CurrentStepLength;
+  MeasureType       m_CurrentValue{ 0.0 };
+  unsigned long     m_CurrentIteration{ 0 };
+  StopConditionType m_StopCondition{ Unknown };
+  bool              m_Stop{ false };
+  double            m_CurrentStepLength{ 0.0 };
 
   /** Is true when the LineSearchOptimizer has been started. */
-  bool m_InLineSearch;
+  bool m_InLineSearch{ false };
 
   RhoType m_Rho;
   SType   m_S;
   YType   m_Y;
 
-  unsigned int m_Point;
-  unsigned int m_PreviousPoint;
-  unsigned int m_Bound;
+  unsigned int m_Point{ 0 };
+  unsigned int m_PreviousPoint{ 0 };
+  unsigned int m_Bound{ 0 };
 
-  itkSetMacro( InLineSearch, bool );
+  itkSetMacro(InLineSearch, bool);
 
   /** Compute H0
    *
    * Override this method if not satisfied with the default choice.
    */
-  virtual void ComputeDiagonalMatrix( DiagonalMatrixType & diag_H0 );
+  virtual void
+  ComputeDiagonalMatrix(DiagonalMatrixType & diag_H0);
 
   /** Compute -Hg
    *
@@ -169,43 +175,33 @@ protected:
    *     "Updating quasi-Newton matrices with limited storage",
    *     Mathematics of Computation, Vol.24, No.151, pp. 773-782.
    */
-  virtual void ComputeSearchDirection(
-    const DerivativeType & gradient,
-    ParametersType & searchDir );
+  virtual void
+  ComputeSearchDirection(const DerivativeType & gradient, ParametersType & searchDir);
 
   /** Perform a line search along the search direction. On calling, x, f, and g should
    * contain the current position, the cost function value at this position, and
    * the derivative. On return the step, x (new position), f (value at x), and g
    * (derivative at x) are updated. */
-  virtual void LineSearch(
-    const ParametersType searchDir,
-    double & step,
-    ParametersType & x,
-    MeasureType & f,
-    DerivativeType & g );
+  virtual void
+  LineSearch(const ParametersType searchDir, double & step, ParametersType & x, MeasureType & f, DerivativeType & g);
 
   /** Store s = x_k - x_k-1 and y = g_k - g_k-1 in m_S and m_Y,
    * and store 1/(ys) in m_Rho. */
-  virtual void StoreCurrentPoint(
-    const ParametersType & step,
-    const DerivativeType & grad_dif );
+  virtual void
+  StoreCurrentPoint(const ParametersType & step, const DerivativeType & grad_dif);
 
-  /** Check if convergence has occured;
+  /** Check if convergence has occurred;
    * The firstLineSearchDone bool allows the implementation of TestConvergence to
    * decide to skip a few convergence checks when no line search has performed yet
    * (so, before the actual optimisation begins)  */
-  virtual bool TestConvergence( bool firstLineSearchDone );
+  virtual bool
+  TestConvergence(bool firstLineSearchDone);
 
 private:
-
-  QuasiNewtonLBFGSOptimizer( const Self & ); // purposely not implemented
-  void operator=( const Self & );            // purposely not implemented
-
-  unsigned long              m_MaximumNumberOfIterations;
-  double                     m_GradientMagnitudeTolerance;
-  LineSearchOptimizerPointer m_LineSearchOptimizer;
-  unsigned int               m_Memory;
-
+  unsigned long              m_MaximumNumberOfIterations{ 100 };
+  double                     m_GradientMagnitudeTolerance{ 1e-5 };
+  LineSearchOptimizerPointer m_LineSearchOptimizer{ nullptr };
+  unsigned int               m_Memory{ 5 };
 };
 
 } // end namespace itk
@@ -420,4 +416,4 @@ private:
 
 /*    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -*/
 
-#endif //#ifndef __itkQuasiNewtonLBFGSOptimizer_h
+#endif //#ifndef itkQuasiNewtonLBFGSOptimizer_h
