@@ -16,8 +16,8 @@
  *
  *=========================================================================*/
 
-#ifndef __itkRSGDEachParameterApartOptimizer_h
-#define __itkRSGDEachParameterApartOptimizer_h
+#ifndef itkRSGDEachParameterApartOptimizer_h
+#define itkRSGDEachParameterApartOptimizer_h
 
 #include "itkRSGDEachParameterApartBaseOptimizer.h"
 
@@ -50,49 +50,40 @@ namespace itk
  * \sa RSGDEachParameterApart
  */
 
-class RSGDEachParameterApartOptimizer :
-  public RSGDEachParameterApartBaseOptimizer
+class RSGDEachParameterApartOptimizer : public RSGDEachParameterApartBaseOptimizer
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(RSGDEachParameterApartOptimizer);
 
   /** Standard class typedefs. */
-  typedef RSGDEachParameterApartOptimizer     Self;
-  typedef RSGDEachParameterApartBaseOptimizer Superclass;
-  typedef SmartPointer< Self >                Pointer;
-  typedef SmartPointer< const Self >          ConstPointer;
+  using Self = RSGDEachParameterApartOptimizer;
+  using Superclass = RSGDEachParameterApartBaseOptimizer;
+  using Pointer = SmartPointer<Self>;
+  using ConstPointer = SmartPointer<const Self>;
 
   /** Method for creation through the object factory. */
-  itkNewMacro( Self );
+  itkNewMacro(Self);
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( RSGDEachParameterApartOptimizer,
-    RSGDEachParameterApartBaseOptimizer );
+  itkTypeMacro(RSGDEachParameterApartOptimizer, RSGDEachParameterApartBaseOptimizer);
 
   /** Cost function typedefs. */
-  typedef Superclass::CostFunctionType CostFunctionType;
-  typedef CostFunctionType::Pointer    CostFunctionPointer;
+  using Superclass::CostFunctionType;
+  using CostFunctionPointer = CostFunctionType::Pointer;
 
 protected:
-
-  RSGDEachParameterApartOptimizer() {}
-  ~RSGDEachParameterApartOptimizer() override {}
+  RSGDEachParameterApartOptimizer() = default;
+  ~RSGDEachParameterApartOptimizer() override = default;
 
   /** Advance one step along the corrected gradient taking into
-  * account the steplengths represented by the factor array.
-  * This method is invoked by AdvanceOneStep. It is expected
-  * to be overrided by optimization methods in non-vector spaces
-  * \sa AdvanceOneStep */
-  void StepAlongGradient(
-    const DerivativeType & factor,
-    const DerivativeType & transformedGradient ) override;
-
-private:
-
-  RSGDEachParameterApartOptimizer( const Self & );  // purposely not implemented
-  void operator=( const Self & );                   // purposely not implemented
-
+   * account the steplengths represented by the factor array.
+   * This method is invoked by AdvanceOneStep. It is expected
+   * to be overrided by optimization methods in non-vector spaces
+   * \sa AdvanceOneStep */
+  void
+  StepAlongGradient(const DerivativeType & factor, const DerivativeType & transformedGradient) override;
 };
 
 } // end namespace itk
 
-#endif // end #ifndef __itkRSGDEachParameterApartOptimizer_h
+#endif // end #ifndef itkRSGDEachParameterApartOptimizer_h
