@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __elxMultiMetricMultiResolutionRegistration_H__
-#define __elxMultiMetricMultiResolutionRegistration_H__
+#ifndef elxMultiMetricMultiResolutionRegistration_h
+#define elxMultiMetricMultiResolutionRegistration_h
 
 #include "elxIncludes.h" // include first to avoid MSVS warning
 #include "itkMultiMetricMultiResolutionImageRegistrationMethod.h"
@@ -53,8 +53,7 @@ namespace elastix
  * \li 1 fixed image pyramid is used.
  * This will save a bit of memory and computation time.
  * In general however, it is better to use the same number of samplers as
- * metrics. Note that some metrics (ViolaWellsMutualInformation for example)
- * do not support the image sampler functionality (yet).
+ * metrics.
  *
  * The parameters used in this class are:\n
  * \parameter Registration: Select this registration framework as follows:\n
@@ -92,101 +91,94 @@ namespace elastix
  * \ingroup Registrations
  */
 
-template< class TElastix >
-class MultiMetricMultiResolutionRegistration :
-  public
-  itk::MultiMetricMultiResolutionImageRegistrationMethod<
-  typename RegistrationBase< TElastix >::FixedImageType,
-  typename RegistrationBase< TElastix >::MovingImageType >,
-  public RegistrationBase< TElastix >
+template <class TElastix>
+class ITK_TEMPLATE_EXPORT MultiMetricMultiResolutionRegistration
+  : public itk::MultiMetricMultiResolutionImageRegistrationMethod<typename RegistrationBase<TElastix>::FixedImageType,
+                                                                  typename RegistrationBase<TElastix>::MovingImageType>
+  , public RegistrationBase<TElastix>
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(MultiMetricMultiResolutionRegistration);
 
   /** Standard ITK: Self */
-  typedef MultiMetricMultiResolutionRegistration Self;
+  using Self = MultiMetricMultiResolutionRegistration;
 
   /** Standard ITK: Superclasses. */
-  typedef itk::MultiMetricMultiResolutionImageRegistrationMethod<
-    typename RegistrationBase< TElastix >::FixedImageType,
-    typename RegistrationBase< TElastix >::MovingImageType >
-    Superclass1;
-  typedef RegistrationBase< TElastix > Superclass2;
+  using Superclass1 =
+    itk::MultiMetricMultiResolutionImageRegistrationMethod<typename RegistrationBase<TElastix>::FixedImageType,
+                                                           typename RegistrationBase<TElastix>::MovingImageType>;
+  using Superclass2 = RegistrationBase<TElastix>;
 
   /** Standard ITK: SmartPointers */
-  typedef itk::SmartPointer< Self >       Pointer;
-  typedef itk::SmartPointer< const Self > ConstPointer;
+  using Pointer = itk::SmartPointer<Self>;
+  using ConstPointer = itk::SmartPointer<const Self>;
 
   /** Method for creation through the object factory. */
-  itkNewMacro( Self );
+  itkNewMacro(Self);
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( MultiMetricMultiResolutionRegistration,
-    MultiMetricMultiResolutionImageRegistrationMethod );
+  itkTypeMacro(MultiMetricMultiResolutionRegistration, MultiMetricMultiResolutionImageRegistrationMethod);
 
   /** Name of this class.
    * Use this name in the parameter file to select this specific registration framework. \n
    * example: <tt>(Registration "MultiMetricMultiResolutionRegistration")</tt>\n
    */
-  elxClassNameMacro( "MultiMetricMultiResolutionRegistration" );
+  elxClassNameMacro("MultiMetricMultiResolutionRegistration");
 
   /** Typedef's inherited from Superclass1. */
 
   /**  Type of the Fixed image. */
-  typedef typename Superclass1::FixedImageType         FixedImageType;
-  typedef typename Superclass1::FixedImageConstPointer FixedImageConstPointer;
-  typedef typename Superclass1::FixedImageRegionType   FixedImageRegionType;
+  using typename Superclass1::FixedImageType;
+  using typename Superclass1::FixedImageConstPointer;
+  using typename Superclass1::FixedImageRegionType;
 
   /**  Type of the Moving image. */
-  typedef typename Superclass1::MovingImageType         MovingImageType;
-  typedef typename Superclass1::MovingImageConstPointer MovingImageConstPointer;
+  using typename Superclass1::MovingImageType;
+  using typename Superclass1::MovingImageConstPointer;
 
   /**  Type of the metric. */
-  typedef typename Superclass1::MetricType    MetricType;
-  typedef typename Superclass1::MetricPointer MetricPointer;
+  using typename Superclass1::MetricType;
+  using typename Superclass1::MetricPointer;
 
   /**  Type of the Transform . */
-  typedef typename Superclass1::TransformType    TransformType;
-  typedef typename Superclass1::TransformPointer TransformPointer;
+  using typename Superclass1::TransformType;
+  using typename Superclass1::TransformPointer;
 
   /**  Type of the Interpolator. */
-  typedef typename Superclass1::InterpolatorType    InterpolatorType;
-  typedef typename Superclass1::InterpolatorPointer InterpolatorPointer;
+  using typename Superclass1::InterpolatorType;
+  using typename Superclass1::InterpolatorPointer;
 
   /**  Type of the optimizer. */
-  typedef typename Superclass1::OptimizerType    OptimizerType;
-  typedef typename Superclass1::OptimizerPointer OptimizerPointer;
+  using typename Superclass1::OptimizerType;
+  using typename Superclass1::OptimizerPointer;
 
   /** Type of the Fixed image multiresolution pyramid. */
-  typedef typename Superclass1::FixedImagePyramidType    FixedImagePyramidType;
-  typedef typename Superclass1::FixedImagePyramidPointer FixedImagePyramidPointer;
+  using typename Superclass1::FixedImagePyramidType;
+  using typename Superclass1::FixedImagePyramidPointer;
 
   /** Type of the moving image multiresolution pyramid. */
-  typedef typename Superclass1::MovingImagePyramidType    MovingImagePyramidType;
-  typedef typename Superclass1::MovingImagePyramidPointer MovingImagePyramidPointer;
+  using typename Superclass1::MovingImagePyramidType;
+  using typename Superclass1::MovingImagePyramidPointer;
 
   /** Type of the Transformation parameters. This is the same type used to
    *  represent the search space of the optimization algorithm.
    */
-  typedef typename Superclass1::ParametersType ParametersType;
+  using typename Superclass1::ParametersType;
 
   /** The CombinationMetric type, which is used internally by the Superclass1. */
-  typedef typename Superclass1::CombinationMetricType    CombinationMetricType;
-  typedef typename Superclass1::CombinationMetricPointer CombinationMetricPointer;
+  using typename Superclass1::CombinationMetricType;
+  using typename Superclass1::CombinationMetricPointer;
 
   /** Typedef's from Elastix. */
-  typedef typename Superclass2::ElastixType             ElastixType;
-  typedef typename Superclass2::ElastixPointer          ElastixPointer;
-  typedef typename Superclass2::ConfigurationType       ConfigurationType;
-  typedef typename Superclass2::ConfigurationPointer    ConfigurationPointer;
-  typedef typename Superclass2::RegistrationType        RegistrationType;
-  typedef typename Superclass2::RegistrationPointer     RegistrationPointer;
-  typedef typename Superclass2::ITKBaseType             ITKBaseType;
-  typedef typename Superclass2::UseMaskErosionArrayType UseMaskErosionArrayType;
+  using typename Superclass2::ElastixType;
+  using RegistrationType = typename Superclass2::RegistrationType;
+  using ITKBaseType = typename Superclass2::ITKBaseType;
+  using typename Superclass2::UseMaskErosionArrayType;
 
   /** Get the dimension of the fixed image. */
-  itkStaticConstMacro( FixedImageDimension, unsigned int, Superclass2::FixedImageDimension );
+  itkStaticConstMacro(FixedImageDimension, unsigned int, Superclass2::FixedImageDimension);
   /** Get the dimension of the moving image. */
-  itkStaticConstMacro( MovingImageDimension, unsigned int, Superclass2::MovingImageDimension );
+  itkStaticConstMacro(MovingImageDimension, unsigned int, Superclass2::MovingImageDimension);
 
   /** Execute stuff before the actual registration:
    * \li Connect all components to the registration framework.
@@ -194,60 +186,60 @@ public:
    * \li Set the fixed image regions.
    * \li Add the sub metric columns to the iteration info object.
    */
-  void BeforeRegistration( void ) override;
+  void
+  BeforeRegistration() override;
 
   /** Execute stuff before each resolution:
    * \li Update masks with an erosion.
    * \li Set the metric weights.
    */
-  void BeforeEachResolution( void ) override;
+  void
+  BeforeEachResolution() override;
 
   /** Execute stuff after each iteration
    * \li Print the latest computed submetric values to screen.
    */
-  void AfterEachIteration( void ) override;
+  void
+  AfterEachIteration() override;
 
 protected:
-
   /** The constructor. */
   MultiMetricMultiResolutionRegistration();
   /** The destructor. */
-  ~MultiMetricMultiResolutionRegistration() override {}
+  ~MultiMetricMultiResolutionRegistration() override = default;
 
   /** Typedef's for mask support. */
-  typedef typename Superclass2::MaskPixelType                  MaskPixelType;
-  typedef typename Superclass2::FixedMaskImageType             FixedMaskImageType;
-  typedef typename Superclass2::MovingMaskImageType            MovingMaskImageType;
-  typedef typename Superclass2::FixedMaskImagePointer          FixedMaskImagePointer;
-  typedef typename Superclass2::MovingMaskImagePointer         MovingMaskImagePointer;
-  typedef typename Superclass2::FixedMaskSpatialObjectType     FixedMaskSpatialObjectType;
-  typedef typename Superclass2::MovingMaskSpatialObjectType    MovingMaskSpatialObjectType;
-  typedef typename Superclass2::FixedMaskSpatialObjectPointer  FixedMaskSpatialObjectPointer;
-  typedef typename Superclass2::MovingMaskSpatialObjectPointer MovingMaskSpatialObjectPointer;
+  using typename Superclass2::MaskPixelType;
+  using typename Superclass2::FixedMaskImageType;
+  using typename Superclass2::MovingMaskImageType;
+  using typename Superclass2::FixedMaskImagePointer;
+  using typename Superclass2::MovingMaskImagePointer;
+  using typename Superclass2::FixedMaskSpatialObjectType;
+  using typename Superclass2::MovingMaskSpatialObjectType;
+  using typename Superclass2::FixedMaskSpatialObjectPointer;
+  using typename Superclass2::MovingMaskSpatialObjectPointer;
 
   /** Function to update masks. */
-  void UpdateFixedMasks( unsigned int level );
+  void
+  UpdateFixedMasks(unsigned int level);
 
-  void UpdateMovingMasks( unsigned int level );
+  void
+  UpdateMovingMasks(unsigned int level);
 
   /** Read the components from m_Elastix and set them in the Registration class. */
-  virtual void SetComponents( void );
+  virtual void
+  SetComponents();
 
   bool m_ShowExactMetricValue;
 
 private:
-
-  /** The private constructor. */
-  MultiMetricMultiResolutionRegistration( const Self & );  // purposely not implemented
-  /** The private copy constructor. */
-  void operator=( const Self & );              // purposely not implemented
-
+  elxOverrideGetSelfMacro;
 };
 
 } // end namespace elastix
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "elxMultiMetricMultiResolutionRegistration.hxx"
+#  include "elxMultiMetricMultiResolutionRegistration.hxx"
 #endif
 
-#endif // end #ifndef __elxMultiMetricMultiResolutionRegistration_H__
+#endif // end #ifndef elxMultiMetricMultiResolutionRegistration_h
