@@ -15,12 +15,10 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-
 /*=========================================================================
 
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkAffineDTI3DTransform.h,v $
-  Language:  C++
   Date:      $Date: 2008-10-13 15:36:31 $
   Version:   $Revision: 1.14 $
 
@@ -32,8 +30,8 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef __itkAffineDTI3DTransform_h
-#define __itkAffineDTI3DTransform_h
+#ifndef itkAffineDTI3DTransform_h
+#define itkAffineDTI3DTransform_h
 
 #include <iostream>
 #include "itkAdvancedMatrixOffsetTransformBase.h"
@@ -75,120 +73,112 @@ namespace itk
  *
  * \ingroup Transforms
  */
-template< class TScalarType = double >
+template <class TScalarType = double>
 // Data type for scalars (float or double)
-class AffineDTI3DTransform :
-  public AdvancedMatrixOffsetTransformBase< TScalarType, 3, 3 >
+class AffineDTI3DTransform : public AdvancedMatrixOffsetTransformBase<TScalarType, 3, 3>
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(AffineDTI3DTransform);
 
   /** Standard class typedefs. */
-  typedef AffineDTI3DTransform                                   Self;
-  typedef AdvancedMatrixOffsetTransformBase< TScalarType, 3, 3 > Superclass;
-  typedef SmartPointer< Self >                                   Pointer;
-  typedef SmartPointer< const Self >                             ConstPointer;
+  using Self = AffineDTI3DTransform;
+  using Superclass = AdvancedMatrixOffsetTransformBase<TScalarType, 3, 3>;
+  using Pointer = SmartPointer<Self>;
+  using ConstPointer = SmartPointer<const Self>;
 
   /** New macro for creation of through a Smart Pointer. */
-  itkNewMacro( Self );
+  itkNewMacro(Self);
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( AffineDTI3DTransform, AdvancedMatrixOffsetTransformBase );
+  itkTypeMacro(AffineDTI3DTransform, AdvancedMatrixOffsetTransformBase);
 
   /** Dimension of the space. */
-  itkStaticConstMacro( SpaceDimension, unsigned int, 3 );
-  itkStaticConstMacro( InputSpaceDimension, unsigned int, 3 );
-  itkStaticConstMacro( OutputSpaceDimension, unsigned int, 3 );
-  itkStaticConstMacro( ParametersDimension, unsigned int, 12 );
+  itkStaticConstMacro(SpaceDimension, unsigned int, 3);
+  itkStaticConstMacro(InputSpaceDimension, unsigned int, 3);
+  itkStaticConstMacro(OutputSpaceDimension, unsigned int, 3);
+  itkStaticConstMacro(ParametersDimension, unsigned int, 12);
 
-  typedef typename Superclass::ParametersType            ParametersType;
-  typedef typename Superclass::NumberOfParametersType    NumberOfParametersType;
-  typedef typename Superclass::JacobianType              JacobianType;
-  typedef typename Superclass::ScalarType                ScalarType;
-  typedef typename Superclass::InputVectorType           InputVectorType;
-  typedef typename Superclass::OutputVectorType          OutputVectorType;
-  typedef typename Superclass::InputCovariantVectorType  InputCovariantVectorType;
-  typedef typename Superclass::OutputCovariantVectorType OutputCovariantVectorType;
-  typedef typename Superclass::InputVnlVectorType        InputVnlVectorType;
-  typedef typename Superclass::OutputVnlVectorType       OutputVnlVectorType;
-  typedef typename Superclass::InputPointType            InputPointType;
-  typedef typename Superclass::OutputPointType           OutputPointType;
-  typedef typename Superclass::MatrixType                MatrixType;
-  typedef typename Superclass::InverseMatrixType         InverseMatrixType;
-  typedef typename Superclass::CenterType                CenterType;
-  typedef typename Superclass::TranslationType           TranslationType;
-  typedef typename Superclass::OffsetType                OffsetType;
-  typedef typename Superclass::ScalarType                AngleType;
+  using typename Superclass::ParametersType;
+  using typename Superclass::NumberOfParametersType;
+  using typename Superclass::JacobianType;
+  using typename Superclass::ScalarType;
+  using typename Superclass::InputVectorType;
+  using typename Superclass::OutputVectorType;
+  using typename Superclass::InputCovariantVectorType;
+  using typename Superclass::OutputCovariantVectorType;
+  using typename Superclass::InputVnlVectorType;
+  using typename Superclass::OutputVnlVectorType;
+  using typename Superclass::InputPointType;
+  using typename Superclass::OutputPointType;
+  using typename Superclass::MatrixType;
+  using typename Superclass::InverseMatrixType;
+  using typename Superclass::CenterType;
+  using typename Superclass::TranslationType;
+  using typename Superclass::OffsetType;
+  using AngleType = typename Superclass::ScalarType;
 
-  typedef typename Superclass
-    ::NonZeroJacobianIndicesType NonZeroJacobianIndicesType;
-  typedef typename Superclass::SpatialJacobianType SpatialJacobianType;
-  typedef typename Superclass
-    ::JacobianOfSpatialJacobianType JacobianOfSpatialJacobianType;
-  typedef typename Superclass::SpatialHessianType SpatialHessianType;
-  typedef typename Superclass
-    ::JacobianOfSpatialHessianType JacobianOfSpatialHessianType;
-  typedef typename Superclass::InternalMatrixType InternalMatrixType;
+  using typename Superclass::NonZeroJacobianIndicesType;
+  using typename Superclass::SpatialJacobianType;
+  using typename Superclass::JacobianOfSpatialJacobianType;
+  using typename Superclass::SpatialHessianType;
+  using typename Superclass::JacobianOfSpatialHessianType;
+  using typename Superclass::InternalMatrixType;
 
-  typedef FixedArray< ScalarType > ScalarArrayType;
+  using ScalarArrayType = FixedArray<ScalarType>;
 
   /** Set/Get the transformation from a container of parameters
    * This is typically used by optimizers.  There are 12 parameters.
    * [ Rx Ry Rz Gx Gy Gz Sx Sy Sz Tx Ty Tz ]
    * ~rotation, scale, skew, translation
    */
-  void SetParameters( const ParametersType & parameters ) override;
+  void
+  SetParameters(const ParametersType & parameters) override;
 
-  const ParametersType & GetParameters( void ) const override;
+  const ParametersType &
+  GetParameters() const override;
 
   /** Compute the Jacobian of the transformation. */
-  void GetJacobian(
-    const InputPointType &,
-    JacobianType &,
-    NonZeroJacobianIndicesType & ) const override;
+  void
+  GetJacobian(const InputPointType &, JacobianType &, NonZeroJacobianIndicesType &) const override;
 
-  void SetIdentity( void ) override;
+  void
+  SetIdentity() override;
 
 protected:
-
   AffineDTI3DTransform();
-  AffineDTI3DTransform( const MatrixType & matrix,
-    const OutputPointType & offset );
-  AffineDTI3DTransform( unsigned int outputSpaceDims,
-    unsigned int paramsSpaceDims );
+  AffineDTI3DTransform(const MatrixType & matrix, const OutputPointType & offset);
+  AffineDTI3DTransform(unsigned int outputSpaceDims, unsigned int paramsSpaceDims);
 
-  ~AffineDTI3DTransform(){}
+  ~AffineDTI3DTransform() override = default;
 
-  void PrintSelf( std::ostream & os, Indent indent ) const override;
+  void
+  PrintSelf(std::ostream & os, Indent indent) const override;
 
   /** Set values of angles etc directly without recomputing other parameters. */
-  void SetVarAngleScaleShear(
-    ScalarArrayType angle,
-    ScalarArrayType shear,
-    ScalarArrayType scale );
+  void
+  SetVarAngleScaleShear(ScalarArrayType angle, ScalarArrayType shear, ScalarArrayType scale);
 
   /** Compute the components of the rotation matrix in the superclass. */
-  void ComputeMatrix( void ) override;
+  void
+  ComputeMatrix() override;
 
-  void ComputeMatrixParameters( void ) override;
+  void
+  ComputeMatrixParameters() override;
 
   /** Update the m_JacobianOfSpatialJacobian.  */
-  virtual void PrecomputeJacobianOfSpatialJacobian( void );
+  virtual void
+  PrecomputeJacobianOfSpatialJacobian();
 
 private:
-
-  AffineDTI3DTransform( const Self & ); // purposely not implemented
-  void operator=( const Self & );       // purposely not implemented
-
   ScalarArrayType m_Angle;
   ScalarArrayType m_Shear;
   ScalarArrayType m_Scale;
-
 };
 
-}  // namespace itk
+} // namespace itk
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "itkAffineDTI3DTransform.hxx"
+#  include "itkAffineDTI3DTransform.hxx"
 #endif
 
-#endif /* __itkAffineDTI3DTransform_h */
+#endif /* itkAffineDTI3DTransform_h */
