@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __elxBSplineTransformWithDiffusion_H__
-#define __elxBSplineTransformWithDiffusion_H__
+#ifndef elxBSplineTransformWithDiffusion_h
+#define elxBSplineTransformWithDiffusion_h
 
 /* For easy changing the BSplineOrder: */
 #define __VSplineOrder 3
@@ -155,186 +155,169 @@ namespace elastix
  * \ingroup Transforms
  */
 
-template< class TElastix >
-class BSplineTransformWithDiffusion :
-  public
-  itk::DeformationFieldRegulizer<
-  itk::AdvancedCombinationTransform<
-  //BSplineCombinationTransform<
-  typename elx::TransformBase< TElastix >::CoordRepType,
-  elx::TransformBase< TElastix >::FixedImageDimension > >,
-  //elx::TransformBase<TElastix>::FixedImageDimension, __VSplineOrder > >,
-  public
-  TransformBase< TElastix >
+template <class TElastix>
+class ITK_TEMPLATE_EXPORT BSplineTransformWithDiffusion
+  : public itk::DeformationFieldRegulizer<itk::AdvancedCombinationTransform<
+      // BSplineCombinationTransform<
+      typename elx::TransformBase<TElastix>::CoordRepType,
+      elx::TransformBase<TElastix>::FixedImageDimension>>
+  ,
+    // elx::TransformBase<TElastix>::FixedImageDimension, __VSplineOrder > >,
+    public TransformBase<TElastix>
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(BSplineTransformWithDiffusion);
 
   /** Standard ITK-stuff. */
-  typedef BSplineTransformWithDiffusion Self;
-  typedef itk::DeformationFieldRegulizer<
-    itk::AdvancedCombinationTransform<
-    //BSplineCombinationTransform<
-    typename elx::TransformBase< TElastix >::CoordRepType,
-    elx::TransformBase< TElastix >::FixedImageDimension > >
-    //elx::TransformBase<TElastix>::FixedImageDimension, __VSplineOrder > >
-    Superclass1;
-  typedef elx::TransformBase< TElastix > Superclass2;
+  using Self = BSplineTransformWithDiffusion;
+  using Superclass1 = itk::DeformationFieldRegulizer<
+    itk::AdvancedCombinationTransform<typename elx::TransformBase<TElastix>::CoordRepType,
+                                      elx::TransformBase<TElastix>::FixedImageDimension>>;
+  using Superclass2 = elx::TransformBase<TElastix>;
 
   /** The ITK-class that provides most of the functionality, and
    * that is set as the "CurrentTransform" in the CombinationTransform.
    */
-  typedef itk::AdvancedBSplineDeformableTransform<
-    typename elx::TransformBase< TElastix >::CoordRepType,
-    elx::TransformBase< TElastix >::FixedImageDimension,
-    __VSplineOrder >                                  BSplineTransformType;
+  using BSplineTransformType =
+    itk::AdvancedBSplineDeformableTransform<typename elx::TransformBase<TElastix>::CoordRepType,
+                                            elx::TransformBase<TElastix>::FixedImageDimension,
+                                            3>;
 
-  typedef itk::SmartPointer< Self >       Pointer;
-  typedef itk::SmartPointer< const Self > ConstPointer;
+  using Pointer = itk::SmartPointer<Self>;
+  using ConstPointer = itk::SmartPointer<const Self>;
 
   /** Method for creation through the object factory. */
-  itkNewMacro( Self );
+  itkNewMacro(Self);
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( BSplineTransformWithDiffusion, itk::DeformationFieldRegulizer );
+  itkTypeMacro(BSplineTransformWithDiffusion, itk::DeformationFieldRegulizer);
 
   /** Name of this class.
    * Use this name in the parameter file to select this specific transform. \n
    * example: <tt>(Transform "BSplineTransformWithDiffusion")</tt>\n
    */
-  elxClassNameMacro( "BSplineTransformWithDiffusion" );
+  elxClassNameMacro("BSplineTransformWithDiffusion");
 
   /** Dimension of the domain space. */
-  itkStaticConstMacro( SpaceDimension, unsigned int, Superclass2::FixedImageDimension );
+  itkStaticConstMacro(SpaceDimension, unsigned int, Superclass2::FixedImageDimension);
 
   /** The B-spline order. */
-  itkStaticConstMacro( SplineOrder, unsigned int, __VSplineOrder );
+  itkStaticConstMacro(SplineOrder, unsigned int, __VSplineOrder);
 
   /** Typedefs inherited from the superclass. */
-  typedef typename Superclass1::ScalarType                ScalarType;
-  typedef typename Superclass1::ParametersType            ParametersType;
-  typedef typename Superclass1::JacobianType              JacobianType;
-  typedef typename Superclass1::InputVectorType           InputVectorType;
-  typedef typename Superclass1::OutputVectorType          OutputVectorType;
-  typedef typename Superclass1::InputCovariantVectorType  InputCovariantVectorType;
-  typedef typename Superclass1::OutputCovariantVectorType OutputCovariantVectorType;
-  typedef typename Superclass1::InputVnlVectorType        InputVnlVectorType;
-  typedef typename Superclass1::OutputVnlVectorType       OutputVnlVectorType;
-  typedef typename Superclass1::InputPointType            InputPointType;
-  typedef typename Superclass1::OutputPointType           OutputPointType;
+  using typename Superclass1::ScalarType;
+  using typename Superclass1::ParametersType;
+  using typename Superclass1::JacobianType;
+  using typename Superclass1::InputVectorType;
+  using typename Superclass1::OutputVectorType;
+  using typename Superclass1::InputCovariantVectorType;
+  using typename Superclass1::OutputCovariantVectorType;
+  using typename Superclass1::InputVnlVectorType;
+  using typename Superclass1::OutputVnlVectorType;
+  using typename Superclass1::InputPointType;
+  using typename Superclass1::OutputPointType;
 
   /** Typedef's specific for the BSplineTransform. */
-  typedef typename BSplineTransformType::PixelType               PixelType;
-  typedef typename BSplineTransformType::ImageType               ImageType;
-  typedef typename BSplineTransformType::ImagePointer            ImagePointer;
-  typedef typename BSplineTransformType::RegionType              RegionType;
-  typedef typename BSplineTransformType::IndexType               IndexType;
-  typedef typename BSplineTransformType::SizeType                SizeType;
-  typedef typename BSplineTransformType::SpacingType             SpacingType;
-  typedef typename BSplineTransformType::OriginType              OriginType;
-  typedef typename BSplineTransformType::WeightsFunctionType     WeightsFunctionType;
-  typedef typename BSplineTransformType::WeightsType             WeightsType;
-  typedef typename BSplineTransformType::ContinuousIndexType     ContinuousIndexType;
-  typedef typename BSplineTransformType::ParameterIndexArrayType ParameterIndexArrayType;
+  using PixelType = typename BSplineTransformType::PixelType;
+  using ImageType = typename BSplineTransformType::ImageType;
+  using ImagePointer = typename BSplineTransformType::ImagePointer;
+  using RegionType = typename BSplineTransformType::RegionType;
+  using IndexType = typename BSplineTransformType::IndexType;
+  using SizeType = typename BSplineTransformType::SizeType;
+  using SpacingType = typename BSplineTransformType::SpacingType;
+  using OriginType = typename BSplineTransformType::OriginType;
+  using WeightsFunctionType = typename BSplineTransformType::WeightsFunctionType;
+  using WeightsType = typename BSplineTransformType::WeightsType;
+  using ContinuousIndexType = typename BSplineTransformType::ContinuousIndexType;
+  using ParameterIndexArrayType = typename BSplineTransformType::ParameterIndexArrayType;
 
   /** Typedef's from TransformBase. */
-  typedef typename Superclass2::ElastixType              ElastixType;
-  typedef typename Superclass2::ElastixPointer           ElastixPointer;
-  typedef typename Superclass2::ConfigurationType        ConfigurationType;
-  typedef typename Superclass2::ConfigurationPointer     ConfigurationPointer;
-  typedef typename Superclass2::RegistrationType         RegistrationType;
-  typedef typename Superclass2::RegistrationPointer      RegistrationPointer;
-  typedef typename Superclass2::CoordRepType             CoordRepType;
-  typedef typename Superclass2::FixedImageType           FixedImageType;
-  typedef typename Superclass2::MovingImageType          MovingImageType;
-  typedef typename Superclass2::ITKBaseType              ITKBaseType;
-  typedef typename Superclass2::CombinationTransformType CombinationTransformType;
+  using typename Superclass2::ElastixType;
+  using typename Superclass2::ParameterMapType;
+  using typename Superclass2::RegistrationType;
+  using typename Superclass2::CoordRepType;
+  using typename Superclass2::FixedImageType;
+  using typename Superclass2::MovingImageType;
+  using ITKBaseType = typename Superclass2::ITKBaseType;
+  using CombinationTransformType = typename Superclass2::CombinationTransformType;
 
   /** Other typedef's inherited from Superclass1. */
-  typedef typename Superclass1::IntermediaryDFTransformType IntermediaryDFTransformType;
-  typedef typename Superclass1::VectorImageType             VectorImageType;
-  typedef typename VectorImageType::Pointer                 VectorImagePointer;
+  using typename Superclass1::IntermediaryDFTransformType;
+  using typename Superclass1::VectorImageType;
+  using VectorImagePointer = typename VectorImageType::Pointer;
 
   /** References to the fixed and moving image types. */
-  typedef typename ElastixType::FixedImageType  FixedImageELXType;
-  typedef typename ElastixType::MovingImageType MovingImageELXType;
+  using FixedImageELXType = typename ElastixType::FixedImageType;
+  using MovingImageELXType = typename ElastixType::MovingImageType;
 
   /** Other typedef's.*/
-  typedef itk::Image< short,
-    itkGetStaticConstMacro( SpaceDimension ) >      DummyImageType;
-  typedef itk::ImageRegionConstIterator<
-    DummyImageType >                                DummyIteratorType;
-  typedef typename BSplineTransformType::Pointer BSplineTransformPointer;
-  typedef typename Superclass1::Superclass       GenericDeformationFieldRegulizer;
+  using DummyImageType = itk::Image<short, Self::SpaceDimension>;
+  using DummyIteratorType = itk::ImageRegionConstIterator<DummyImageType>;
+  using BSplineTransformPointer = typename BSplineTransformType::Pointer;
+  using GenericDeformationFieldRegulizer = typename Superclass1::Superclass;
 
   /** Typedef's for the diffusion of the deformation field. */
-  typedef itk::ImageFileReader< VectorImageType > VectorReaderType;
-  typedef typename VectorImageType::PixelType     VectorType;
-  typedef itk::ImageRegionIterator<
-    VectorImageType >                               VectorImageIteratorType;
-  typedef FixedImageELXType                      GrayValueImageType;
-  typedef typename GrayValueImageType::Pointer   GrayValueImagePointer;
-  typedef typename GrayValueImageType::PixelType GrayValuePixelType;
-  typedef itk::ImageRegionIterator<
-    GrayValueImageType >                            GrayValueImageIteratorType;
-  typedef itk::MaximumImageFilter<
-    GrayValueImageType, GrayValueImageType,
-    GrayValueImageType >                            MaximumImageFilterType;
-  typedef itk::VectorMeanDiffusionImageFilter<
-    VectorImageType, GrayValueImageType >           DiffusionFilterType;
-  typedef typename DiffusionFilterType::Pointer DiffusionFilterPointer;
-  typedef typename VectorImageType::SizeType    RadiusType;
-  typedef itk::ResampleImageFilter<
-    MovingImageELXType, GrayValueImageType,
-    CoordRepType >                                  ResamplerType1;
-  typedef typename ResamplerType1::Pointer ResamplerPointer1;
-  typedef itk::ResampleImageFilter<
-    GrayValueImageType, GrayValueImageType,
-    CoordRepType >                                  ResamplerType2;
-  typedef typename ResamplerType2::Pointer ResamplerPointer2;
-  typedef itk::BSplineInterpolateImageFunction<
-    GrayValueImageType >                            InterpolatorType;
-  typedef typename InterpolatorType::Pointer         InterpolatorPointer;
-  typedef itk::ImageFileReader< GrayValueImageType > GrayValueImageReaderType;
-  typedef typename GrayValueImageReaderType::Pointer GrayValueImageReaderPointer;
-  typedef itk::ImageFileWriter< GrayValueImageType > GrayValueImageWriterType;
-  typedef itk::ImageFileWriter< VectorImageType >    DeformationFieldWriterType;
+  using VectorReaderType = itk::ImageFileReader<VectorImageType>;
+  using VectorType = typename VectorImageType::PixelType;
+  using VectorImageIteratorType = itk::ImageRegionIterator<VectorImageType>;
+  using GrayValueImageType = FixedImageELXType;
+  using GrayValueImagePointer = typename GrayValueImageType::Pointer;
+  using GrayValuePixelType = typename GrayValueImageType::PixelType;
+  using GrayValueImageIteratorType = itk::ImageRegionIterator<GrayValueImageType>;
+  using MaximumImageFilterType = itk::MaximumImageFilter<GrayValueImageType, GrayValueImageType, GrayValueImageType>;
+  using DiffusionFilterType = itk::VectorMeanDiffusionImageFilter<VectorImageType, GrayValueImageType>;
+  using DiffusionFilterPointer = typename DiffusionFilterType::Pointer;
+  using RadiusType = typename VectorImageType::SizeType;
+  using ResamplerType1 = itk::ResampleImageFilter<MovingImageELXType, GrayValueImageType, CoordRepType>;
+  using ResamplerPointer1 = typename ResamplerType1::Pointer;
+  using ResamplerType2 = itk::ResampleImageFilter<GrayValueImageType, GrayValueImageType, CoordRepType>;
+  using ResamplerPointer2 = typename ResamplerType2::Pointer;
+  using InterpolatorType = itk::BSplineInterpolateImageFunction<GrayValueImageType>;
+  using InterpolatorPointer = typename InterpolatorType::Pointer;
+  using GrayValueImageReaderType = itk::ImageFileReader<GrayValueImageType>;
+  using GrayValueImageReaderPointer = typename GrayValueImageReaderType::Pointer;
 
   /** Execute stuff before the actual registration:
    * \li Create an initial B-spline grid.
    * \li Create initial registration parameters.
    * \li Setup stuff for the diffusion of the deformation field.
    */
-  void BeforeRegistration( void ) override;
+  void
+  BeforeRegistration() override;
 
   /** Execute stuff before each new pyramid resolution:
    * \li upsample the B-spline grid.
    */
-  void BeforeEachResolution( void ) override;
+  void
+  BeforeEachResolution() override;
 
   /** Execute stuff after each iteration:
    * \li Do a diffusion of the deformation field.
    */
-  void AfterEachIteration( void ) override;
+  void
+  AfterEachIteration() override;
 
   /** Execute stuff after registration:
    * \li Destroy things that are not needed anymore in order to free memory.
    */
-  void AfterRegistration( void ) override;
+  void
+  AfterRegistration() override;
 
   /** Set the initial B-spline grid. */
-  virtual void SetInitialGrid( bool upsampleGridOption );
+  virtual void
+  SetInitialGrid(bool upsampleGridOption);
 
   /** Upsample the B-spline grid. */
-  virtual void IncreaseScale( void );
+  virtual void
+  IncreaseScale();
 
   /** Function to read transform-parameters from a file. */
-  void ReadFromFile( void ) override;
-
-  /** Function to write transform-parameters to a file. */
-  void WriteToFile( const ParametersType & param ) const override;
+  void
+  ReadFromFile() override;
 
   /** Diffuse the deformation field. */
-  void DiffuseDeformationField( void );
+  void
+  DiffuseDeformationField();
 
   /** Method to transform a point.
    * This method just calls the implementation from the
@@ -346,7 +329,8 @@ public:
    * TransformPoint() method (it does not call the TransformPoint() with
    * with 5 arguments, as the BSplineDeformableTransform does).
    */
-  OutputPointType TransformPoint( const InputPointType  & point ) const override;
+  OutputPointType
+  TransformPoint(const InputPointType & point) const override;
 
   /**  Method to transform a point with extra arguments. Just calls
    * the Superclass1's implementation. Has to be present here since it is an
@@ -360,21 +344,24 @@ public:
     bool & inside ) const;*/
 
 protected:
-
   /** The constructor. */
   BSplineTransformWithDiffusion();
   /** The destructor. */
-  ~BSplineTransformWithDiffusion() override {}
+  ~BSplineTransformWithDiffusion() override = default;
 
   /** Member variables. */
   SpacingType m_GridSpacingFactor;
 
 private:
+  elxOverrideGetSelfMacro;
 
-  /** The private constructor. */
-  BSplineTransformWithDiffusion( const Self & ); // purposely not implemented
-  /** The private copy constructor. */
-  void operator=( const Self & );                // purposely not implemented
+  /** Creates a map of the parameters specific for this (derived) transform type. */
+  ParameterMapType
+  CreateDerivedTransformParametersMap() const override;
+
+  /** Writes its deformation field to a file. */
+  void
+  WriteDerivedTransformDataToFile() const override;
 
   /** Member variables for diffusion. */
   DiffusionFilterPointer      m_Diffusion;
@@ -410,13 +397,12 @@ private:
    * the combination transform.
    */
   BSplineTransformPointer m_BSplineTransform;
-
 };
 
 } // end namespace elastix
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "elxBSplineTransformWithDiffusion.hxx"
+#  include "elxBSplineTransformWithDiffusion.hxx"
 #endif
 
-#endif // end #ifndef __elxBSplineTransformWithDiffusion_H__
+#endif // end #ifndef elxBSplineTransformWithDiffusion_h
