@@ -15,13 +15,13 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __elxEulerStackTransform_h
-#define __elxEulerStackTransform_h
+#ifndef elxEulerStackTransform_h
+#define elxEulerStackTransform_h
 
 #include "elxIncludes.h"
 /** Include itk transforms needed. */
 #include "itkAdvancedCombinationTransform.h"
-#include "itkStackTransform.h"
+#include "itkEulerStackTransform.h"
 #include "itkEulerTransform.h"
 
 namespace elastix
@@ -77,121 +77,105 @@ namespace elastix
  * \ingroup Transforms
  */
 
-template< class TElastix >
-class EulerStackTransform :
-  public itk::AdvancedCombinationTransform<
-    typename elx::TransformBase< TElastix >::CoordRepType,
-    elx::TransformBase< TElastix >::FixedImageDimension >,
-  public elx::TransformBase< TElastix >
+template <class TElastix>
+class ITK_TEMPLATE_EXPORT EulerStackTransform
+  : public itk::AdvancedCombinationTransform<typename elx::TransformBase<TElastix>::CoordRepType,
+                                             elx::TransformBase<TElastix>::FixedImageDimension>
+  , public elx::TransformBase<TElastix>
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(EulerStackTransform);
 
   /** Standard ITK-stuff. */
-  typedef EulerStackTransform                             Self;
-  typedef itk::AdvancedCombinationTransform<
-    typename elx::TransformBase< TElastix >::CoordRepType,
-    elx::TransformBase< TElastix >::FixedImageDimension > Superclass1;
-  typedef elx::TransformBase< TElastix >                  Superclass2;
-  typedef itk::SmartPointer< Self >                       Pointer;
-  typedef itk::SmartPointer< const Self >                 ConstPointer;
+  using Self = EulerStackTransform;
+  using Superclass1 = itk::AdvancedCombinationTransform<typename elx::TransformBase<TElastix>::CoordRepType,
+                                                        elx::TransformBase<TElastix>::FixedImageDimension>;
+  using Superclass2 = elx::TransformBase<TElastix>;
+  using Pointer = itk::SmartPointer<Self>;
+  using ConstPointer = itk::SmartPointer<const Self>;
 
   /** Method for creation through the object factory. */
-  itkNewMacro( Self );
+  itkNewMacro(Self);
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( EulerStackTransform, itk::AdvancedCombinationTransform );
+  itkTypeMacro(EulerStackTransform, itk::AdvancedCombinationTransform);
 
   /** Name of this class.
    * Use this name in the parameter file to select this specific transform. \n
    * example: <tt>(Transform "EulerStackTransform")</tt>\n
    */
-  elxClassNameMacro( "EulerStackTransform" );
+  elxClassNameMacro("EulerStackTransform");
 
   /** (Reduced) dimension of the fixed image. */
-  itkStaticConstMacro( SpaceDimension, unsigned int, Superclass2::FixedImageDimension );
-  itkStaticConstMacro( ReducedSpaceDimension, unsigned int, Superclass2::FixedImageDimension - 1 );
+  itkStaticConstMacro(SpaceDimension, unsigned int, Superclass2::FixedImageDimension);
+  itkStaticConstMacro(ReducedSpaceDimension, unsigned int, Superclass2::FixedImageDimension - 1);
 
   /** The ITK-class that provides most of the functionality, and
    * that is set as the "CurrentTransform" in the CombinationTransform.
    */
-  typedef itk::EulerTransform<
-    typename elx::TransformBase< TElastix >::CoordRepType,
-    itkGetStaticConstMacro( SpaceDimension ) >        EulerTransformType;
-  typedef typename EulerTransformType::Pointer        EulerTransformPointer;
-  typedef typename EulerTransformType::InputPointType InputPointType;
+  using EulerTransformType =
+    itk::EulerTransform<typename elx::TransformBase<TElastix>::CoordRepType, Self::SpaceDimension>;
+  using EulerTransformPointer = typename EulerTransformType::Pointer;
+  using InputPointType = typename EulerTransformType::InputPointType;
 
   /** The ITK-class for the sub transforms, which have a reduced dimension. */
-  typedef itk::EulerTransform<
-    typename elx::TransformBase< TElastix >::CoordRepType,
-    itkGetStaticConstMacro( ReducedSpaceDimension ) >                         ReducedDimensionEulerTransformType;
-  typedef typename ReducedDimensionEulerTransformType::Pointer ReducedDimensionEulerTransformPointer;
+  using ReducedDimensionEulerTransformType =
+    itk::EulerTransform<typename elx::TransformBase<TElastix>::CoordRepType, Self::ReducedSpaceDimension>;
+  using ReducedDimensionEulerTransformPointer = typename ReducedDimensionEulerTransformType::Pointer;
 
-  typedef typename ReducedDimensionEulerTransformType::OutputVectorType ReducedDimensionOutputVectorType;
-  typedef typename ReducedDimensionEulerTransformType::InputPointType   ReducedDimensionInputPointType;
-
-  /** Typedef for stack transform. */
-  typedef itk::StackTransform<
-    typename elx::TransformBase< TElastix >::CoordRepType,
-    itkGetStaticConstMacro( SpaceDimension ),
-    itkGetStaticConstMacro( SpaceDimension ) >           EulerStackTransformType;
-  typedef typename EulerStackTransformType::Pointer EulerStackTransformPointer;
+  using ReducedDimensionOutputVectorType = typename ReducedDimensionEulerTransformType::OutputVectorType;
+  using ReducedDimensionInputPointType = typename ReducedDimensionEulerTransformType::InputPointType;
 
   /** Typedefs inherited from the superclass. */
-  typedef typename Superclass1::ParametersType         ParametersType;
-  typedef typename Superclass1::NumberOfParametersType NumberOfParametersType;
+  using typename Superclass1::ParametersType;
+  using typename Superclass1::NumberOfParametersType;
 
   /** Typedef's from TransformBase. */
-  typedef typename Superclass2::ElastixType              ElastixType;
-  typedef typename Superclass2::ElastixPointer           ElastixPointer;
-  typedef typename Superclass2::ConfigurationType        ConfigurationType;
-  typedef typename Superclass2::ConfigurationPointer     ConfigurationPointer;
-  typedef typename Superclass2::RegistrationType         RegistrationType;
-  typedef typename Superclass2::RegistrationPointer      RegistrationPointer;
-  typedef typename Superclass2::CoordRepType             CoordRepType;
-  typedef typename Superclass2::FixedImageType           FixedImageType;
-  typedef typename Superclass2::MovingImageType          MovingImageType;
-  typedef typename Superclass2::ITKBaseType              ITKBaseType;
-  typedef typename Superclass2::CombinationTransformType CombinationTransformType;
+  using typename Superclass2::ElastixType;
+  using typename Superclass2::ParameterMapType;
+  using typename Superclass2::RegistrationType;
+  using typename Superclass2::CoordRepType;
+  using typename Superclass2::FixedImageType;
+  using typename Superclass2::MovingImageType;
+  using ITKBaseType = typename Superclass2::ITKBaseType;
+  using CombinationTransformType = typename Superclass2::CombinationTransformType;
 
   /** Reduced Dimension typedef's. */
-  typedef float PixelType;
-  typedef itk::Image< PixelType,
-    itkGetStaticConstMacro( ReducedSpaceDimension ) >          ReducedDimensionImageType;
-  typedef itk::ImageRegion<
-    itkGetStaticConstMacro( ReducedSpaceDimension ) >         ReducedDimensionRegionType;
-  typedef typename ReducedDimensionImageType::PointType     ReducedDimensionPointType;
-  typedef typename ReducedDimensionImageType::SizeType      ReducedDimensionSizeType;
-  typedef typename ReducedDimensionRegionType::IndexType    ReducedDimensionIndexType;
-  typedef typename ReducedDimensionImageType::SpacingType   ReducedDimensionSpacingType;
-  typedef typename ReducedDimensionImageType::DirectionType ReducedDimensionDirectionType;
-  typedef typename ReducedDimensionImageType::PointType     ReducedDimensionOriginType;
+  using PixelType = float;
+  using ReducedDimensionImageType = itk::Image<PixelType, Self::ReducedSpaceDimension>;
+  using ReducedDimensionRegionType = itk::ImageRegion<Self::ReducedSpaceDimension>;
+  using ReducedDimensionPointType = typename ReducedDimensionImageType::PointType;
+  using ReducedDimensionSizeType = typename ReducedDimensionImageType::SizeType;
+  using ReducedDimensionIndexType = typename ReducedDimensionRegionType::IndexType;
+  using ReducedDimensionSpacingType = typename ReducedDimensionImageType::SpacingType;
+  using ReducedDimensionDirectionType = typename ReducedDimensionImageType::DirectionType;
+  using ReducedDimensionOriginType = typename ReducedDimensionImageType::PointType;
 
   /** For scales setting in the optimizer */
-  typedef typename Superclass2::ScalesType ScalesType;
+  using typename Superclass2::ScalesType;
 
   /** Other typedef's. */
-  typedef typename FixedImageType::IndexType                                   IndexType;
-  typedef typename FixedImageType::SizeType                                    SizeType;
-  typedef typename FixedImageType::PointType                                   PointType;
-  typedef typename FixedImageType::SpacingType                                 SpacingType;
-  typedef typename FixedImageType::RegionType                                  RegionType;
-  typedef typename FixedImageType::DirectionType                               DirectionType;
-  typedef typename itk::ContinuousIndex< CoordRepType, ReducedSpaceDimension > ReducedDimensionContinuousIndexType;
-  typedef typename itk::ContinuousIndex< CoordRepType, SpaceDimension >        ContinuousIndexType;
+  using IndexType = typename FixedImageType::IndexType;
+  using SizeType = typename FixedImageType::SizeType;
+  using PointType = typename FixedImageType::PointType;
+  using SpacingType = typename FixedImageType::SpacingType;
+  using RegionType = typename FixedImageType::RegionType;
+  using DirectionType = typename FixedImageType::DirectionType;
+  using ReducedDimensionContinuousIndexType = typename itk::ContinuousIndex<CoordRepType, ReducedSpaceDimension>;
+  using ContinuousIndexType = typename itk::ContinuousIndex<CoordRepType, SpaceDimension>;
 
   /** Execute stuff before anything else is done:*/
 
-  int BeforeAll( void ) override;
+  int
+  BeforeAll() override;
 
   /** Execute stuff before the actual registration:
    * \li Set the stack transform parameters.
    * \li Set initial sub transforms.
    * \li Create initial registration parameters.
    */
-  void BeforeRegistration( void ) override;
-
-  /** Method initialize the parameters (to 0). */
-  virtual void InitializeTransform( void );
+  void
+  BeforeRegistration() override;
 
   /** Set the scales
    * \li If AutomaticScalesEstimation is "true" estimate scales
@@ -200,58 +184,67 @@ public:
    * This function is called by BeforeRegistration, after
    * the InitializeTransform function is called
    */
-  virtual void SetScales( void );
+  virtual void
+  SetScales();
 
   /** Function to read transform-parameters from a file. */
-  void ReadFromFile( void ) override;
-
-  /** Function to write transform-parameters to a file. */
-  void WriteToFile( const ParametersType & param ) const override;
+  void
+  ReadFromFile() override;
 
   /** Function to rotate center of rotation point using initial transformation. */
-  virtual void InitialTransformCenter( ReducedDimensionInputPointType & point );
+  virtual void
+  InitialTransformCenter(ReducedDimensionInputPointType & point);
 
 protected:
-
   /** The constructor. */
-  EulerStackTransform();
+  EulerStackTransform() { this->Superclass1::SetCurrentTransform(m_StackTransform); }
 
   /** The destructor. */
-  ~EulerStackTransform() override {}
+  ~EulerStackTransform() override = default;
 
   /** Try to read the CenterOfRotationPoint from the transform parameter file
    * The CenterOfRotationPoint is already in world coordinates.
    * Transform parameter files generated by elastix version > 3.402
    * save the center of rotation in this way.
    */
-  virtual bool ReadCenterOfRotationPoint( ReducedDimensionInputPointType & rotationPoint ) const;
+  virtual bool
+  ReadCenterOfRotationPoint(ReducedDimensionInputPointType & rotationPoint) const;
 
 private:
+  elxOverrideGetSelfMacro;
 
-  /** The private constructor and copy constructor. */
-  EulerStackTransform( const Self & );    // purposely not implemented
-  void operator=( const Self & );         // purposely not implemented
+  /** Method initialize the parameters (to 0). */
+  void
+  InitializeTransform();
+
+  /** Creates a map of the parameters specific for this (derived) transform type. */
+  ParameterMapType
+  CreateDerivedTransformParametersMap() const override;
+
+  /** The deleted copy constructor and assignment operator. */
+  /** Typedef for stack transform. */
+  using StackTransformType = itk::EulerStackTransform<SpaceDimension>;
 
   /** The Affine stack transform. */
-  EulerStackTransformPointer m_EulerStackTransform;
+  const typename StackTransformType::Pointer m_StackTransform{ StackTransformType::New() };
 
   /** Dummy sub transform to be used to set sub transforms of stack transform. */
-  ReducedDimensionEulerTransformPointer m_EulerDummySubTransform;
+  ReducedDimensionEulerTransformPointer m_DummySubTransform;
 
   /** Stack variables. */
   unsigned int m_NumberOfSubTransforms;
   double       m_StackOrigin, m_StackSpacing;
 
   /** Initialize the affine transform. */
-  unsigned int InitializeEulerTransform();
-
+  unsigned int
+  InitializeEulerTransform();
 };
 
 
 } // end namespace elastix
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "elxEulerStackTransform.hxx"
+#  include "elxEulerStackTransform.hxx"
 #endif
 
-#endif // end #ifndef __elxEulerStackTransform_h
+#endif // end #ifndef elxEulerStackTransform_h
