@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __elxRecursiveBSplineTransform_h
-#define __elxRecursiveBSplineTransform_h
+#ifndef elxRecursiveBSplineTransform_h
+#define elxRecursiveBSplineTransform_h
 
 #include "elxIncludes.h" // include first to avoid MSVS warning
 #include "itkAdvancedCombinationTransform.h"
@@ -105,135 +105,99 @@ namespace elastix
  * \ingroup Transforms
  */
 
-template< class TElastix >
-class RecursiveBSplineTransform :
-  public itk::AdvancedCombinationTransform<
-    typename elx::TransformBase< TElastix >::CoordRepType,
-    elx::TransformBase< TElastix >::FixedImageDimension >,
-  public TransformBase< TElastix >
+template <class TElastix>
+class ITK_TEMPLATE_EXPORT RecursiveBSplineTransform
+  : public itk::AdvancedCombinationTransform<typename elx::TransformBase<TElastix>::CoordRepType,
+                                             elx::TransformBase<TElastix>::FixedImageDimension>
+  , public TransformBase<TElastix>
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(RecursiveBSplineTransform);
 
   /** Standard ITK-stuff. */
-  typedef RecursiveBSplineTransform                       Self;
-  typedef itk::AdvancedCombinationTransform<
-    typename elx::TransformBase< TElastix >::CoordRepType,
-    elx::TransformBase< TElastix >::FixedImageDimension > Superclass1;
-  typedef elx::TransformBase< TElastix >                  Superclass2;
-  typedef itk::SmartPointer< Self >                       Pointer;
-  typedef itk::SmartPointer< const Self >                 ConstPointer;
+  using Self = RecursiveBSplineTransform;
+  using Superclass1 = itk::AdvancedCombinationTransform<typename elx::TransformBase<TElastix>::CoordRepType,
+                                                        elx::TransformBase<TElastix>::FixedImageDimension>;
+  using Superclass2 = elx::TransformBase<TElastix>;
+  using Pointer = itk::SmartPointer<Self>;
+  using ConstPointer = itk::SmartPointer<const Self>;
 
   /** Method for creation through the object factory. */
-  itkNewMacro( Self );
+  itkNewMacro(Self);
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( RecursiveBSplineTransform, itk::AdvancedCombinationTransform );
+  itkTypeMacro(RecursiveBSplineTransform, itk::AdvancedCombinationTransform);
 
   /** Name of this class.
    * Use this name in the parameter file to select this specific transform. \n
    * example: <tt>(Transform "RecursiveBSplineTransform")</tt>\n
    */
-  elxClassNameMacro( "RecursiveBSplineTransform" );
+  elxClassNameMacro("RecursiveBSplineTransform");
 
   /** Dimension of the fixed image. */
-  itkStaticConstMacro( SpaceDimension, unsigned int, Superclass2::FixedImageDimension );
+  itkStaticConstMacro(SpaceDimension, unsigned int, Superclass2::FixedImageDimension);
 
   /** The ITK-class that provides most of the functionality, and
    * that is set as the "CurrentTransform" in the CombinationTransform.
    */
-  typedef itk::AdvancedBSplineDeformableTransformBase<
-    typename elx::TransformBase< TElastix >::CoordRepType,
-    itkGetStaticConstMacro( SpaceDimension ) >             BSplineTransformBaseType;
-  typedef typename BSplineTransformBaseType::Pointer BSplineTransformBasePointer;
-
-  /** Typedef for supported BSplineTransform types. */
-  typedef itk::RecursiveBSplineTransform<
-    typename elx::TransformBase< TElastix >::CoordRepType,
-    itkGetStaticConstMacro( SpaceDimension ),
-    1 >                                                   BSplineTransformLinearType;
-  typedef itk::RecursiveBSplineTransform<
-    typename elx::TransformBase< TElastix >::CoordRepType,
-    itkGetStaticConstMacro( SpaceDimension ),
-    2 >                                                   BSplineTransformQuadraticType;
-  typedef itk::RecursiveBSplineTransform<
-    typename elx::TransformBase< TElastix >::CoordRepType,
-    itkGetStaticConstMacro( SpaceDimension ),
-    3 >                                                   BSplineTransformCubicType;
-  typedef itk::CyclicBSplineDeformableTransform<
-    typename elx::TransformBase< TElastix >::CoordRepType,
-    itkGetStaticConstMacro( SpaceDimension ),
-    1 >                                                   CyclicBSplineTransformLinearType;
-  typedef itk::CyclicBSplineDeformableTransform<
-    typename elx::TransformBase< TElastix >::CoordRepType,
-    itkGetStaticConstMacro( SpaceDimension ),
-    2 >                                                   CyclicBSplineTransformQuadraticType;
-  typedef itk::CyclicBSplineDeformableTransform<
-    typename elx::TransformBase< TElastix >::CoordRepType,
-    itkGetStaticConstMacro( SpaceDimension ),
-    3 >                                                   CyclicBSplineTransformCubicType;
+  using BSplineTransformBaseType =
+    itk::AdvancedBSplineDeformableTransformBase<typename elx::TransformBase<TElastix>::CoordRepType,
+                                                Self::SpaceDimension>;
+  using BSplineTransformBasePointer = typename BSplineTransformBaseType::Pointer;
 
   /** Typedefs inherited from the superclass. */
-  typedef typename Superclass1::ScalarType                ScalarType;
-  typedef typename Superclass1::ParametersType            ParametersType;
-  typedef typename Superclass1::NumberOfParametersType    NumberOfParametersType;
-  typedef typename Superclass1::JacobianType              JacobianType;
-  typedef typename Superclass1::InputVectorType           InputVectorType;
-  typedef typename Superclass1::OutputVectorType          OutputVectorType;
-  typedef typename Superclass1::InputCovariantVectorType  InputCovariantVectorType;
-  typedef typename Superclass1::OutputCovariantVectorType OutputCovariantVectorType;
-  typedef typename Superclass1::InputVnlVectorType        InputVnlVectorType;
-  typedef typename Superclass1::OutputVnlVectorType       OutputVnlVectorType;
-  typedef typename Superclass1::InputPointType            InputPointType;
-  typedef typename Superclass1::OutputPointType           OutputPointType;
+  using typename Superclass1::ScalarType;
+  using typename Superclass1::ParametersType;
+  using typename Superclass1::NumberOfParametersType;
+  using typename Superclass1::JacobianType;
+  using typename Superclass1::InputVectorType;
+  using typename Superclass1::OutputVectorType;
+  using typename Superclass1::InputCovariantVectorType;
+  using typename Superclass1::OutputCovariantVectorType;
+  using typename Superclass1::InputVnlVectorType;
+  using typename Superclass1::OutputVnlVectorType;
+  using typename Superclass1::InputPointType;
+  using typename Superclass1::OutputPointType;
 
   /** Typedef's specific for the BSplineTransform. */
-  typedef typename BSplineTransformBaseType::PixelType     PixelType;
-  typedef typename BSplineTransformBaseType::ImageType     ImageType;
-  typedef typename BSplineTransformBaseType::ImagePointer  ImagePointer;
-  typedef typename BSplineTransformBaseType::RegionType    RegionType;
-  typedef typename BSplineTransformBaseType::IndexType     IndexType;
-  typedef typename BSplineTransformBaseType::SizeType      SizeType;
-  typedef typename BSplineTransformBaseType::SpacingType   SpacingType;
-  typedef typename BSplineTransformBaseType::OriginType    OriginType;
-  typedef typename BSplineTransformBaseType::DirectionType DirectionType;
-  typedef typename
-    BSplineTransformBaseType::ContinuousIndexType ContinuousIndexType;
-  typedef typename
-    BSplineTransformBaseType::ParameterIndexArrayType ParameterIndexArrayType;
+  using PixelType = typename BSplineTransformBaseType::PixelType;
+  using ImageType = typename BSplineTransformBaseType::ImageType;
+  using ImagePointer = typename BSplineTransformBaseType::ImagePointer;
+  using RegionType = typename BSplineTransformBaseType::RegionType;
+  using IndexType = typename BSplineTransformBaseType::IndexType;
+  using SizeType = typename BSplineTransformBaseType::SizeType;
+  using SpacingType = typename BSplineTransformBaseType::SpacingType;
+  using OriginType = typename BSplineTransformBaseType::OriginType;
+  using DirectionType = typename BSplineTransformBaseType::DirectionType;
+  using ContinuousIndexType = typename BSplineTransformBaseType::ContinuousIndexType;
+  using ParameterIndexArrayType = typename BSplineTransformBaseType::ParameterIndexArrayType;
 
   /** Typedef's from TransformBase. */
-  typedef typename Superclass2::ElastixType              ElastixType;
-  typedef typename Superclass2::ElastixPointer           ElastixPointer;
-  typedef typename Superclass2::ConfigurationType        ConfigurationType;
-  typedef typename Superclass2::ConfigurationPointer     ConfigurationPointer;
-  typedef typename Superclass2::RegistrationType         RegistrationType;
-  typedef typename Superclass2::RegistrationPointer      RegistrationPointer;
-  typedef typename Superclass2::CoordRepType             CoordRepType;
-  typedef typename Superclass2::FixedImageType           FixedImageType;
-  typedef typename Superclass2::MovingImageType          MovingImageType;
-  typedef typename Superclass2::ITKBaseType              ITKBaseType;
-  typedef typename Superclass2::CombinationTransformType CombinationTransformType;
+  using typename Superclass2::ElastixType;
+  using typename Superclass2::RegistrationType;
+  using typename Superclass2::CoordRepType;
+  using typename Superclass2::FixedImageType;
+  using typename Superclass2::MovingImageType;
+  using ITKBaseType = typename Superclass2::ITKBaseType;
+  using CombinationTransformType = typename Superclass2::CombinationTransformType;
 
   /** Typedef's for the GridScheduleComputer and the UpsampleBSplineParametersFilter. */
-  typedef itk::GridScheduleComputer<
-    CoordRepType, SpaceDimension >                        GridScheduleComputerType;
-  typedef itk::CyclicGridScheduleComputer<
-    CoordRepType, SpaceDimension >                        CyclicGridScheduleComputerType;
-  typedef typename GridScheduleComputerType::Pointer GridScheduleComputerPointer;
-  typedef typename GridScheduleComputerType
-    ::VectorGridSpacingFactorType GridScheduleType;
-  typedef itk::UpsampleBSplineParametersFilter<
-    ParametersType, ImageType >                           GridUpsamplerType;
-  typedef typename GridUpsamplerType::Pointer GridUpsamplerPointer;
+  using GridScheduleComputerType = itk::GridScheduleComputer<CoordRepType, SpaceDimension>;
+  using CyclicGridScheduleComputerType = itk::CyclicGridScheduleComputer<CoordRepType, SpaceDimension>;
+  using GridScheduleComputerPointer = typename GridScheduleComputerType::Pointer;
+  using GridScheduleType = typename GridScheduleComputerType ::VectorGridSpacingFactorType;
+  using GridUpsamplerType = itk::UpsampleBSplineParametersFilter<ParametersType, ImageType>;
+  using GridUpsamplerPointer = typename GridUpsamplerType::Pointer;
 
   /** Typedef that is used in the elastix dll version. */
-  typedef typename Superclass2::ParameterMapType ParameterMapType;
+  using typename Superclass2::ParameterMapType;
 
   /** Execute stuff before anything else is done:
    * \li Initialize the right BSplineTransform.
    * \li Initialize the right grid schedule computer.
    */
-  int BeforeAll( void ) override;
+  int
+  BeforeAll() override;
 
   /** Execute stuff before the actual registration:
    * \li Create an initial B-spline grid.
@@ -246,61 +210,57 @@ public:
    * the number of parameters in the registration class. This check is done
    * before calling the BeforeEachResolution() methods.
    */
-  void BeforeRegistration( void ) override;
+  void
+  BeforeRegistration() override;
 
   /** Execute stuff before each new pyramid resolution:
    * \li In the first resolution call InitializeTransform().
    * \li In next resolutions upsample the B-spline grid if necessary (so, call IncreaseScale())
    */
-  void BeforeEachResolution( void ) override;
-
-  /** Method to set the initial B-spline grid and initialize the parameters (to 0).
-   * \li Define the initial grid region, origin and spacing, using the precomputed grid information.
-   * \li Set the initial parameters to zero and set then as InitialParametersOfNextLevel in the registration object.
-   * Called by BeforeEachResolution().
-   */
-  virtual void InitializeTransform( void );
+  void
+  BeforeEachResolution() override;
 
   /** Method to increase the density of the B-spline grid.
    * \li Determine the new B-spline coefficients that describe the current deformation field.
    * \li Set these coefficients as InitialParametersOfNextLevel in the registration object.
    * Called by BeforeEachResolution().
    */
-  virtual void IncreaseScale( void );
+  virtual void
+  IncreaseScale();
 
   /** Function to read transform-parameters from a file. */
-  void ReadFromFile( void ) override;
-
-  /** Function to write transform-parameters to a file. */
-  void WriteToFile( const ParametersType & param ) const override;
-
-  /** Function to create transform-parameters map.
-   * Creates the TransformParametersmap as a vector and if wanted
-   * also as a deformation field.
-   */
-  void CreateTransformParametersMap(
-    const ParametersType & param, ParameterMapType * paramsMap ) const override;
+  void
+  ReadFromFile() override;
 
   /** Set the scales of the edge B-spline coefficients to zero. */
-  virtual void SetOptimizerScales( const unsigned int edgeWidth );
+  virtual void
+  SetOptimizerScales(const unsigned int edgeWidth);
 
 protected:
-
   /** The constructor. */
-  RecursiveBSplineTransform();
+  RecursiveBSplineTransform() = default;
 
   /** The destructor. */
-  ~RecursiveBSplineTransform() override {}
+  ~RecursiveBSplineTransform() override = default;
 
   /** Read user-specified grid spacing and call the itkGridScheduleComputer. */
-  virtual void PreComputeGridInformation( void );
+  virtual void
+  PreComputeGridInformation();
 
 private:
+  elxOverrideGetSelfMacro;
 
-  /** The private constructor. */
-  RecursiveBSplineTransform( const Self & );  // purposely not implemented
-  /** The private copy constructor. */
-  void operator=( const Self & );    // purposely not implemented
+  /** Method to set the initial B-spline grid and initialize the parameters (to 0).
+   * \li Define the initial grid region, origin and spacing, using the precomputed grid information.
+   * \li Set the initial parameters to zero and set then as InitialParametersOfNextLevel in the registration object.
+   * Called by BeforeEachResolution().
+   */
+  void
+  InitializeTransform();
+
+  /** Creates a map of the parameters specific for this (derived) transform type. */
+  ParameterMapType
+  CreateDerivedTransformParametersMap() const override;
 
   /** Private variables. */
   BSplineTransformBasePointer m_BSplineTransform;
@@ -312,14 +272,14 @@ private:
   bool         m_Cyclic;
 
   /** Initialize the right B-spline transform based on the spline order and periodicity. */
-  unsigned int InitializeBSplineTransform();
-
+  unsigned int
+  InitializeBSplineTransform();
 };
 
 } // end namespace elastix
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "elxRecursiveBSplineTransform.hxx"
+#  include "elxRecursiveBSplineTransform.hxx"
 #endif
 
-#endif // end #ifndef __elxRecursiveBSplineTransform_h
+#endif // end #ifndef elxRecursiveBSplineTransform_h
