@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __elxSimilarityTransform_H__
-#define __elxSimilarityTransform_H__
+#ifndef elxSimilarityTransform_h
+#define elxSimilarityTransform_h
 
 #include "elxIncludes.h" // include first to avoid MSVS warning
 #include "itkSimilarityTransform.h"
@@ -75,100 +75,138 @@ namespace elastix
  * \ingroup Transforms
  */
 
-template< class TElastix >
-class SimilarityTransformElastix :
-  public itk::AdvancedCombinationTransform<
-  typename elx::TransformBase< TElastix >::CoordRepType,
-  elx::TransformBase< TElastix >::FixedImageDimension >,
-  public elx::TransformBase< TElastix >
+template <class TElastix>
+class ITK_TEMPLATE_EXPORT SimilarityTransformElastix
+  : public itk::AdvancedCombinationTransform<typename elx::TransformBase<TElastix>::CoordRepType,
+                                             elx::TransformBase<TElastix>::FixedImageDimension>
+  , public elx::TransformBase<TElastix>
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(SimilarityTransformElastix);
 
   /** Standard ITK-stuff. */
-  typedef SimilarityTransformElastix Self;
-  typedef itk::AdvancedCombinationTransform<
-    typename elx::TransformBase< TElastix >::CoordRepType,
-    elx::TransformBase< TElastix >::FixedImageDimension >     Superclass1;
-  typedef elx::TransformBase< TElastix >  Superclass2;
-  typedef itk::SmartPointer< Self >       Pointer;
-  typedef itk::SmartPointer< const Self > ConstPointer;
+  using Self = SimilarityTransformElastix;
+  using Superclass1 = itk::AdvancedCombinationTransform<typename elx::TransformBase<TElastix>::CoordRepType,
+                                                        elx::TransformBase<TElastix>::FixedImageDimension>;
+  using Superclass2 = elx::TransformBase<TElastix>;
+  using Pointer = itk::SmartPointer<Self>;
+  using ConstPointer = itk::SmartPointer<const Self>;
 
   /** The ITK-class that provides most of the functionality, and
    * that is set as the "CurrentTransform" in the CombinationTransform */
-  typedef itk::SimilarityTransform<
-    typename elx::TransformBase< TElastix >::CoordRepType,
-    elx::TransformBase< TElastix >::FixedImageDimension >     SimilarityTransformType;
+  using SimilarityTransformType = itk::SimilarityTransform<typename elx::TransformBase<TElastix>::CoordRepType,
+                                                           elx::TransformBase<TElastix>::FixedImageDimension>;
 
   /** Method for creation through the object factory. */
-  itkNewMacro( Self );
+  itkNewMacro(Self);
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( SimilarityTransformElastix, itk::AdvancedCombinationTransform );
+  itkTypeMacro(SimilarityTransformElastix, itk::AdvancedCombinationTransform);
 
   /** Name of this class.
    * Use this name in the parameter file to select this specific transform. \n
    * example: <tt>(Transform "SimilarityTransform")</tt>\n
    */
-  elxClassNameMacro( "SimilarityTransform" );
+  elxClassNameMacro("SimilarityTransform");
 
   /** Dimension of the fixed image. */
-  itkStaticConstMacro( SpaceDimension, unsigned int, Superclass2::FixedImageDimension );
+  itkStaticConstMacro(SpaceDimension, unsigned int, Superclass2::FixedImageDimension);
 
   /** Typedefs inherited from the superclass. */
 
   /** These are both in Similarity2D and Similarity3D. */
-  typedef typename Superclass1::ScalarType             ScalarType;
-  typedef typename Superclass1::ParametersType         ParametersType;
-  typedef typename Superclass1::NumberOfParametersType NumberOfParametersType;
-  typedef typename Superclass1::JacobianType           JacobianType;
+  using typename Superclass1::ScalarType;
+  using typename Superclass1::ParametersType;
+  using typename Superclass1::NumberOfParametersType;
+  using typename Superclass1::JacobianType;
 
-  typedef typename Superclass1::InputPointType            InputPointType;
-  typedef typename Superclass1::OutputPointType           OutputPointType;
-  typedef typename Superclass1::InputVectorType           InputVectorType;
-  typedef typename Superclass1::OutputVectorType          OutputVectorType;
-  typedef typename Superclass1::InputCovariantVectorType  InputCovariantVectorType;
-  typedef typename Superclass1::OutputCovariantVectorType OutputCovariantVectorType;
-  typedef typename Superclass1::InputVnlVectorType        InputVnlVectorType;
-  typedef typename Superclass1::OutputVnlVectorType       OutputVnlVectorType;
+  using typename Superclass1::InputPointType;
+  using typename Superclass1::OutputPointType;
+  using typename Superclass1::InputVectorType;
+  using typename Superclass1::OutputVectorType;
+  using typename Superclass1::InputCovariantVectorType;
+  using typename Superclass1::OutputCovariantVectorType;
+  using typename Superclass1::InputVnlVectorType;
+  using typename Superclass1::OutputVnlVectorType;
 
   /** NOTE: use this one only in 3D (otherwise it's just an int). */
-  typedef typename SimilarityTransformType::Pointer    SimilarityTransformPointer;
-  typedef typename SimilarityTransformType::OffsetType OffsetType;
+  using SimilarityTransformPointer = typename SimilarityTransformType::Pointer;
+  using OffsetType = typename SimilarityTransformType::OffsetType;
 
   /** Typedef's inherited from TransformBase. */
-  typedef typename Superclass2::ElastixType              ElastixType;
-  typedef typename Superclass2::ElastixPointer           ElastixPointer;
-  typedef typename Superclass2::ConfigurationType        ConfigurationType;
-  typedef typename Superclass2::ConfigurationPointer     ConfigurationPointer;
-  typedef typename Superclass2::RegistrationType         RegistrationType;
-  typedef typename Superclass2::RegistrationPointer      RegistrationPointer;
-  typedef typename Superclass2::CoordRepType             CoordRepType;
-  typedef typename Superclass2::FixedImageType           FixedImageType;
-  typedef typename Superclass2::MovingImageType          MovingImageType;
-  typedef typename Superclass2::ITKBaseType              ITKBaseType;
-  typedef typename Superclass2::CombinationTransformType CombinationTransformType;
+  using typename Superclass2::ElastixType;
+  using typename Superclass2::ParameterMapType;
+  using typename Superclass2::RegistrationType;
+  using typename Superclass2::CoordRepType;
+  using typename Superclass2::FixedImageType;
+  using typename Superclass2::MovingImageType;
+  using ITKBaseType = typename Superclass2::ITKBaseType;
+  using CombinationTransformType = typename Superclass2::CombinationTransformType;
 
   /** Other typedef's. */
-  typedef typename FixedImageType::IndexType     IndexType;
-  typedef typename IndexType::IndexValueType     IndexValueType;
-  typedef typename FixedImageType::SizeType      SizeType;
-  typedef typename FixedImageType::PointType     PointType;
-  typedef typename FixedImageType::SpacingType   SpacingType;
-  typedef typename FixedImageType::RegionType    RegionType;
-  typedef typename FixedImageType::DirectionType DirectionType;
+  using IndexType = typename FixedImageType::IndexType;
+  using IndexValueType = typename IndexType::IndexValueType;
+  using SizeType = typename FixedImageType::SizeType;
+  using PointType = typename FixedImageType::PointType;
+  using SpacingType = typename FixedImageType::SpacingType;
+  using RegionType = typename FixedImageType::RegionType;
+  using DirectionType = typename FixedImageType::DirectionType;
 
-  typedef itk::CenteredTransformInitializer<
-    SimilarityTransformType, FixedImageType, MovingImageType > TransformInitializerType;
-  typedef typename TransformInitializerType::Pointer TransformInitializerPointer;
+  using TransformInitializerType =
+    itk::CenteredTransformInitializer<SimilarityTransformType, FixedImageType, MovingImageType>;
+  using TransformInitializerPointer = typename TransformInitializerType::Pointer;
 
   /** For scales setting in the optimizer */
-  typedef typename Superclass2::ScalesType ScalesType;
+  using typename Superclass2::ScalesType;
 
   /** Execute stuff before the actual registration:
    * \li Call InitializeTransform
    * \li Set the scales.
    */
-  void BeforeRegistration( void ) override;
+  void
+  BeforeRegistration() override;
+
+  /** Set the scales
+   * \li If AutomaticScalesEstimation is "true" estimate scales
+   * \li If scales are provided by the user use those,
+   * \li Otherwise use some default value
+   * This function is called by BeforeRegistration, after
+   * the InitializeTransform function is called
+   */
+  virtual void
+  SetScales();
+
+  /** Function to read transform-parameters from a file.
+   *
+   * It reads the center of rotation and calls the superclass' implementation.
+   */
+  void
+  ReadFromFile() override;
+
+protected:
+  /** The constructor. */
+  SimilarityTransformElastix();
+  /** The destructor. */
+  ~SimilarityTransformElastix() override = default;
+
+  /** Try to read the CenterOfRotation from the transform parameter file
+   * This is an index value, and, thus, converted to world coordinates.
+   * Transform parameter files generated by elastix version < 3.402
+   * saved the center of rotation in this way.
+   */
+  virtual bool
+  ReadCenterOfRotationIndex(InputPointType & rotationPoint) const;
+
+  /** Try to read the CenterOfRotationPoint from the transform parameter file
+   * The CenterOfRotationPoint is already in world coordinates.
+   * Transform parameter files generated by elastix version > 3.402
+   * save the center of rotation in this way.
+   */
+  virtual bool
+  ReadCenterOfRotationPoint(InputPointType & rotationPoint) const;
+
+private:
+  elxOverrideGetSelfMacro;
 
   /** Initialize Transform.
    * \li Set all parameters to zero.
@@ -185,64 +223,20 @@ public:
    *
    * It is not yet possible to enter an initial rotation angle.
    */
-  virtual void InitializeTransform( void );
+  void
+  InitializeTransform();
 
-  /** Set the scales
-   * \li If AutomaticScalesEstimation is "true" estimate scales
-   * \li If scales are provided by the user use those,
-   * \li Otherwise use some default value
-   * This function is called by BeforeRegistration, after
-   * the InitializeTransform function is called
-   */
-  virtual void SetScales( void );
-
-  /** Function to read transform-parameters from a file.
-   *
-   * It reads the center of rotation and calls the superclass' implementation.
-   */
-  void ReadFromFile( void ) override;
-
-  /** Function to write transform-parameters to a file.
-   * It writes the center of rotation to file and calls the superclass' implementation.
-   */
-  void WriteToFile( const ParametersType & param ) const override;
-
-protected:
-
-  /** The constructor. */
-  SimilarityTransformElastix();
-  /** The destructor. */
-  ~SimilarityTransformElastix() override {}
-
-  /** Try to read the CenterOfRotation from the transform parameter file
-   * This is an index value, and, thus, converted to world coordinates.
-   * Transform parameter files generated by elastix version < 3.402
-   * saved the center of rotation in this way.
-   */
-  virtual bool ReadCenterOfRotationIndex( InputPointType & rotationPoint ) const;
-
-  /** Try to read the CenterOfRotationPoint from the transform parameter file
-   * The CenterOfRotationPoint is already in world coordinates.
-   * Transform parameter files generated by elastix version > 3.402
-   * save the center of rotation in this way.
-   */
-  virtual bool ReadCenterOfRotationPoint( InputPointType & rotationPoint ) const;
-
-private:
-
-  /** The private constructor. */
-  SimilarityTransformElastix( const Self & );   // purposely not implemented
-  /** The private copy constructor. */
-  void operator=( const Self & );         // purposely not implemented
-
-  SimilarityTransformPointer m_SimilarityTransform;
+  /** Creates a map of the parameters specific for this (derived) transform type. */
+  ParameterMapType
+  CreateDerivedTransformParametersMap() const override;
 
+  const SimilarityTransformPointer m_SimilarityTransform{ SimilarityTransformType::New() };
 };
 
 } // end namespace elastix
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "elxSimilarityTransform.hxx"
+#  include "elxSimilarityTransform.hxx"
 #endif
 
-#endif // end #ifndef __elxSimilarityTransform_H__
+#endif // end #ifndef elxSimilarityTransform_h
