@@ -19,7 +19,6 @@
 
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkElasticBodyReciprocalSplineKernelTransform2.h,v $
-  Language:  C++
   Date:      $Date: 2006/04/17 01:50:19 $
   Version:   $Revision: 1.8 $
 
@@ -31,8 +30,8 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef __itkElasticBodyReciprocalSplineKernelTransform2_h
-#define __itkElasticBodyReciprocalSplineKernelTransform2_h
+#ifndef itkElasticBodyReciprocalSplineKernelTransform2_h
+#define itkElasticBodyReciprocalSplineKernelTransform2_h
 
 #include "itkKernelTransform2.h"
 
@@ -51,90 +50,93 @@ namespace itk
  *
  * \ingroup Transforms
  */
-template< class TScalarType = double,   // Data type for scalars (float or double)
-unsigned int NDimensions    = 3 >
+template <class TScalarType = double, // Data type for scalars (float or double)
+          unsigned int NDimensions = 3>
 // Number of dimensions
-class ElasticBodyReciprocalSplineKernelTransform2 :
-  public KernelTransform2<  TScalarType, NDimensions >
+class ITK_TEMPLATE_EXPORT ElasticBodyReciprocalSplineKernelTransform2
+  : public KernelTransform2<TScalarType, NDimensions>
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(ElasticBodyReciprocalSplineKernelTransform2);
 
   /** Standard class typedefs. */
-  typedef ElasticBodyReciprocalSplineKernelTransform2 Self;
-  typedef KernelTransform2<  TScalarType,
-    NDimensions > Superclass;
+  using Self = ElasticBodyReciprocalSplineKernelTransform2;
+  using Superclass = KernelTransform2<TScalarType, NDimensions>;
 
-  typedef SmartPointer< Self >       Pointer;
-  typedef SmartPointer< const Self > ConstPointer;
+  using Pointer = SmartPointer<Self>;
+  using ConstPointer = SmartPointer<const Self>;
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( ElasticBodyReciprocalSplineKernelTransform2, KernelTransform2 );
+  itkTypeMacro(ElasticBodyReciprocalSplineKernelTransform2, KernelTransform2);
 
   /** New macro for creation of through a Smart Pointer */
-  itkNewMacro( Self );
+  itkNewMacro(Self);
 
   /** Scalar type. */
-  typedef typename Superclass::ScalarType ScalarType;
+  using typename Superclass::ScalarType;
 
   /** Parameters type. */
-  typedef typename Superclass::ParametersType ParametersType;
+  using typename Superclass::ParametersType;
 
   /** Jacobian type. */
-  typedef typename Superclass::JacobianType JacobianType;
+  using typename Superclass::JacobianType;
 
   /** Dimension of the domain space. */
-  itkStaticConstMacro( SpaceDimension, unsigned int, Superclass::SpaceDimension );
+  itkStaticConstMacro(SpaceDimension, unsigned int, Superclass::SpaceDimension);
 
   /** Set alpha.  Alpha is related to Poisson's Ratio (\f$\nu\f$) as
    * \f$\alpha = 8 ( 1 - \nu ) - 1\f$
    */
-  //itkSetMacro( Alpha, TScalarType ); Cant use the macro because the matrices must be recomputed
-  void SetAlpha( TScalarType Alpha ) override
+  // itkSetMacro( Alpha, TScalarType ); Cant use the macro because the matrices must be recomputed
+  void
+  SetAlpha(TScalarType Alpha) override
   {
-    this->m_Alpha            = Alpha;
-    this->m_LMatrixComputed  = false;
+    this->m_Alpha = Alpha;
+    this->m_LMatrixComputed = false;
     this->m_LInverseComputed = false;
-    this->m_WMatrixComputed  = false;
+    this->m_WMatrixComputed = false;
   }
 
 
   /** Get alpha */
-  elxOverrideGetConstMacro(Alpha, TScalarType);
+  itkGetConstMacro(Alpha, TScalarType);
 
   /** Convenience method */
-  void SetPoissonRatio( const TScalarType Nu ) override
+  void
+  SetPoissonRatio(const TScalarType Nu) override
   {
-    if( Nu > -1.0 && Nu < 0.5 )
+    if (Nu > -1.0 && Nu < 0.5)
     {
-      this->SetAlpha( 8.0 * ( 1.0 - Nu ) - 1.0 );
+      this->SetAlpha(8.0 * (1.0 - Nu) - 1.0);
     }
   }
 
 
-  const TScalarType GetPoissonRatio( void ) const override
+  const TScalarType
+  GetPoissonRatio() const override
   {
-    return 1.0 - ( this->m_Alpha + 1.0 ) / 8.0;
+    return 1.0 - (this->m_Alpha + 1.0) / 8.0;
   }
 
 
   /** These (rather redundant) typedefs are needed because on SGI, typedefs
    * are not inherited */
-  typedef typename Superclass::InputPointType            InputPointType;
-  typedef typename Superclass::OutputPointType           OutputPointType;
-  typedef typename Superclass::InputVectorType           InputVectorType;
-  typedef typename Superclass::OutputVectorType          OutputVectorType;
-  typedef typename Superclass::InputCovariantVectorType  InputCovariantVectorType;
-  typedef typename Superclass::OutputCovariantVectorType OutputCovariantVectorType;
+  using typename Superclass::InputPointType;
+  using typename Superclass::OutputPointType;
+  using typename Superclass::InputVectorType;
+  using typename Superclass::OutputVectorType;
+  using typename Superclass::InputCovariantVectorType;
+  using typename Superclass::OutputCovariantVectorType;
 
 protected:
-
   ElasticBodyReciprocalSplineKernelTransform2();
-  ~ElasticBodyReciprocalSplineKernelTransform2() override {}
-  void PrintSelf( std::ostream & os, Indent indent ) const override;
+  ~ElasticBodyReciprocalSplineKernelTransform2() override = default;
+  void
+  PrintSelf(std::ostream & os, Indent indent) const override;
 
   /** These (rather redundant) typedefs are needed because on SGI, typedefs
    * are not inherited */
-  typedef typename Superclass::GMatrixType GMatrixType;
+  using typename Superclass::GMatrixType;
 
   /** Compute G(x)
    * For the elastic body spline, this is:
@@ -144,22 +146,17 @@ protected:
    * \f$r(x) = \sqrt{ x_1^2 + x_2^2 + x_3^2 } \f$ and
    * \f$I\f$ is the identity matrix.
    */
-  void ComputeG( const InputVectorType & x, GMatrixType & GMatrix ) const override;
+  void
+  ComputeG(const InputVectorType & x, GMatrixType & GMatrix) const override;
 
   /** alpha, Poisson's ratio */
   TScalarType m_Alpha;
-
-private:
-
-  ElasticBodyReciprocalSplineKernelTransform2( const Self & ); // purposely not implemented
-  void operator=( const Self & );                              // purposely not implemented
-
 };
 
 } // namespace itk
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "itkElasticBodyReciprocalSplineKernelTransform2.hxx"
+#  include "itkElasticBodyReciprocalSplineKernelTransform2.hxx"
 #endif
 
-#endif // __itkElasticBodyReciprocalSplineKernelTransform2_h
+#endif // itkElasticBodyReciprocalSplineKernelTransform2_h
