@@ -31,8 +31,8 @@ the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef __itkKernelTransform2_h
-#define __itkKernelTransform2_h
+#ifndef itkKernelTransform2_h
+#define itkKernelTransform2_h
 
 #include "itkAdvancedTransform.h"
 #include "itkPoint.h"
@@ -41,13 +41,13 @@ PURPOSE.  See the above copyright notices for more information.
 #include "itkPointSet.h"
 #include <deque>
 #include <math.h>
-#include "vnl/vnl_matrix_fixed.h"
-#include "vnl/vnl_matrix.h"
-#include "vnl/vnl_vector.h"
-#include "vnl/vnl_vector_fixed.h"
-#include "vnl/vnl_sample.h"
-#include "vnl/algo/vnl_svd.h"
-#include "vnl/algo/vnl_qr.h"
+#include <vnl/vnl_matrix_fixed.h>
+#include <vnl/vnl_matrix.h>
+#include <vnl/vnl_vector.h>
+#include <vnl/vnl_vector_fixed.h>
+#include <vnl/vnl_sample.h>
+#include <vnl/algo/vnl_svd.h>
+#include <vnl/algo/vnl_qr.h>
 
 namespace itk
 {
@@ -91,163 +91,165 @@ namespace itk
  *
  */
 
-template< class TScalarType, // probably only float and double make sense here
-unsigned int NDimensions >
+template <class TScalarType, // probably only float and double make sense here
+          unsigned int NDimensions>
 // Number of dimensions
-class KernelTransform2 :
-  public AdvancedTransform< TScalarType, NDimensions, NDimensions >
+class ITK_TEMPLATE_EXPORT KernelTransform2 : public AdvancedTransform<TScalarType, NDimensions, NDimensions>
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(KernelTransform2);
 
   /** Standard class typedefs. */
-  typedef KernelTransform2 Self;
-  typedef AdvancedTransform<
-    TScalarType, NDimensions, NDimensions > Superclass;
-  typedef SmartPointer< Self >       Pointer;
-  typedef SmartPointer< const Self > ConstPointer;
+  using Self = KernelTransform2;
+  using Superclass = AdvancedTransform<TScalarType, NDimensions, NDimensions>;
+  using Pointer = SmartPointer<Self>;
+  using ConstPointer = SmartPointer<const Self>;
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( KernelTransform2, AdvancedTransform );
+  itkTypeMacro(KernelTransform2, AdvancedTransform);
 
   /** New macro for creation of through a Smart Pointer. */
-  itkNewMacro( Self );
+  itkNewMacro(Self);
 
   /** Dimension of the domain space. */
-  itkStaticConstMacro( SpaceDimension, unsigned int, NDimensions );
+  itkStaticConstMacro(SpaceDimension, unsigned int, NDimensions);
 
   /** Typedefs. */
-  typedef typename Superclass::ScalarType                ScalarType;
-  typedef typename Superclass::ParametersType            ParametersType;
-  typedef typename Superclass::NumberOfParametersType    NumberOfParametersType;
-  typedef typename Superclass::JacobianType              JacobianType;
-  typedef typename Superclass::InputPointType            InputPointType;
-  typedef typename Superclass::OutputPointType           OutputPointType;
-  typedef typename Superclass::InputVectorType           InputVectorType;
-  typedef typename Superclass::OutputVectorType          OutputVectorType;
-  typedef typename Superclass::InputCovariantVectorType  InputCovariantVectorType;
-  typedef typename Superclass::OutputCovariantVectorType OutputCovariantVectorType;
-  typedef typename Superclass::InputVnlVectorType        InputVnlVectorType;
-  typedef typename Superclass::OutputVnlVectorType       OutputVnlVectorType;
+  using typename Superclass::ScalarType;
+  using typename Superclass::ParametersType;
+  using typename Superclass::NumberOfParametersType;
+  using typename Superclass::JacobianType;
+  using typename Superclass::InputPointType;
+  using typename Superclass::OutputPointType;
+  using typename Superclass::InputVectorType;
+  using typename Superclass::OutputVectorType;
+  using typename Superclass::InputCovariantVectorType;
+  using typename Superclass::OutputCovariantVectorType;
+  using typename Superclass::InputVnlVectorType;
+  using typename Superclass::OutputVnlVectorType;
 
   /** AdvancedTransform typedefs. */
-  typedef typename Superclass
-    ::NonZeroJacobianIndicesType NonZeroJacobianIndicesType;
-  typedef typename Superclass::SpatialJacobianType SpatialJacobianType;
-  typedef typename Superclass
-    ::JacobianOfSpatialJacobianType JacobianOfSpatialJacobianType;
-  typedef typename Superclass::SpatialHessianType SpatialHessianType;
-  typedef typename Superclass
-    ::JacobianOfSpatialHessianType JacobianOfSpatialHessianType;
-  typedef typename Superclass::InternalMatrixType InternalMatrixType;
+  using typename Superclass::NonZeroJacobianIndicesType;
+  using typename Superclass::SpatialJacobianType;
+  using typename Superclass::JacobianOfSpatialJacobianType;
+  using typename Superclass::SpatialHessianType;
+  using typename Superclass::JacobianOfSpatialHessianType;
+  using typename Superclass::InternalMatrixType;
 
   /** PointList typedef. This type is used for maintaining lists of points,
    * specifically, the source and target landmark lists.
    */
-  typedef DefaultStaticMeshTraits< TScalarType,
-    NDimensions, NDimensions, TScalarType, TScalarType >       PointSetTraitsType;
-  typedef PointSet< InputPointType, NDimensions,
-    PointSetTraitsType >                                       PointSetType;
-  typedef typename PointSetType::Pointer                      PointSetPointer;
-  typedef typename PointSetType::PointsContainer              PointsContainer;
-  typedef typename PointSetType::PointsContainerIterator      PointsIterator;
-  typedef typename PointSetType::PointsContainerConstIterator PointsConstIterator;
+  using PointSetTraitsType = DefaultStaticMeshTraits<TScalarType, NDimensions, NDimensions, TScalarType, TScalarType>;
+  using PointSetType = PointSet<InputPointType, NDimensions, PointSetTraitsType>;
+  using PointSetPointer = typename PointSetType::Pointer;
+  using PointsContainer = typename PointSetType::PointsContainer;
+  using PointsIterator = typename PointSetType::PointsContainerIterator;
+  using PointsConstIterator = typename PointSetType::PointsContainerConstIterator;
 
   /** VectorSet typedef. */
-  typedef VectorContainer< unsigned long, InputVectorType > VectorSetType;
-  typedef typename VectorSetType::Pointer                   VectorSetPointer;
+  using VectorSetType = VectorContainer<unsigned long, InputVectorType>;
+  using VectorSetPointer = typename VectorSetType::Pointer;
 
   /** 'I' (identity) matrix typedef. */
-  typedef vnl_matrix_fixed< TScalarType, NDimensions, NDimensions > IMatrixType;
+  using IMatrixType = vnl_matrix_fixed<TScalarType, NDimensions, NDimensions>;
 
   /** Return the number of parameters that completely define the Transform. */
-  NumberOfParametersType GetNumberOfParameters( void ) const override
+  NumberOfParametersType
+  GetNumberOfParameters() const override
   {
-    return ( this->m_SourceLandmarks->GetNumberOfPoints() * SpaceDimension );
+    return (this->m_SourceLandmarks->GetNumberOfPoints() * SpaceDimension);
   }
 
 
   /** Get the source landmarks list, which we will denote \f$ p \f$. */
-  itkGetModifiableObjectMacro( SourceLandmarks, PointSetType );
+  itkGetModifiableObjectMacro(SourceLandmarks, PointSetType);
 
   /** Set the source landmarks list. */
-  virtual void SetSourceLandmarks( PointSetType * );
+  virtual void
+  SetSourceLandmarks(PointSetType *);
 
   /** Get the target landmarks list, which we will denote  \f$ q \f$. */
-  itkGetModifiableObjectMacro( TargetLandmarks, PointSetType );
+  itkGetModifiableObjectMacro(TargetLandmarks, PointSetType);
 
   /** Set the target landmarks list. */
-  virtual void SetTargetLandmarks( PointSetType * );
+  virtual void
+  SetTargetLandmarks(PointSetType *);
 
   /** Get the displacements list, which we will denote \f$ d \f$,
    * where \f$ d_i = q_i - p_i \f$.
    */
-  itkGetModifiableObjectMacro( Displacements, VectorSetType );
+  itkGetModifiableObjectMacro(Displacements, VectorSetType);
 
   /** Compute W matrix. */
-  void ComputeWMatrix( void );
+  void
+  ComputeWMatrix();
 
   /** Compute L matrix inverse. */
-  void ComputeLInverse( void );
+  void
+  ComputeLInverse();
 
   /** Compute the position of point in the new space */
-  OutputPointType TransformPoint( const InputPointType & thisPoint ) const override;
+  OutputPointType
+  TransformPoint(const InputPointType & thisPoint) const override;
 
   /** These vector transforms are not implemented for this transform. */
-  OutputVectorType TransformVector( const InputVectorType & ) const override
+  OutputVectorType
+  TransformVector(const InputVectorType &) const override
   {
-    itkExceptionMacro(
-        << "TransformVector(const InputVectorType &) is not implemented "
-        << "for KernelTransform" );
+    itkExceptionMacro(<< "TransformVector(const InputVectorType &) is not implemented for KernelTransform");
   }
 
 
-  OutputVnlVectorType TransformVector( const InputVnlVectorType & ) const override
+  OutputVnlVectorType
+  TransformVector(const InputVnlVectorType &) const override
   {
-    itkExceptionMacro(
-        << "TransformVector(const InputVnlVectorType &) is not implemented "
-        << "for KernelTransform" );
+    itkExceptionMacro(<< "TransformVector(const InputVnlVectorType &) is not implemented for KernelTransform");
   }
 
 
-  OutputCovariantVectorType TransformCovariantVector( const InputCovariantVectorType & ) const override
+  OutputCovariantVectorType
+  TransformCovariantVector(const InputCovariantVectorType &) const override
   {
     itkExceptionMacro(
-        << "TransformCovariantVector(const InputCovariantVectorType &) is not implemented "
-        << "for KernelTransform" );
+      << "TransformCovariantVector(const InputCovariantVectorType &) is not implemented for KernelTransform");
   }
 
 
   /** Compute the Jacobian of the transformation. */
-  void GetJacobian(
-    const InputPointType &,
-    JacobianType &,
-    NonZeroJacobianIndicesType & ) const override;
+  void
+  GetJacobian(const InputPointType &, JacobianType &, NonZeroJacobianIndicesType &) const override;
 
   /** Set the Transformation Parameters to be an identity transform. */
-  virtual void SetIdentity( void );
+  virtual void
+  SetIdentity();
 
   /** Set the Transformation Parameters and update the internal transformation.
    * The parameters represent the source landmarks. Each landmark point is represented
    * by NDimensions doubles. All the landmarks are concatenated to form one flat
    * Array<double>.
    */
-  void SetParameters( const ParametersType & ) override;
+  void
+  SetParameters(const ParametersType &) override;
 
   /** Set Transform Fixed Parameters:
    *     To support the transform file writer this function was
    *     added to set the target landmarks similar to the
    *     SetParameters function setting the source landmarks
    */
-  void SetFixedParameters( const ParametersType & ) override;
+  void
+  SetFixedParameters(const ParametersType &) override;
 
   /** Update the Parameters array from the landmarks coordinates. */
-  virtual void UpdateParameters( void );
+  virtual void
+  UpdateParameters();
 
   /** Get the Transformation Parameters - Gets the source landmarks. */
-  const ParametersType & GetParameters( void ) const override;
+  const ParametersType &
+  GetParameters() const override;
 
   /** Get Transform Fixed Parameters - Gets the target landmarks. */
-  const ParametersType & GetFixedParameters( void ) const override;
+  const ParametersType &
+  GetFixedParameters() const override;
 
   /** Stiffness of the spline.  A stiffness of zero results in the
    * standard interpolating spline.  A non-zero stiffness allows the
@@ -259,16 +261,17 @@ public:
    * International Conference of the IEEE Engineering in Medicine and
    * Biology Society. 1996.
    */
-  virtual void SetStiffness( double stiffness )
+  virtual void
+  SetStiffness(double stiffness)
   {
-    this->m_Stiffness        = stiffness > 0 ? stiffness : 0.0;
-    this->m_LMatrixComputed  = false;
+    this->m_Stiffness = stiffness > 0 ? stiffness : 0.0;
+    this->m_LMatrixComputed = false;
     this->m_LInverseComputed = false;
-    this->m_WMatrixComputed  = false;
+    this->m_WMatrixComputed = false;
   }
 
 
-  itkGetMacro( Stiffness, double );
+  itkGetConstMacro(Stiffness, double);
 
   /** This method makes only sense for the ElasticBody splines.
    * Declare here, so that you can always call it if you don't know
@@ -276,8 +279,9 @@ public:
    * ElasticBodySplineKernelTransform and in the
    * ElasticBodyReciprocalSplineKernelTransform.
    */
-  virtual void SetAlpha( TScalarType itkNotUsed( Alpha ) ) {}
-  virtual TScalarType GetAlpha( void ) const { return -1.0; }
+  virtual void
+  SetAlpha(TScalarType itkNotUsed(Alpha))
+  {}
 
   /** This method makes only sense for the ElasticBody splines.
    * Declare here, so that you can always call it if you don't know
@@ -285,106 +289,110 @@ public:
    * ElasticBodySplineKernelTransform and in the
    * ElasticBodyReciprocalSplineKernelTransform.
    */
-  itkSetMacro( PoissonRatio, TScalarType );
-  virtual const TScalarType GetPoissonRatio( void ) const
+  itkSetMacro(PoissonRatio, TScalarType);
+  virtual const TScalarType
+  GetPoissonRatio() const
   {
     return this->m_PoissonRatio;
   }
 
 
   /** Matrix inversion by SVD or QR decomposition. */
-  itkSetMacro( MatrixInversionMethod, std::string );
-  itkGetConstReferenceMacro( MatrixInversionMethod, std::string );
+  itkSetMacro(MatrixInversionMethod, std::string);
+  itkGetConstReferenceMacro(MatrixInversionMethod, std::string);
 
   /** Must be provided. */
-  void GetSpatialJacobian(
-    const InputPointType & ipp, SpatialJacobianType & sj ) const override
+  void
+  GetSpatialJacobian(const InputPointType & inputPoint, SpatialJacobianType & sj) const override
   {
-    itkExceptionMacro( << "Not implemented for KernelTransform2" );
+    itkExceptionMacro(<< "Not implemented for KernelTransform2");
   }
 
 
-  void GetSpatialHessian(
-    const InputPointType & ipp, SpatialHessianType & sh ) const override
+  void
+  GetSpatialHessian(const InputPointType & inputPoint, SpatialHessianType & sh) const override
   {
-    itkExceptionMacro( << "Not implemented for KernelTransform2" );
+    itkExceptionMacro(<< "Not implemented for KernelTransform2");
   }
 
 
-  void GetJacobianOfSpatialJacobian(
-    const InputPointType & ipp, JacobianOfSpatialJacobianType & jsj,
-    NonZeroJacobianIndicesType & nonZeroJacobianIndices ) const override
+  void
+  GetJacobianOfSpatialJacobian(const InputPointType &          inputPoint,
+                               JacobianOfSpatialJacobianType & jsj,
+                               NonZeroJacobianIndicesType &    nonZeroJacobianIndices) const override
   {
-    itkExceptionMacro( << "Not implemented for KernelTransform2" );
+    itkExceptionMacro(<< "Not implemented for KernelTransform2");
   }
 
 
-  void GetJacobianOfSpatialJacobian(
-    const InputPointType & ipp, SpatialJacobianType & sj,
-    JacobianOfSpatialJacobianType & jsj,
-    NonZeroJacobianIndicesType & nonZeroJacobianIndices ) const override
+  void
+  GetJacobianOfSpatialJacobian(const InputPointType &          inputPoint,
+                               SpatialJacobianType &           sj,
+                               JacobianOfSpatialJacobianType & jsj,
+                               NonZeroJacobianIndicesType &    nonZeroJacobianIndices) const override
   {
-    itkExceptionMacro( << "Not implemented for KernelTransform2" );
+    itkExceptionMacro(<< "Not implemented for KernelTransform2");
   }
 
 
-  void GetJacobianOfSpatialHessian(
-    const InputPointType & ipp, JacobianOfSpatialHessianType & jsh,
-    NonZeroJacobianIndicesType & nonZeroJacobianIndices ) const override
+  void
+  GetJacobianOfSpatialHessian(const InputPointType &         inputPoint,
+                              JacobianOfSpatialHessianType & jsh,
+                              NonZeroJacobianIndicesType &   nonZeroJacobianIndices) const override
   {
-    itkExceptionMacro( << "Not implemented for KernelTransform2" );
+    itkExceptionMacro(<< "Not implemented for KernelTransform2");
   }
 
 
-  void GetJacobianOfSpatialHessian(
-    const InputPointType & ipp, SpatialHessianType & sh,
-    JacobianOfSpatialHessianType & jsh,
-    NonZeroJacobianIndicesType & nonZeroJacobianIndices ) const override
+  void
+  GetJacobianOfSpatialHessian(const InputPointType &         inputPoint,
+                              SpatialHessianType &           sh,
+                              JacobianOfSpatialHessianType & jsh,
+                              NonZeroJacobianIndicesType &   nonZeroJacobianIndices) const override
   {
-    itkExceptionMacro( << "Not implemented for KernelTransform2" );
+    itkExceptionMacro(<< "Not implemented for KernelTransform2");
   }
 
 
 protected:
-
   KernelTransform2();
   ~KernelTransform2() override;
-  void PrintSelf( std::ostream & os, Indent indent ) const override;
+  void
+  PrintSelf(std::ostream & os, Indent indent) const override;
 
 public:
-
   /** 'G' matrix typedef. */
-  typedef vnl_matrix_fixed< TScalarType, NDimensions, NDimensions > GMatrixType;
+  using GMatrixType = vnl_matrix_fixed<TScalarType, NDimensions, NDimensions>;
 
   /** 'L' matrix typedef. */
-  typedef vnl_matrix< TScalarType > LMatrixType;
+  using LMatrixType = vnl_matrix<TScalarType>;
 
   /** 'K' matrix typedef. */
-  typedef vnl_matrix< TScalarType > KMatrixType;
+  using KMatrixType = vnl_matrix<TScalarType>;
 
   /** 'P' matrix typedef. */
-  typedef vnl_matrix< TScalarType > PMatrixType;
+  using PMatrixType = vnl_matrix<TScalarType>;
 
   /** 'Y' matrix typedef. */
-  typedef vnl_matrix< TScalarType > YMatrixType;
+  using YMatrixType = vnl_matrix<TScalarType>;
 
   /** 'W' matrix typedef. */
-  typedef vnl_matrix< TScalarType > WMatrixType;
+  using WMatrixType = vnl_matrix<TScalarType>;
 
   /** 'D' matrix typedef. Deformation component */
-  typedef vnl_matrix< TScalarType > DMatrixType;
+  using DMatrixType = vnl_matrix<TScalarType>;
 
   /** 'A' matrix typedef. Rotational part of the Affine component */
-  typedef vnl_matrix_fixed< TScalarType, NDimensions, NDimensions > AMatrixType;
+  using AMatrixType = vnl_matrix_fixed<TScalarType, NDimensions, NDimensions>;
 
   /** 'B' matrix typedef. Translational part of the Affine component */
-  typedef vnl_vector_fixed< TScalarType, NDimensions > BMatrixType;
+  using BMatrixType = vnl_vector_fixed<TScalarType, NDimensions>;
 
   /** Row matrix typedef. */
-  typedef vnl_matrix_fixed< TScalarType, 1, NDimensions > RowMatrixType;
+  using RowMatrixType = vnl_matrix_fixed<TScalarType, 1, NDimensions>;
 
   /** Column matrix typedef. */
-  typedef vnl_matrix_fixed< TScalarType, NDimensions, 1 > ColumnMatrixType;
+  using ColumnMatrixType = vnl_matrix_fixed<TScalarType, NDimensions, 1>;
 
   /** The list of source landmarks, denoted 'p'. */
   PointSetPointer m_SourceLandmarks;
@@ -393,7 +401,6 @@ public:
   PointSetPointer m_TargetLandmarks;
 
 protected:
-
   /** Compute G(x)
    * This is essentially the kernel of the transform.
    * By overriding this method, we can obtain (among others):
@@ -401,8 +408,8 @@ protected:
    *    Thin plate spline
    *    Volume spline.
    */
-  virtual void ComputeG( const InputVectorType & landmarkVector,
-    GMatrixType & GMatrix ) const;
+  virtual void
+  ComputeG(const InputVectorType & landmarkVector, GMatrixType & GMatrix) const;
 
   /** Compute a G(x) for a point to itself (i.e. for the block
    * diagonal elements of the matrix K. Parameter indicates for which
@@ -411,35 +418,41 @@ protected:
    * matrix where the diagonal elements are the stiffness of the
    * spline.
    */
-  virtual void ComputeReflexiveG( PointsIterator, GMatrixType & GMatrix ) const;
+  virtual void
+  ComputeReflexiveG(PointsIterator, GMatrixType & GMatrix) const;
 
   /** Compute the contribution of the landmarks weighted by the kernel
    * function to the global deformation of the space.
    */
-  virtual void ComputeDeformationContribution(
-    const InputPointType & inputPoint,
-    OutputPointType & result ) const;
+  virtual void
+  ComputeDeformationContribution(const InputPointType & inputPoint, OutputPointType & result) const;
 
   /** Compute K matrix. */
-  void ComputeK( void );
+  void
+  ComputeK();
 
   /** Compute L matrix. */
-  void ComputeL( void );
+  void
+  ComputeL();
 
   /** Compute P matrix. */
-  void ComputeP( void );
+  void
+  ComputeP();
 
   /** Compute Y matrix. */
-  void ComputeY( void );
+  void
+  ComputeY();
 
   /** Compute displacements \f$ q_i - p_i \f$. */
-  void ComputeD( void );
+  void
+  ComputeD();
 
   /** Reorganize the components of W into D (deformable), A (rotation part
    * of affine) and B (translational part of affine ) components.
    * \warning This method release the memory of the W Matrix.
    */
-  void ReorganizeW( void );
+  void
+  ReorganizeW();
 
   /** Stiffness parameter. */
   double m_Stiffness;
@@ -485,7 +498,7 @@ protected:
    * copying the matrix at return time but this is not necessary.
    * SK: we don't need this matrix anymore as a member.
    */
-  //GMatrixType m_GMatrix;
+  // GMatrixType m_GMatrix;
 
   /** Has the W matrix been computed? */
   bool m_WMatrixComputed;
@@ -502,8 +515,8 @@ protected:
    * turn calls ComputeWMatrix(). The L matrix is not changed however, and therefore
    * it is not needed to redo the decomposition.
    */
-  typedef vnl_svd< ScalarType > SVDDecompositionType;
-  typedef vnl_qr< ScalarType >  QRDecompositionType;
+  using SVDDecompositionType = vnl_svd<ScalarType>;
+  using QRDecompositionType = vnl_qr<ScalarType>;
 
   SVDDecompositionType * m_LMatrixDecompositionSVD;
   QRDecompositionType *  m_LMatrixDecompositionQR;
@@ -514,30 +527,22 @@ protected:
   /** Precomputed nonzero Jacobian indices (simply all params) */
   NonZeroJacobianIndicesType m_NonZeroJacobianIndices;
 
-  /** for old GetJacobian() method: */
-  mutable NonZeroJacobianIndicesType m_NonZeroJacobianIndicesTemp;
-
   /** The Jacobian can be computed much faster for some of the
    * derived kerbel transforms, most notably the TPS.
    */
   bool m_FastComputationPossible;
 
 private:
-
-  KernelTransform2( const Self & ); // purposely not implemented
-  void operator=( const Self & );   // purposely not implemented
-
   TScalarType m_PoissonRatio;
 
   /** Using SVD or QR decomposition. */
   std::string m_MatrixInversionMethod;
-
 };
 
 } // end namespace itk
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "itkKernelTransform2.hxx"
+#  include "itkKernelTransform2.hxx"
 #endif
 
-#endif // __itkKernelTransform2_h
+#endif // itkKernelTransform2_h
