@@ -15,14 +15,15 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __elxResamplerBase_h
-#define __elxResamplerBase_h
+#ifndef elxResamplerBase_h
+#define elxResamplerBase_h
 
 /** Needed for the macros */
 #include "elxMacro.h"
 
 #include "elxBaseComponentSE.h"
 #include "itkResampleImageFilter.h"
+#include "itkCastImageFilter.h"
 #include "elxProgressCommand.h"
 
 namespace elastix
@@ -38,6 +39,9 @@ namespace elastix
  *    result image is resampled and written. Choose from {"true", "false"} \n
  *    example: <tt>(WriteResultImage "false")</tt> \n
  *    The default is "true".
+ * \note When WriteResultImage is false, the executable will not write a
+ * result image, and the elastix library interface produces an empty image.
+ *
  * \parameter WriteResultImageAfterEachResolution: flag to determine if the intermediate
  *    result image is resampled and written after each resolution. Choose from {"true", "false"} \n
  *    example: <tt>(WriteResultImageAfterEachResolution "true" "false" "true")</tt> \n
@@ -69,75 +73,76 @@ namespace elastix
  * \ingroup ComponentBaseClasses
  */
 
-template< class TElastix >
-class ResamplerBase : public BaseComponentSE< TElastix >
+template <class TElastix>
+class ITK_TEMPLATE_EXPORT ResamplerBase : public BaseComponentSE<TElastix>
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(ResamplerBase);
 
   /** Standard ITK stuff. */
-  typedef ResamplerBase               Self;
-  typedef BaseComponentSE< TElastix > Superclass;
+  using Self = ResamplerBase;
+  using Superclass = BaseComponentSE<TElastix>;
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( ResamplerBase, BaseComponentSE );
+  itkTypeMacro(ResamplerBase, BaseComponentSE);
 
   /** Typedef's from superclass. */
-  typedef typename Superclass::ElastixType          ElastixType;
-  typedef typename Superclass::ElastixPointer       ElastixPointer;
-  typedef typename Superclass::ConfigurationType    ConfigurationType;
-  typedef typename Superclass::ConfigurationPointer ConfigurationPointer;
-  typedef typename Superclass::RegistrationType     RegistrationType;
-  typedef typename Superclass::RegistrationPointer  RegistrationPointer;
+  using typename Superclass::ElastixType;
+  using typename Superclass::RegistrationType;
 
   /** Typedef's from elastix.
-  * NB: it is assumed that fixed and moving image dimension are equal!  */
-  typedef typename ElastixType::MovingImageType InputImageType;
-  typedef typename ElastixType::MovingImageType OutputImageType;
-  //typedef typename ElastixType::FixedImageType      OutputImageType;
-  typedef typename ElastixType::CoordRepType CoordRepType;
+   * NB: it is assumed that fixed and moving image dimension are equal!  */
+  using InputImageType = typename ElastixType::MovingImageType;
+  using OutputImageType = typename ElastixType::MovingImageType;
+  // typedef typename ElastixType::FixedImageType      OutputImageType;
+  using CoordRepType = ElastixBase::CoordRepType;
 
   /** Other typedef's. */
-  typedef itk::ResampleImageFilter<
-    InputImageType, OutputImageType, CoordRepType >  ITKBaseType;
+  using ITKBaseType = itk::ResampleImageFilter<InputImageType, OutputImageType, CoordRepType>;
 
   /** Typedef's from ResampleImageFiler. */
-  typedef typename ITKBaseType::TransformType    TransformType;
-  typedef typename ITKBaseType::InterpolatorType InterpolatorType;
-  typedef typename ITKBaseType::SizeType         SizeType;
-  typedef typename ITKBaseType::IndexType        IndexType;
-  typedef typename ITKBaseType::SpacingType      SpacingType;
-  typedef typename ITKBaseType::DirectionType    DirectionType;
-  typedef typename ITKBaseType::OriginPointType  OriginPointType;
-  typedef typename ITKBaseType::PixelType        OutputPixelType;
+  using TransformType = typename ITKBaseType::TransformType;
+  using InterpolatorType = typename ITKBaseType::InterpolatorType;
+  using SizeType = typename ITKBaseType::SizeType;
+  using IndexType = typename ITKBaseType::IndexType;
+  using SpacingType = typename ITKBaseType::SpacingType;
+  using DirectionType = typename ITKBaseType::DirectionType;
+  using OriginPointType = typename ITKBaseType::OriginPointType;
+  using OutputPixelType = typename ITKBaseType::PixelType;
 
   /** Typedef that is used in the elastix dll version. */
-  typedef typename ElastixType::ParameterMapType ParameterMapType;
+  using ParameterMapType = typename ElastixType::ParameterMapType;
 
   /** Typedef for the ProgressCommand. */
-  typedef elx::ProgressCommand ProgressCommandType;
+  using ProgressCommandType = elx::ProgressCommand;
 
   /** Get the ImageDimension. */
-  itkStaticConstMacro( ImageDimension, unsigned int,
-    OutputImageType::ImageDimension );
+  itkStaticConstMacro(ImageDimension, unsigned int, OutputImageType::ImageDimension);
 
-  /** Cast to ITKBaseType. */
-  virtual ITKBaseType * GetAsITKBaseType( void )
+  /** Retrieves this object as ITKBaseType. */
+  ITKBaseType *
+  GetAsITKBaseType()
   {
-    return dynamic_cast< ITKBaseType * >( this );
+    return &(this->GetSelf());
   }
 
 
-  /** Cast to ITKBaseType, to use in const functions. */
-  virtual const ITKBaseType * GetAsITKBaseType( void ) const
+  /** Retrieves this object as ITKBaseType, to use in const functions. */
+  const ITKBaseType *
+  GetAsITKBaseType() const
   {
-    return dynamic_cast< const ITKBaseType * >( this );
+    return &(this->GetSelf());
   }
 
 
   /** Execute stuff before the actual transformation:
    * \li nothing here
    */
-  virtual int BeforeAllTransformix( void ){ return 0; }
+  virtual int
+  BeforeAllTransformix()
+  {
+    return 0;
+  }
 
   /** Execute stuff before the actual registration:
    * \li Set all components into the resampler, such as the transform
@@ -145,71 +150,94 @@ public:
    * \li Set output image information, such as size, spacing, etc.
    * \li Set the default pixel value.
    */
-  void BeforeRegistrationBase( void ) override;
+  void
+  BeforeRegistrationBase() override;
 
   /** Execute stuff after each resolution:
    * \li Write the resulting output image.
    */
-  void AfterEachResolutionBase( void ) override;
+  void
+  AfterEachResolutionBase() override;
 
   /** Execute stuff after each iteration:
    * \li Write the resulting output image.
    */
-  void AfterEachIterationBase( void ) override;
+  void
+  AfterEachIterationBase() override;
 
   /** Execute stuff after the registration:
    * \li Write the resulting output image.
    */
-  void AfterRegistrationBase( void ) override;
+  void
+  AfterRegistrationBase() override;
 
   /** Function to read transform-parameters from a file. */
-  virtual void ReadFromFile( void );
+  virtual void
+  ReadFromFile();
 
   /** Function to write transform-parameters to a file. */
-  virtual void WriteToFile( void ) const;
+  void
+  WriteToFile(xl::xoutsimple & transformationParameterInfo) const;
 
   /** Function to create transform-parameters map. */
-  virtual void CreateTransformParametersMap( ParameterMapType * paramsMap ) const;
+  void
+  CreateTransformParametersMap(ParameterMapType & parameterMap) const;
 
   /** Function to perform resample and write the result output image to a file. */
-  virtual void ResampleAndWriteResultImage( const char * filename, const bool & showProgress = true );
+  void
+  ResampleAndWriteResultImage(const char * filename, const bool showProgress = true);
 
   /** Function to write the result output image to a file. */
-  virtual void WriteResultImage( OutputImageType * imageimage,
-    const char * filename, const bool & showProgress = true );
+  void
+  WriteResultImage(OutputImageType * imageimage, const char * filename, const bool showProgress = true);
 
   /** Function to create the result image in the format of an itk::Image. */
-  virtual void CreateItkResultImage( void );
+  virtual void
+  CreateItkResultImage();
 
 protected:
-
   /** The constructor. */
-  ResamplerBase();
+  ResamplerBase() = default;
   /** The destructor. */
-  ~ResamplerBase() override {}
+  ~ResamplerBase() override = default;
 
   /** Method that sets the transform, the interpolator and the inputImage. */
-  virtual void SetComponents( void );
+  virtual void
+  SetComponents();
 
   /** Variable that defines to print the progress or not. */
-  bool m_ShowProgress;
+  bool m_ShowProgress{ true };
 
 private:
+  elxDeclarePureVirtualGetSelfMacro(ITKBaseType);
 
-  /** The private constructor. */
-  ResamplerBase( const Self & );   // purposely not implemented
-  /** The private copy constructor. */
-  void operator=( const Self & );  // purposely not implemented
+  virtual ParameterMapType
+  CreateDerivedTransformParametersMap() const
+  {
+    return {};
+  }
 
   /** Release memory. */
-  void ReleaseMemory( void );
+  void
+  ReleaseMemory();
 
+  /** Casts the specified input image to the image type with the specified pixel type. */
+  template <typename TResultPixel>
+  itk::SmartPointer<itk::ImageBase<ImageDimension>>
+  CastImage(const InputImageType * const inputImage) const
+  {
+    const auto castFilter =
+      itk::CastImageFilter<InputImageType, itk::Image<TResultPixel, InputImageType::ImageDimension>>::New();
+    castFilter->SetInput(inputImage);
+    castFilter->Update();
+    return castFilter->GetOutput();
+  }
 };
 
 } // end namespace elastix
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "elxResamplerBase.hxx"
+#  include "elxResamplerBase.hxx"
 #endif
 
-#endif // end #ifndef __elxResamplerBase_h
+#endif // end #ifndef elxResamplerBase_h
