@@ -15,23 +15,29 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __elxTransformBase_h
-#define __elxTransformBase_h
+#ifndef elxTransformBase_h
+#define elxTransformBase_h
 
 /** Needed for the macros */
 #include "elxMacro.h"
 
 #include "elxBaseComponentSE.h"
+#include "elxDefaultConstruct.h"
+#include "elxElastixBase.h"
 #include "itkAdvancedTransform.h"
 #include "itkAdvancedCombinationTransform.h"
 #include "elxComponentDatabase.h"
 #include "elxProgressCommand.h"
 
-#include <memory> // For unique_ptr.
+// ITK header files:
+#include <itkImage.h>
+#include <itkOptimizerParameters.h>
+#include <itkTransformMeshFilter.h>
+
 
 namespace elastix
 {
-//using namespace itk; //Not here, because a TransformBase class was added to ITK...
+// using namespace itk; //Not here, because a TransformBase class was added to ITK...
 
 /**
  * \class TransformBase
@@ -124,178 +130,279 @@ namespace elastix
  * \ingroup ComponentBaseClasses
  */
 
-template< class TElastix >
-class TransformBase :
-  public BaseComponentSE< TElastix >
+template <class TElastix>
+class ITK_TEMPLATE_EXPORT TransformBase : public BaseComponentSE<TElastix>
 {
 public:
-  ITK_DISALLOW_COPY_AND_ASSIGN(TransformBase);
+  ITK_DISALLOW_COPY_AND_MOVE(TransformBase);
 
   /** Standard ITK stuff. */
-  typedef TransformBase               Self;
-  typedef BaseComponentSE< TElastix > Superclass;
+  using Self = TransformBase;
+  using Superclass = BaseComponentSE<TElastix>;
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( TransformBase, BaseComponentSE );
+  itkTypeMacro(TransformBase, BaseComponentSE);
 
-  /** Typedef's from Superclass. */
-  using typename Superclass::ElastixType;
-  using typename Superclass::ElastixPointer;
-  using typename Superclass::ConfigurationType;
-  using typename Superclass::ConfigurationPointer;
+  /** Typedef from Superclass. */
   using typename Superclass::RegistrationType;
-  using typename Superclass::RegistrationPointer;
 
-  typedef typename ConfigurationType
-    ::CommandLineArgumentMapType CommandLineArgumentMapType;
-  typedef typename ConfigurationType
-    ::CommandLineEntryType CommandLineEntryType;
+  using CommandLineArgumentMapType = Configuration ::CommandLineArgumentMapType;
+  using CommandLineEntryType = Configuration ::CommandLineEntryType;
 
   /** Elastix typedef's. */
-  typedef typename ElastixType::CoordRepType    CoordRepType;
-  typedef typename ElastixType::FixedImageType  FixedImageType;
-  typedef typename ElastixType::MovingImageType MovingImageType;
+  using CoordRepType = ElastixBase::CoordRepType;
+  using FixedImageType = typename TElastix::FixedImageType;
+  using MovingImageType = typename TElastix::MovingImageType;
 
   /** Typedef's from ComponentDatabase. */
-  typedef ComponentDatabase                               ComponentDatabaseType;
-  typedef ComponentDatabaseType::ComponentDescriptionType ComponentDescriptionType;
-  typedef ComponentDatabase::PtrToCreator                 PtrToCreator;
+  using ComponentDescriptionType = ComponentDatabase::ComponentDescriptionType;
+  using PtrToCreator = ComponentDatabase::PtrToCreator;
 
   /** Typedef for the ProgressCommand. */
-  typedef elx::ProgressCommand ProgressCommandType;
+  using ProgressCommandType = elx::ProgressCommand;
 
   /** Get the dimension of the fixed image. */
-  itkStaticConstMacro( FixedImageDimension,
-    unsigned int, FixedImageType::ImageDimension );
+  itkStaticConstMacro(FixedImageDimension, unsigned int, FixedImageType::ImageDimension);
 
   /** Get the dimension of the moving image. */
-  itkStaticConstMacro( MovingImageDimension,
-    unsigned int, MovingImageType::ImageDimension );
+  itkStaticConstMacro(MovingImageDimension, unsigned int, MovingImageType::ImageDimension);
 
   /** Other typedef's. */
-  typedef itk::Object ObjectType;
-  typedef itk::AdvancedTransform<
-    CoordRepType,
-    itkGetStaticConstMacro( FixedImageDimension ),
-    itkGetStaticConstMacro( MovingImageDimension ) >  ITKBaseType;
-  typedef itk::AdvancedCombinationTransform< CoordRepType,
-    itkGetStaticConstMacro( FixedImageDimension ) >   CombinationTransformType;
-  typedef typename
-    CombinationTransformType::InitialTransformType InitialTransformType;
+  using CombinationTransformType = itk::AdvancedCombinationTransform<CoordRepType, Self::FixedImageDimension>;
+  using ITKBaseType = CombinationTransformType;
+  using InitialTransformType = typename CombinationTransformType::InitialTransformType;
 
-  /** Typedef's from Transform. */
-  typedef typename ITKBaseType::ParametersType ParametersType;
-  typedef typename ParametersType::ValueType   ValueType;
+  /** Typedef's for parameters. */
+  using ValueType = double;
+  using ParametersType = itk::OptimizerParameters<ValueType>;
 
   /** Typedef's for TransformPoint. */
-  typedef typename ITKBaseType::InputPointType  InputPointType;
-  typedef typename ITKBaseType::OutputPointType OutputPointType;
+  using InputPointType = typename ITKBaseType::InputPointType;
+  using OutputPointType = typename ITKBaseType::OutputPointType;
 
   /** Typedef's for TransformPointsAllPoints. */
-  typedef itk::Vector<
-    float, FixedImageDimension >                      VectorPixelType;
-  typedef itk::Image<
-    VectorPixelType, FixedImageDimension >            DeformationFieldImageType;
+  using VectorPixelType = itk::Vector<float, FixedImageDimension>;
+  using DeformationFieldImageType = itk::Image<VectorPixelType, FixedImageDimension>;
 
   /** Typedefs needed for AutomaticScalesEstimation function */
-  typedef typename RegistrationType::ITKBaseType      ITKRegistrationType;
-  typedef typename ITKRegistrationType::OptimizerType OptimizerType;
-  typedef typename OptimizerType::ScalesType          ScalesType;
+  using ITKRegistrationType = typename RegistrationType::ITKBaseType;
+  using OptimizerType = typename ITKRegistrationType::OptimizerType;
+  using ScalesType = typename OptimizerType::ScalesType;
+
+  /** Typedefs for images of determinants of spatial Jacobian matrices, and images of spatial Jacobian matrices */
+  using SpatialJacobianDeterminantImageType = itk::Image<float, FixedImageDimension>;
+  using SpatialJacobianMatrixImageType =
+    itk::Image<itk::Matrix<float, MovingImageDimension, FixedImageDimension>, FixedImageDimension>;
+
 
   /** Typedef that is used in the elastix dll version. */
-  typedef typename ElastixType::ParameterMapType ParameterMapType;
+  using ParameterMapType = typename TElastix::ParameterMapType;
 
-  /** Cast to ITKBaseType. */
-  virtual ITKBaseType * GetAsITKBaseType( void )
+  /** Retrieves this object as ITKBaseType. */
+  ITKBaseType *
+  GetAsITKBaseType()
   {
-    return dynamic_cast< ITKBaseType * >( this );
+    return &(this->GetSelf());
   }
 
 
-  /** Cast to ITKBaseType, to use in const functions. */
-  virtual const ITKBaseType * GetAsITKBaseType( void ) const
+  /** Retrieves this object as ITKBaseType, to use in const functions. */
+  const ITKBaseType *
+  GetAsITKBaseType() const
   {
-    return dynamic_cast< const ITKBaseType * >( this );
+    return &(this->GetSelf());
   }
 
-
-  virtual const CombinationTransformType * GetAsCombinationTransform( void ) const
-  {
-    return dynamic_cast< const CombinationTransformType * >( this );
-  }
-
-
-  virtual CombinationTransformType * GetAsCombinationTransform( void )
-  {
-    return dynamic_cast< CombinationTransformType * >( this );
-  }
-
-
-  /** Execute stuff before everything else:
-   * \li Check the appearance of an initial transform.
-   */
-  int BeforeAllBase( void ) override;
-
   /** Execute stuff before the actual transformation:
    * \li Check the appearance of inputpoints to be transformed.
    */
-  virtual int BeforeAllTransformix( void );
+  int
+  BeforeAllTransformix();
+
+  /** Set the initial transform. */
+  void
+  SetInitialTransform(InitialTransformType * _arg);
+
+  /** Set the TransformParametersFileName. */
+  void
+  SetTransformParametersFileName(const char * filename);
+
+  /** Function to read transform-parameters from a file. */
+  virtual void
+  ReadFromFile();
+
+  /** Function to create transform-parameters map. */
+  void
+  CreateTransformParametersMap(const ParametersType & param,
+                               ParameterMapType &     parameterMap,
+                               const bool             includeDerivedTransformParameters = true) const;
+
+  /** Function to write transform-parameters to a file. */
+  void
+  WriteToFile(xl::xoutsimple & transformationParameterInfo, const ParametersType & param) const;
+
+  /** Macro for reading and writing the transform parameters in WriteToFile or not. */
+  void
+  SetReadWriteTransformParameters(const bool _arg);
+
+  /** Function to read the initial transform parameters from a file. */
+  void
+  ReadInitialTransformFromFile(const char * transformParameterFileName);
+
+  /** Function to transform coordinates from fixed to moving image. */
+  void
+  TransformPoints() const;
+
+  /** Computes the spatial Jacobian determinant for each pixel, and returns the image. */
+  typename SpatialJacobianDeterminantImageType::Pointer
+  ComputeSpatialJacobianDeterminantImage() const;
+
+  /** Computes the spatial Jacobian matrix for each pixel, and returns the image. */
+  typename SpatialJacobianMatrixImageType::Pointer
+  ComputeSpatialJacobianMatrixImage() const;
+
+  /** Computes the determinant of the spatial Jacobian and writes it to file. */
+  void
+  ComputeAndWriteSpatialJacobianDeterminantImage() const;
+
+  /** Computes the spatial Jacobian and writes it to file. */
+  void
+  ComputeAndWriteSpatialJacobianMatrixImage() const;
+
+  /** Makes sure that the final parameters from the registration components
+   * are copied, set, and stored.
+   */
+  void
+  SetFinalParameters();
+
+  /** Transforms the specified mesh.
+   */
+  template <typename TMesh>
+  typename TMesh::Pointer
+  TransformMesh(const TMesh & mesh) const
+  {
+    DefaultConstruct<itk::TransformMeshFilter<TMesh, TMesh, CombinationTransformType>> transformMeshFilter;
+    transformMeshFilter.SetTransform(&const_cast<CombinationTransformType &>(this->GetSelf()));
+    transformMeshFilter.SetInput(&mesh);
+    transformMeshFilter.Update();
+    return transformMeshFilter.GetOutput();
+  }
+
+protected:
+  /** The default-constructor. */
+  TransformBase() = default;
+  /** The destructor. */
+  ~TransformBase() override = default;
+
+  /** Tells whether this transform is specified by TransformParameters from ITK */
+  bool
+  HasITKTransformParameters() const
+  {
+    return this->BaseComponentSE<TElastix>::m_Configuration->HasParameter("ITKTransformParameters");
+  }
+
+  /** Estimate a scales vector
+   * AutomaticScalesEstimation works like this:
+   * \li N=10000 points are sampled on a uniform grid on the fixed image.
+   * \li Jacobians dT/dmu are computed
+   * \li Scales_i = 1/N sum_x || dT / dmu_i ||^2
+   */
+  void
+  AutomaticScalesEstimation(ScalesType & scales) const;
+
+  /** Estimate a scales vector for a stack transform (elxTranslationStackTransform,
+   * elxAffineStackTransform, ...) Instead of sampling along the n dimensions of the
+   * fixed image, it samples along n-1 dimensions. Then
+   * \li N=10000 points are sampled.
+   * \li Jacobians dT/dmu are computed
+   * \li Scales_i = 1/N sum_x || dT / dmu_i ||^2
+   */
+  void
+  AutomaticScalesEstimationStackTransform(const unsigned int numSubTransforms, ScalesType & scales) const;
+
+private:
+  elxDeclarePureVirtualGetSelfMacro(ITKBaseType);
+
+  /** Supports either TransformToDeterminantOfSpatialJacobianSource or TransformToSpatialJacobianSource as TSource. */
+  template <template <typename, typename> class TSource, typename TOutputImage>
+  auto
+  CreateJacobianSource() const
+  {
+    const auto & resampleImageFilter = *(this->m_Elastix->GetElxResamplerBase()->GetAsITKBaseType());
+
+    /** Create an setup Jacobian generator. */
+    const auto jacGenerator = TSource<TOutputImage, CoordRepType>::New();
+
+    jacGenerator->SetTransform(this->GetAsITKBaseType());
+    jacGenerator->SetOutputSize(resampleImageFilter.GetSize());
+    jacGenerator->SetOutputSpacing(resampleImageFilter.GetOutputSpacing());
+    jacGenerator->SetOutputOrigin(resampleImageFilter.GetOutputOrigin());
+    jacGenerator->SetOutputIndex(resampleImageFilter.GetOutputStartIndex());
+    jacGenerator->SetOutputDirection(resampleImageFilter.GetOutputDirection());
+    // NOTE: We can not use the following, since the fixed image does not exist in transformix
+    //   jacGenerator->SetOutputParametersFromImage(
+    //     this->GetRegistration()->GetAsITKBaseType()->GetFixedImage() );
+
+    return jacGenerator;
+  }
+
+
+  /** Creates an info changer that may change the direction of the image to the original value. */
+  template <typename TImage>
+  auto
+  CreateChangeInformationImageFilter(TImage * image) const
+  {
+    /** Possibly change direction cosines to their original value, as specified
+     * in the tp-file, or by the fixed image. This is only necessary when
+     * the UseDirectionCosines flag was set to false. */
+    const auto                             infoChanger = itk::ChangeInformationImageFilter<TImage>::New();
+    typename FixedImageType::DirectionType originalDirection;
+    const bool                             retdc = this->m_Elastix->GetOriginalFixedImageDirection(originalDirection);
+    infoChanger->SetOutputDirection(originalDirection);
+    infoChanger->SetChangeDirection(retdc & !this->m_Elastix->GetUseDirectionCosines());
+    infoChanger->SetInput(image);
+
+    return infoChanger;
+  }
+
+
+  /** Function to read the initial transform parameters from the specified configuration object.
+   */
+  void
+  ReadInitialTransformFromConfiguration(const Configuration::Pointer);
+
+  /** Execute stuff before everything else:
+   * \li Check the appearance of an initial transform.
+   */
+  int
+  BeforeAllBase() override;
 
   /** Execute stuff before the actual registration:
    * \li Set the initial transform and how to group transforms.
    */
-  void BeforeRegistrationBase( void ) override;
+  void
+  BeforeRegistrationBase() override;
 
   /** Execute stuff after the registration:
    * \li Get and set the final parameters for the resampler.
    */
-  void AfterRegistrationBase( void ) override;
+  void
+  AfterRegistrationBase() override;
 
   /** Get the initial transform. */
-  virtual const InitialTransformType * GetInitialTransform( void ) const;
-
-  /** Set the initial transform. */
-  virtual void SetInitialTransform( InitialTransformType * _arg );
-
-  /** Set the TransformParametersFileName. */
-  virtual void SetTransformParametersFileName( const char * filename );
+  const InitialTransformType *
+  GetInitialTransform() const;
 
   /** Get the TransformParametersFileName. */
-  itkGetStringMacro( TransformParametersFileName );
-
-  /** Function to read transform-parameters from a file. */
-  virtual void ReadFromFile( void );
-
-  /** Function to create transform-parameters map. */
-  virtual void CreateTransformParametersMap(
-    const ParametersType & param, ParameterMapType * paramsMap ) const;
-
-  /** Function to write transform-parameters to a file. */
-  virtual void WriteToFile( const ParametersType & param ) const;
-
-  /** Function to write transform-parameters to a file. */
-  virtual void WriteToFile( void ) const;
-
-  /** Macro for reading and writing the transform parameters in WriteToFile or not. */
-  virtual void SetReadWriteTransformParameters( const bool _arg );
-
-  /** Function to read the initial transform parameters from a file. */
-  virtual void ReadInitialTransformFromFile(
-    const char * transformParameterFileName );
-
-  /** Function to read the initial transform parameters from the internally stored
-   * configuration object.
-   */
-  virtual void ReadInitialTransformFromVector( const size_t index );
+  itkGetStringMacro(TransformParametersFileName);
 
   /** Function to transform coordinates from fixed to moving image. */
-  virtual void TransformPoints( void ) const;
-
-  /** Function to transform coordinates from fixed to moving image. */
-  virtual void TransformPointsSomePoints( const std::string filename ) const;
+  void
+  TransformPointsSomePoints(const std::string & filename) const;
 
   /** Function to transform coordinates from fixed to moving image, given as VTK file. */
-  virtual void TransformPointsSomePointsVTK( const std::string filename ) const;
+  void
+  TransformPointsSomePointsVTK(const std::string & filename) const;
 
   /** Deprecation note: The plan is to split all Compute* and TransformPoints* functions
    *  into Generate* and Write* functions, since that would facilitate a proper library
@@ -305,79 +412,48 @@ public:
    */
 
   /** Function to transform all coordinates from fixed to moving image. */
-  typename DeformationFieldImageType::Pointer GenerateDeformationFieldImage( void ) const;
+  typename DeformationFieldImageType::Pointer
+  GenerateDeformationFieldImage() const;
 
-  void WriteDeformationFieldImage( typename DeformationFieldImageType::Pointer ) const;
+  void WriteDeformationFieldImage(typename DeformationFieldImageType::Pointer) const;
 
   /** Legacy function that calls GenerateDeformationFieldImage and WriteDeformationFieldImage. */
-  virtual void TransformPointsAllPoints(void) const;
+  void
+  TransformPointsAllPoints() const;
 
-  /** Function to compute the determinant of the spatial Jacobian. */
-  virtual void ComputeDeterminantOfSpatialJacobian( void ) const;
-
-  /** Function to compute the determinant of the spatial Jacobian. */
-  virtual void ComputeSpatialJacobian( void ) const;
-
-  /** Makes sure that the final parameters from the registration components
-   * are copied, set, and stored.
-   */
-  virtual void SetFinalParameters( void );
-
-protected:
-
-  /** The default-constructor. */
-  TransformBase() = default;
-  /** The destructor. */
-  ~TransformBase() override = default;
-
-  /** Estimate a scales vector
-   * AutomaticScalesEstimation works like this:
-   * \li N=10000 points are sampled on a uniform grid on the fixed image.
-   * \li Jacobians dT/dmu are computed
-   * \li Scales_i = 1/N sum_x || dT / dmu_i ||^2
-   */
-  void AutomaticScalesEstimation( ScalesType & scales ) const;
-
-  /** Estimate a scales vector for a stack transform (elxTranslationStackTransform,
-   * elxAffineStackTransform, ...) Instead of sampling along the n dimensions of the
-   * fixed image, it samples along n-1 dimensions. Then
-   * \li N=10000 points are sampled.
-   * \li Jacobians dT/dmu are computed
-   * \li Scales_i = 1/N sum_x || dT / dmu_i ||^2
-   */
-  void AutomaticScalesEstimationStackTransform(
-    const unsigned int & numSubTransforms, ScalesType & scales ) const;
-
-private:
-
-  /** Member variables. */
-  std::unique_ptr<ParametersType> m_TransformParametersPointer{};
-  std::string      m_TransformParametersFileName;
-  ParametersType   m_FinalParameters;
-
-  /** Boolean to decide whether or not the transform parameters are written. */
-  bool m_ReadWriteTransformParameters{ true };
-
-  std::string GetInitialTransformParametersFileName( void ) const
+  std::string
+  GetInitialTransformParametersFileName() const
   {
-    if( !this->GetInitialTransform() )
+    if (!this->GetInitialTransform())
     {
       return "NoInitialTransform";
     }
 
-    const Self * t0 = dynamic_cast<const Self *>( this->GetInitialTransform() );
+    const Self * t0 = dynamic_cast<const Self *>(this->GetInitialTransform());
     return t0->GetTransformParametersFileName();
   }
 
-  /** Boolean to decide whether or not the transform parameters are written in binary format. */
-  bool m_UseBinaryFormatForTransformationParameters{};
+  virtual ParameterMapType
+  CreateDerivedTransformParametersMap() const = 0;
 
+  /** Allows a derived transform class to write its data to file, by overriding this member function. */
+  virtual void
+  WriteDerivedTransformDataToFile() const
+  {}
+
+  /** Member variables. */
+  std::string    m_TransformParametersFileName;
+  ParametersType m_TransformParameters;
+  ParametersType m_FinalParameters;
+
+  /** Boolean to decide whether or not the transform parameters are written. */
+  bool m_ReadWriteTransformParameters{ true };
 };
 
 } // end namespace elastix
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "elxTransformBase.hxx"
+#  include "elxTransformBase.hxx"
 #endif
 
-#endif // end #ifndef __elxTransformBase_h
+#endif // end #ifndef elxTransformBase_h
