@@ -15,12 +15,15 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __elxBaseComponentSE_h
-#define __elxBaseComponentSE_h
+#ifndef elxBaseComponentSE_h
+#define elxBaseComponentSE_h
 
 #include "elxBaseComponent.h"
-#include "itkMacro.h" // For ITK_DISALLOW_COPY_AND_ASSIGN.
-#include "itkWeakPointer.h"
+#include "elxConfiguration.h"
+
+// ITK header files:
+#include <itkMacro.h> // For ITK_DISALLOW_COPY_AND_MOVE.
+#include <itkWeakPointer.h>
 
 namespace elastix
 {
@@ -40,29 +43,26 @@ namespace elastix
  * \ingroup Install
  */
 
-template< class TElastix >
-class BaseComponentSE : public BaseComponent
+template <class TElastix>
+class ITK_TEMPLATE_EXPORT BaseComponentSE : public BaseComponent
 {
 public:
-  ITK_DISALLOW_COPY_AND_ASSIGN(BaseComponentSE);
+  ITK_DISALLOW_COPY_AND_MOVE(BaseComponentSE);
 
   /** Standard stuff. */
-  typedef BaseComponentSE Self;
-  typedef BaseComponent   Superclass;
+  using Self = BaseComponentSE;
+  using Superclass = BaseComponent;
 
-  /** Elastix typedef's. */
-  typedef TElastix                        ElastixType;
-  typedef itk::WeakPointer< ElastixType > ElastixPointer;
+  /** Elastix typedef. */
+  using ElastixType = TElastix;
 
-  /** ConfigurationType. */
-  typedef Configuration          ConfigurationType;
-  typedef Configuration::Pointer ConfigurationPointer;
+  /** Configuration pointer type. */
+  using ConfigurationPointer = Configuration::Pointer;
 
   /** RegistrationType; NB: this is the elx::RegistrationBase
    * not an itk::Object or something like that.
    */
-  typedef typename ElastixType::RegistrationBaseType RegistrationType;
-  typedef RegistrationType *                         RegistrationPointer;
+  using RegistrationType = typename ElastixType::RegistrationBaseType;
 
   /**
    * Get/Set functions for Elastix.
@@ -76,55 +76,83 @@ public:
    * Besides setting m_Elastix, this method also sets m_Configuration
    * and m_Registration.
    */
-  void SetElastix( ElastixType * _arg );
+  void
+  SetElastix(ElastixType * _arg);
 
   /** itkGetModifiableObjectMacro( Elastix, ElastixType );
    * without the itkDebug call.
    */
-  ElastixType * GetElastix( void ) const
+  ElastixType *
+  GetElastix() const
   {
     return this->m_Elastix.GetPointer();
   }
 
+  int
+  RemoveTargetCellFromIterationInfo(const char * const name)
+  {
+    return this->m_Elastix->GetIterationInfo().xl::xoutrow::RemoveTargetCell(name);
+  }
 
-  /** itkGetModifiableObjectMacro(Configuration, ConfigurationType);
+  xl::xoutbase &
+  GetIterationInfoAt(const char * const name)
+  {
+    return this->m_Elastix->GetIterationInfoAt(name);
+  }
+
+  void
+  AddTargetCellToIterationInfo(const char * const name)
+  {
+    return this->m_Elastix->AddTargetCellToIterationInfo(name);
+  }
+
+  /** itkGetModifiableObjectMacro(Configuration, Configuration);
    * The configuration object provides functionality to
    * read parameters and command line arguments.
    */
-  ConfigurationType * GetConfiguration( void ) const
+  Configuration *
+  GetConfiguration() const
   {
     return this->m_Configuration.GetPointer();
   }
 
 
   /** Set the configuration. Added for transformix. */
-  void SetConfiguration( ConfigurationType * _arg );
+  void
+  SetConfiguration(Configuration * _arg);
 
   /** Get a pointer to the Registration component.
    * This is a convenience function, since the registration
    * component is needed often by other components.
    * It could be accessed also via GetElastix->GetElxRegistrationBase().
    */
-  RegistrationPointer GetRegistration( void ) const
+  RegistrationType *
+  GetRegistration() const
   {
     return this->m_Registration;
   }
 
 
 protected:
-
   BaseComponentSE() = default;
   ~BaseComponentSE() override = default;
 
-  ElastixPointer       m_Elastix{};
-  ConfigurationPointer m_Configuration{};
-  RegistrationPointer  m_Registration{};
+  itk::WeakPointer<TElastix> m_Elastix{};
+  ConfigurationPointer       m_Configuration{};
+  RegistrationType *         m_Registration{};
+
+private:
+  virtual const itk::Object &
+  GetSelf() const = 0;
+
+  virtual itk::Object &
+  GetSelf() = 0;
 };
 
-} //end namespace elastix
+} // end namespace elastix
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "elxBaseComponentSE.hxx"
+#  include "elxBaseComponentSE.hxx"
 #endif
 
-#endif // end #ifndef __elxBaseComponentSE_h
+#endif // end #ifndef elxBaseComponentSE_h
