@@ -15,20 +15,22 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __elxElastixMain_h
-#define __elxElastixMain_h
+#ifndef elxElastixMain_h
+#define elxElastixMain_h
 
 #include "elxComponentDatabase.h"
-#include "elxComponentLoader.h"
 
 #include "elxElastixBase.h"
-#include "itkObject.h"
-
-#include <iostream>
-#include <fstream>
-
 #include "itkParameterMapInterface.h"
 
+#include <itkObject.h>
+
+// Standard C++ header files:
+#include <fstream>
+#include <iostream>
+#include <string>
+
+
 namespace elastix
 {
 
@@ -48,7 +50,37 @@ namespace elastix
  * The method takes a logfile name as its input argument.
  * It returns 0 if everything went ok. 1 otherwise.
  */
-extern int xoutSetup( const char * logfilename, bool setupLogging, bool setupCout );
+extern int
+xoutSetup(const char * logfilename, bool setupLogging, bool setupCout);
+
+
+/** Manages setting up and closing the "xout" output streams.
+ */
+class xoutManager
+{
+public:
+  ITK_DISALLOW_COPY_AND_MOVE(xoutManager);
+
+  /** This explicit constructor does set up the "xout" output streams. */
+  explicit xoutManager(const std::string & logfilename, const bool setupLogging, const bool setupCout);
+
+  /** The default-constructor only just constructs a manager object */
+  xoutManager() = default;
+
+  /** The destructor closes the "xout" output streams. */
+  ~xoutManager() = default;
+
+private:
+  struct Guard
+  {
+    ITK_DISALLOW_COPY_AND_MOVE(Guard);
+    Guard() = default;
+    ~Guard();
+  };
+
+  const Guard m_Guard{};
+};
+
 
 /**
  * \class ElastixMain
@@ -94,262 +126,251 @@ extern int xoutSetup( const char * logfilename, bool setupLogging, bool setupCou
 class ElastixMain : public itk::Object
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(ElastixMain);
 
   /** Standard itk. */
-  typedef ElastixMain                     Self;
-  typedef itk::Object                     Superclass;
-  typedef itk::SmartPointer< Self >       Pointer;
-  typedef itk::SmartPointer< const Self > ConstPointer;
+  using Self = ElastixMain;
+  using Superclass = itk::Object;
+  using Pointer = itk::SmartPointer<Self>;
+  using ConstPointer = itk::SmartPointer<const Self>;
 
   /** Method for creation through the object factory. */
-  itkNewMacro( Self );
+  itkNewMacro(Self);
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( ElastixMain, Object );
+  itkTypeMacro(ElastixMain, Object);
 
   /** Typedef's.*/
 
   /** ITK base objects. */
-  typedef itk::Object             ObjectType;
-  typedef ObjectType::Pointer     ObjectPointer;
-  typedef itk::DataObject         DataObjectType;
-  typedef DataObjectType::Pointer DataObjectPointer;
+  using ObjectPointer = itk::Object::Pointer;
+  using DataObjectPointer = itk::DataObject::Pointer;
 
   /** elastix components. */
-  typedef ElastixBase                                   ElastixBaseType;
-  typedef ElastixBase::ConfigurationType                ConfigurationType;
-  typedef ConfigurationType::CommandLineArgumentMapType ArgumentMapType;
-  typedef ConfigurationType::Pointer                    ConfigurationPointer;
-  typedef ElastixBase::ObjectContainerType              ObjectContainerType;
-  typedef ElastixBase::DataObjectContainerType          DataObjectContainerType;
-  typedef ElastixBase::ObjectContainerPointer           ObjectContainerPointer;
-  typedef ElastixBase::DataObjectContainerPointer       DataObjectContainerPointer;
-  typedef ElastixBase::FlatDirectionCosinesType         FlatDirectionCosinesType;
+  using ArgumentMapType = Configuration::CommandLineArgumentMapType;
+  using ConfigurationPointer = Configuration::Pointer;
+  using ObjectContainerType = ElastixBase::ObjectContainerType;
+  using DataObjectContainerType = ElastixBase::DataObjectContainerType;
+  using ObjectContainerPointer = ElastixBase::ObjectContainerPointer;
+  using DataObjectContainerPointer = ElastixBase::DataObjectContainerPointer;
+  using FlatDirectionCosinesType = ElastixBase::FlatDirectionCosinesType;
 
   /** Typedefs for the database that holds pointers to New() functions.
    * Those functions are used to instantiate components, such as the metric etc.
    */
-  typedef ComponentDatabase                               ComponentDatabaseType;
-  typedef ComponentDatabaseType::Pointer                  ComponentDatabasePointer;
-  typedef ComponentDatabaseType::PtrToCreator             PtrToCreator;
-  typedef ComponentDatabaseType::ComponentDescriptionType ComponentDescriptionType;
-  typedef ComponentDatabaseType::PixelTypeDescriptionType PixelTypeDescriptionType;
-  typedef ComponentDatabaseType::ImageDimensionType       ImageDimensionType;
-  typedef ComponentDatabaseType::IndexType                DBIndexType;
-
-  /** Typedef for class that populates a ComponentDatabase. */
-  typedef ComponentLoader              ComponentLoaderType;
-  typedef ComponentLoaderType::Pointer ComponentLoaderPointer;
+  using ComponentDatabasePointer = ComponentDatabase::Pointer;
+  using PtrToCreator = ComponentDatabase::PtrToCreator;
+  using ComponentDescriptionType = ComponentDatabase::ComponentDescriptionType;
+  using PixelTypeDescriptionType = ComponentDatabase::PixelTypeDescriptionType;
+  using ImageDimensionType = ComponentDatabase::ImageDimensionType;
+  using DBIndexType = ComponentDatabase::IndexType;
 
   /** Typedef that is used in the elastix dll version. */
-  typedef itk::ParameterMapInterface::ParameterMapType ParameterMapType;
+  using ParameterMapType = itk::ParameterMapInterface::ParameterMapType;
 
   /** Set/Get functions for the description of the image type. */
-  itkSetMacro( FixedImagePixelType,   PixelTypeDescriptionType );
-  itkSetMacro( MovingImagePixelType,  PixelTypeDescriptionType );
-  itkSetMacro( FixedImageDimension,   ImageDimensionType );
-  itkSetMacro( MovingImageDimension,  ImageDimensionType );
-  itkGetMacro( FixedImagePixelType,   PixelTypeDescriptionType );
-  itkGetMacro( MovingImagePixelType,  PixelTypeDescriptionType );
-  itkGetMacro( FixedImageDimension,   ImageDimensionType );
-  itkGetMacro( MovingImageDimension,  ImageDimensionType );
+  itkSetMacro(FixedImagePixelType, PixelTypeDescriptionType);
+  itkSetMacro(MovingImagePixelType, PixelTypeDescriptionType);
+  itkSetMacro(FixedImageDimension, ImageDimensionType);
+  itkSetMacro(MovingImageDimension, ImageDimensionType);
+  itkGetConstMacro(FixedImagePixelType, PixelTypeDescriptionType);
+  itkGetConstMacro(MovingImagePixelType, PixelTypeDescriptionType);
+  itkGetConstMacro(FixedImageDimension, ImageDimensionType);
+  itkGetConstMacro(MovingImageDimension, ImageDimensionType);
 
   /** Set/Get functions for the fixed and moving images
    * (if these are not used, elastix tries to read them from disk,
    * according to the command line parameters).
    */
-  itkSetObjectMacro( FixedImageContainer,  DataObjectContainerType );
-  itkSetObjectMacro( MovingImageContainer, DataObjectContainerType );
-  itkGetModifiableObjectMacro( FixedImageContainer,  DataObjectContainerType );
-  itkGetModifiableObjectMacro( MovingImageContainer, DataObjectContainerType );
+  itkSetObjectMacro(FixedImageContainer, DataObjectContainerType);
+  itkSetObjectMacro(MovingImageContainer, DataObjectContainerType);
+  itkGetModifiableObjectMacro(FixedImageContainer, DataObjectContainerType);
+  itkGetModifiableObjectMacro(MovingImageContainer, DataObjectContainerType);
 
   /** Set/Get functions for the fixed and moving masks
    * (if these are not used, elastix tries to read them from disk,
    * according to the command line parameters).
    */
-  itkSetObjectMacro( FixedMaskContainer, DataObjectContainerType );
-  itkSetObjectMacro( MovingMaskContainer, DataObjectContainerType );
-  itkGetModifiableObjectMacro( FixedMaskContainer, DataObjectContainerType );
-  itkGetModifiableObjectMacro( MovingMaskContainer, DataObjectContainerType );
+  itkSetObjectMacro(FixedMaskContainer, DataObjectContainerType);
+  itkSetObjectMacro(MovingMaskContainer, DataObjectContainerType);
+  itkGetModifiableObjectMacro(FixedMaskContainer, DataObjectContainerType);
+  itkGetModifiableObjectMacro(MovingMaskContainer, DataObjectContainerType);
 
   /** Set/Get functions for the result images
    * (if these are not used, elastix tries to read them from disk,
    * according to the command line parameters).
    */
-  itkSetObjectMacro( ResultImageContainer, DataObjectContainerType );
-  itkGetModifiableObjectMacro( ResultImageContainer, DataObjectContainerType );
+  itkSetObjectMacro(ResultImageContainer, DataObjectContainerType);
+  itkGetModifiableObjectMacro(ResultImageContainer, DataObjectContainerType);
 
-  itkSetObjectMacro( ResultDeformationFieldContainer, DataObjectContainerType );
-  itkGetModifiableObjectMacro( ResultDeformationFieldContainer, DataObjectContainerType );
+  itkSetObjectMacro(ResultDeformationFieldContainer, DataObjectContainerType);
+  itkGetModifiableObjectMacro(ResultDeformationFieldContainer, DataObjectContainerType);
 
   /** Set/Get the configuration object. */
-  itkSetObjectMacro( Configuration, ConfigurationType );
-  itkGetModifiableObjectMacro( Configuration, ConfigurationType );
+  itkSetObjectMacro(Configuration, Configuration);
+  itkGetModifiableObjectMacro(Configuration, Configuration);
 
   /** Functions to get pointers to the elastix components.
    * The components are returned as Object::Pointer.
    * Before calling this functions, call run().
    */
-  itkGetModifiableObjectMacro( Elastix, ObjectType );
+  itkGetModifiableObjectMacro(Elastix, itk::Object);
 
   /** Convenience function that returns the elastix component as
-   * a pointer to an ElastixBaseType. Use only after having called run()!
+   * a pointer to an ElastixBase. Use only after having called run()!
    */
-  virtual ElastixBaseType * GetElastixBase( void ) const;
+  ElastixBase &
+  GetElastixBase() const;
 
   /** Get the final transform (the result of running elastix).
    * You may pass this as an InitialTransform in an other instantiation
    * of ElastixMain.
    * Only valid after calling Run()!
    */
-  itkGetModifiableObjectMacro( FinalTransform, ObjectType );
+  itkGetModifiableObjectMacro(FinalTransform, itk::Object);
 
   /** Set/Get the initial transform
-   * the type is ObjectType, but the pointer should actually point
+   * the type is itk::Object, but the pointer should actually point
    * to an itk::Transform type (or inherited from that one).
    */
-  itkSetObjectMacro( InitialTransform, ObjectType );
-  itkGetModifiableObjectMacro( InitialTransform, ObjectType );
+  itkSetObjectMacro(InitialTransform, itk::Object);
+  itkGetModifiableObjectMacro(InitialTransform, itk::Object);
 
   /** Set/Get the original fixed image direction as a flat array
    * (d11 d21 d31 d21 d22 etc ) */
-  virtual void SetOriginalFixedImageDirectionFlat(
-    const FlatDirectionCosinesType & arg );
+  virtual void
+  SetOriginalFixedImageDirectionFlat(const FlatDirectionCosinesType & arg);
 
-  virtual const FlatDirectionCosinesType & GetOriginalFixedImageDirectionFlat( void ) const;
+  virtual const FlatDirectionCosinesType &
+  GetOriginalFixedImageDirectionFlat() const;
 
   /** Get and Set the elastix level. */
-  void SetElastixLevel( unsigned int level );
+  void
+  SetElastixLevel(unsigned int level);
 
-  unsigned int GetElastixLevel( void );
+  unsigned int
+  GetElastixLevel();
 
   /** Get and Set the total number of elastix levels. */
-  void SetTotalNumberOfElastixLevels( unsigned int levels );
+  void
+  SetTotalNumberOfElastixLevels(unsigned int levels);
 
-  unsigned int GetTotalNumberOfElastixLevels( void );
+  unsigned int
+  GetTotalNumberOfElastixLevels();
 
   /** Returns the Index that is used in elx::ComponentDatabase. */
-  itkGetConstMacro( DBIndex, DBIndexType );
+  itkGetConstMacro(DBIndex, DBIndexType);
 
   /** Enter the command line parameters, which were given by the user,
    * if elastix.exe is used to do a registration.
    * The Configuration object will be initialized in this way.
    */
-  virtual void EnterCommandLineArguments( const ArgumentMapType & argmap );
+  virtual void
+  EnterCommandLineArguments(const ArgumentMapType & argmap);
 
-  virtual void EnterCommandLineArguments( const ArgumentMapType & argmap,
-    const ParameterMapType & inputMap );
+  virtual void
+  EnterCommandLineArguments(const ArgumentMapType & argmap, const ParameterMapType & inputMap);
 
   // Version used when elastix is used as a library.
-  virtual void EnterCommandLineArguments( const ArgumentMapType & argmap,
-    const std::vector< ParameterMapType > & inputMaps );
+  virtual void
+  EnterCommandLineArguments(const ArgumentMapType & argmap, const std::vector<ParameterMapType> & inputMaps);
 
   /** Start the registration
    * run() without command line parameters; it assumes that
    * EnterCommandLineParameters has been invoked already, or that
    * m_Configuration is initialized in a different way.
    */
-  virtual int Run( void );
+  virtual int
+  Run();
 
   /** Start the registration
    * this version of 'run' first calls this->EnterCommandLineParameters(argc,argv)
    * and then calls run().
    */
-  virtual int Run( const ArgumentMapType & argmap );
+  virtual int
+  Run(const ArgumentMapType & argmap);
 
-  virtual int Run( const ArgumentMapType & argmap, const ParameterMapType & inputMap );
+  virtual int
+  Run(const ArgumentMapType & argmap, const ParameterMapType & inputMap);
 
   /** Set process priority, which is read from the command line arguments.
    * Syntax:
    * -priority \<high, belownormal\>
    */
-  virtual void SetProcessPriority( void ) const;
+  virtual void
+  SetProcessPriority() const;
 
   /** Set maximum number of threads, which is read from the command line arguments.
    * Syntax:
    * -threads \<int\>
    */
-  virtual void SetMaximumNumberOfThreads( void ) const;
-
-  /** Functions to get/set the ComponentDatabase. */
-  static ComponentDatabase * GetComponentDatabase( void )
-  {
-    return s_CDB.GetPointer();
-  }
-
-
-  static void SetComponentDatabase( ComponentDatabase * arg )
-  {
-    if( s_CDB != arg )
-    {
-      s_CDB = arg;
-    }
-  }
+  virtual void
+  SetMaximumNumberOfThreads() const;
 
+  /** Function to get the ComponentDatabase. */
+  static const ComponentDatabase &
+  GetComponentDatabase();
 
   /** GetTransformParametersMap */
-  virtual ParameterMapType GetTransformParametersMap( void ) const;
-
-  static void UnloadComponents( void );
+  virtual ParameterMapType
+  GetTransformParametersMap() const;
 
 protected:
-
   ElastixMain();
   ~ElastixMain() override;
 
   /** A pointer to elastix as an itk::object. In run() this
    * pointer will be assigned to an ElastixTemplate<>.
    */
-  ObjectPointer m_Elastix;
+  ObjectPointer m_Elastix{ nullptr };
 
   /** The configuration object, containing the parameters and command-line arguments. */
-  ConfigurationPointer m_Configuration;
+  ConfigurationPointer m_Configuration{ Configuration::New() };
 
   /** A vector of configuration objects, needed when transformix is used as library. */
-  std::vector< ConfigurationPointer > m_Configurations;
+  std::vector<ConfigurationPointer> m_Configurations{};
 
   /** Description of the ImageTypes. */
-  PixelTypeDescriptionType m_FixedImagePixelType;
-  ImageDimensionType       m_FixedImageDimension;
-  PixelTypeDescriptionType m_MovingImagePixelType;
-  ImageDimensionType       m_MovingImageDimension;
+  PixelTypeDescriptionType m_FixedImagePixelType{};
+  ImageDimensionType       m_FixedImageDimension{ 0 };
+  PixelTypeDescriptionType m_MovingImagePixelType{};
+  ImageDimensionType       m_MovingImageDimension{ 0 };
 
-  DBIndexType m_DBIndex;
+  DBIndexType m_DBIndex{ 0 };
 
   /** The images and masks. */
-  DataObjectContainerPointer m_FixedImageContainer;
-  DataObjectContainerPointer m_MovingImageContainer;
-  DataObjectContainerPointer m_FixedMaskContainer;
-  DataObjectContainerPointer m_MovingMaskContainer;
-  DataObjectContainerPointer m_ResultImageContainer;
-  DataObjectContainerPointer m_ResultDeformationFieldContainer;
+  DataObjectContainerPointer m_FixedImageContainer{ nullptr };
+  DataObjectContainerPointer m_MovingImageContainer{ nullptr };
+  DataObjectContainerPointer m_FixedMaskContainer{ nullptr };
+  DataObjectContainerPointer m_MovingMaskContainer{ nullptr };
+  DataObjectContainerPointer m_ResultImageContainer{ nullptr };
+  DataObjectContainerPointer m_ResultDeformationFieldContainer{ nullptr };
 
   /** A transform that is the result of registration. */
-  ObjectPointer m_FinalTransform;
+  ObjectPointer m_FinalTransform{ nullptr };
 
   /** The initial transform. */
-  ObjectPointer m_InitialTransform;
+  ObjectPointer m_InitialTransform{ nullptr };
+
   /** Transformation parameters map containing parameters that is the
    *  result of registration.
    */
-  ParameterMapType m_TransformParametersMap;
+  ParameterMapType m_TransformParametersMap{};
 
-  FlatDirectionCosinesType m_OriginalFixedImageDirection;
-
-  static ComponentDatabasePointer s_CDB;
-  static ComponentLoaderPointer   s_ComponentLoader;
-  virtual int LoadComponents( void );
+  FlatDirectionCosinesType m_OriginalFixedImageDirection{};
 
   /** InitDBIndex sets m_DBIndex by asking the ImageTypes
    * from the Configuration object and obtaining the corresponding
    * DB index from the ComponentDatabase.
    */
-  virtual int InitDBIndex( void );
+  virtual int
+  InitDBIndex();
 
   /** Create a component. Make sure InitDBIndex has been called before.
    * The input is a string, e.g. "MattesMutualInformation".
    */
-  virtual ObjectPointer CreateComponent( const ComponentDescriptionType & name );
+  virtual ObjectPointer
+  CreateComponent(const ComponentDescriptionType & name);
 
   /** Create components. Reads from the configuration object (using the provided key)
    * the names of the components to create and store their instantiations in the
@@ -366,23 +387,17 @@ protected:
    * ( !mandatoryComponent && defaultComponentName != "" ) == true
    *
    */
-  virtual ObjectContainerPointer CreateComponents(
-    const ComponentDescriptionType & key,
-    const ComponentDescriptionType & defaultComponentName,
-    int & errorcode,
-    bool mandatoryComponent = true );
+  virtual ObjectContainerPointer
+  CreateComponents(const ComponentDescriptionType & key,
+                   const ComponentDescriptionType & defaultComponentName,
+                   int &                            errorcode,
+                   bool                             mandatoryComponent = true);
 
   /** Helper function to obtain information from images on disk. */
-  void GetImageInformationFromFile( const std::string & filename,
-    ImageDimensionType & imageDimension ) const;
-
-private:
-
-  ElastixMain( const Self & );     // purposely not implemented
-  void operator=( const Self & );  // purposely not implemented
-
+  void
+  GetImageInformationFromFile(const std::string & filename, ImageDimensionType & imageDimension) const;
 };
 
 } // end namespace elastix
 
-#endif // end #ifndef __elxElastixMain_h
+#endif // end #ifndef elxElastixMain_h
