@@ -16,13 +16,13 @@
  *
  *=========================================================================*/
 
- // Elastix header files:
+// Elastix header files:
 #include "elastixlib.h"
 #include "elxElastixMain.h"
 #include "elastix.h" // For ConvertSecondsToDHMS and GetCurrentDateAndTime.
 
 #ifdef _ELASTIX_USE_MEVISDICOMTIFF
-#include "itkUseMevisDicomTiff.h"
+#  include "itkUseMevisDicomTiff.h"
 #endif
 
 // ITK header files:
@@ -64,8 +64,15 @@ ELASTIX::~ELASTIX()
  * ******************* GetResultImage ***********************
  */
 
+ELASTIX::ConstImagePointer
+ELASTIX::GetResultImage() const
+{
+  return this->m_ResultImage;
+} // end GetResultImage()
+
+
 ELASTIX::ImagePointer
-ELASTIX::GetResultImage( void )
+ELASTIX::GetResultImage()
 {
   return this->m_ResultImage;
 } // end GetResultImage()
@@ -76,9 +83,9 @@ ELASTIX::GetResultImage( void )
  */
 
 ELASTIX::ParameterMapType
-ELASTIX::GetTransformParameterMap( void )
+ELASTIX::GetTransformParameterMap() const
 {
-  return this->m_TransformParametersList[ this->m_TransformParametersList.size() - 1 ];
+  return this->m_TransformParametersList.back();
 } // end GetTransformParameterMap()
 
 
@@ -87,7 +94,7 @@ ELASTIX::GetTransformParameterMap( void )
  */
 
 ELASTIX::ParameterMapListType
-ELASTIX::GetTransformParameterMapList( void )
+ELASTIX::GetTransformParameterMapList() const
 {
   return this->m_TransformParametersList;
 } // end GetTransformParameterMapList()
@@ -98,24 +105,19 @@ ELASTIX::GetTransformParameterMapList( void )
  */
 
 int
-ELASTIX::RegisterImages(
-  ImagePointer fixedImage,
-  ImagePointer movingImage,
-  const ParameterMapType & parameterMap,
-  const std::string & outputPath,
-  bool performLogging,
-  bool performCout,
-  ImagePointer fixedMask,
-  ImagePointer movingMask )
+ELASTIX::RegisterImages(ImagePointer             fixedImage,
+                        ImagePointer             movingImage,
+                        const ParameterMapType & parameterMap,
+                        const std::string &      outputPath,
+                        bool                     performLogging,
+                        bool                     performCout,
+                        ImagePointer             fixedMask,
+                        ImagePointer             movingMask)
 {
-  std::vector< ParameterMapType > parameterMaps( 1 );
-  parameterMaps[ 0 ] = parameterMap;
+  std::vector<ParameterMapType> parameterMaps(1);
+  parameterMaps[0] = parameterMap;
   return this->RegisterImages(
-    fixedImage, movingImage,
-    parameterMaps,
-    outputPath,
-    performLogging, performCout,
-    fixedMask, movingMask );
+    fixedImage, movingImage, parameterMaps, outputPath, performLogging, performCout, fixedMask, movingMask);
 
 } // end RegisterImages()
 
@@ -125,69 +127,63 @@ ELASTIX::RegisterImages(
  */
 
 int
-ELASTIX::RegisterImages(
-  ImagePointer fixedImage,
-  ImagePointer movingImage,
-  const std::vector< ParameterMapType > & parameterMaps,
-  const std::string & outputPath,
-  bool performLogging,
-  bool performCout,
-  ImagePointer fixedMask,
-  ImagePointer movingMask,
-  ObjectPointer transform)
+ELASTIX::RegisterImages(ImagePointer                          fixedImage,
+                        ImagePointer                          movingImage,
+                        const std::vector<ParameterMapType> & parameterMaps,
+                        const std::string &                   outputPath,
+                        bool                                  performLogging,
+                        bool                                  performCout,
+                        ImagePointer                          fixedMask,
+                        ImagePointer                          movingMask,
+                        ObjectPointer                         transform)
 {
   /** Some typedef's. */
-  typedef elx::ElastixMain                            ElastixMainType;
-  typedef ElastixMainType::ObjectPointer              ObjectPointer;
-  typedef ElastixMainType::DataObjectContainerType    DataObjectContainerType;
-  typedef ElastixMainType::DataObjectContainerPointer DataObjectContainerPointer;
-  typedef ElastixMainType::FlatDirectionCosinesType   FlatDirectionCosinesType;
+  using ElastixMainType = elx::ElastixMain;
+  using DataObjectContainerType = ElastixMainType::DataObjectContainerType;
+  using DataObjectContainerPointer = ElastixMainType::DataObjectContainerPointer;
+  using FlatDirectionCosinesType = ElastixMainType::FlatDirectionCosinesType;
 
-  typedef ElastixMainType::ArgumentMapType ArgumentMapType;
-  typedef ArgumentMapType::value_type      ArgumentMapEntryType;
-
-  typedef std::pair< std::string, std::string > ArgPairType;
+  using ArgumentMapType = ElastixMainType::ArgumentMapType;
+  using ArgumentMapEntryType = ArgumentMapType::value_type;
 
   // Clear output transform parameters
   this->m_TransformParametersList.clear();
 
   /** Some declarations and initialisations. */
 
-  std::string                value;
+  std::string value;
 
   /** Setup the argumentMap for output path. */
-  if( !outputPath.empty() )
+  if (!outputPath.empty())
   {
     /** Put command line parameters into parameterFileList. */
     value = outputPath;
 
     /** Make sure that last character of the output folder equals a '/'. */
-    if( value.find_last_of( "/" ) != value.size() - 1 )
+    if (outputPath.back() != '/')
     {
-      value.append( "/" );
+      value.append("/");
     }
   }
   else
   {
     /** Put command line parameters into parameterFileList. */
-    //there must be an "-out", this is checked later in code!!
+    // there must be an "-out", this is checked later in code!!
     value = "output_path_not_set";
   }
 
   /** Save this information. */
   const auto outFolder = value;
 
-  const ArgumentMapType argMap
-  {
-    /** The argv0 argument, required for finding the component.dll/so's. */
-    ArgumentMapEntryType("-argv0", "elastix"),
-    ArgumentMapEntryType("-out", outFolder)
+  const ArgumentMapType argMap{ /** The argv0 argument, required for finding the component.dll/so's. */
+                                ArgumentMapEntryType("-argv0", "elastix"),
+                                ArgumentMapEntryType("-out", outFolder)
   };
 
   /** Check if the output directory exists. */
-  if( performLogging && ! itksys::SystemTools::FileIsDirectory( outFolder ) )
+  if (performLogging && !itksys::SystemTools::FileIsDirectory(outFolder))
   {
-    if( performCout )
+    if (performCout)
     {
       std::cerr << "ERROR: the output directory does not exist." << std::endl;
       std::cerr << "You are responsible for creating it." << std::endl;
@@ -196,11 +192,12 @@ ELASTIX::RegisterImages(
   }
 
   /** Setup xout. */
-  const std::string logFileName = performLogging ? (outFolder + "elastix.log") : "";
-  int returndummy = elx::xoutSetup( logFileName.c_str(), performLogging, performCout );
-  if( ( returndummy != 0 ) && performCout )
+  const std::string      logFileName = performLogging ? (outFolder + "elastix.log") : "";
+  const elx::xoutManager manager{};
+  int                    returndummy = elx::xoutSetup(logFileName.c_str(), performLogging, performCout);
+  if ((returndummy != 0) && performCout)
   {
-    if( performCout )
+    if (performCout)
     {
       std::cerr << "ERROR while setting up xout." << std::endl;
     }
@@ -220,60 +217,60 @@ ELASTIX::RegisterImages(
    ************************************************************************/
 
   /* Allocate and store images in containers */
-  auto fixedImageContainer                   = DataObjectContainerType::New();
-  auto movingImageContainer                  = DataObjectContainerType::New();
-  fixedImageContainer->CreateElementAt( 0 )  = fixedImage;
-  movingImageContainer->CreateElementAt( 0 ) = movingImage;
+  auto fixedImageContainer = DataObjectContainerType::New();
+  auto movingImageContainer = DataObjectContainerType::New();
+  fixedImageContainer->CreateElementAt(0) = fixedImage;
+  movingImageContainer->CreateElementAt(0) = movingImage;
 
-  DataObjectContainerPointer fixedMaskContainer   = nullptr;
-  DataObjectContainerPointer movingMaskContainer  = nullptr;
+  DataObjectContainerPointer fixedMaskContainer = nullptr;
+  DataObjectContainerPointer movingMaskContainer = nullptr;
   DataObjectContainerPointer resultImageContainer = nullptr;
   FlatDirectionCosinesType   fixedImageOriginalDirection;
 
   /* Allocate and store masks in containers if available*/
-  if( fixedMask )
+  if (fixedMask)
   {
-    fixedMaskContainer                       = DataObjectContainerType::New();
-    fixedMaskContainer->CreateElementAt( 0 ) = fixedMask;
+    fixedMaskContainer = DataObjectContainerType::New();
+    fixedMaskContainer->CreateElementAt(0) = fixedMask;
   }
-  if( movingMask )
+  if (movingMask)
   {
-    movingMaskContainer                       = DataObjectContainerType::New();
-    movingMaskContainer->CreateElementAt( 0 ) = movingMask;
+    movingMaskContainer = DataObjectContainerType::New();
+    movingMaskContainer->CreateElementAt(0) = movingMask;
   }
 
-  //todo original direction cosin, problem is that Image type is unknown at this in elastixlib.cxx
-  //for now in elaxElastixTemplate (Run()) direction cosines are taken from fixed image
+  // todo original direction cosin, problem is that Image type is unknown at this in elastixlib.cxx
+  // for now in elaxElastixTemplate (Run()) direction cosines are taken from fixed image
 
   /**
    * ********************* START REGISTRATION *********************
    *
    * Do the (possibly multiple) registration(s).
    */
-  
+
   const auto nrOfParameterFiles = parameterMaps.size();
   assert(nrOfParameterFiles <= UINT_MAX);
 
-  for( unsigned i{}; i < static_cast<unsigned>(nrOfParameterFiles); ++i )
+  for (unsigned i{}; i < static_cast<unsigned>(nrOfParameterFiles); ++i)
   {
     /** Create another instance of ElastixMain. */
     const auto elastixMain = ElastixMainType::New();
 
     /** Set stuff we get from a former registration. */
-    elastixMain->SetInitialTransform( transform );
-    elastixMain->SetFixedImageContainer( fixedImageContainer );
-    elastixMain->SetMovingImageContainer( movingImageContainer );
-    elastixMain->SetFixedMaskContainer( fixedMaskContainer );
-    elastixMain->SetMovingMaskContainer( movingMaskContainer );
-    elastixMain->SetResultImageContainer( resultImageContainer );
-    elastixMain->SetOriginalFixedImageDirectionFlat( fixedImageOriginalDirection );
+    elastixMain->SetInitialTransform(transform);
+    elastixMain->SetFixedImageContainer(fixedImageContainer);
+    elastixMain->SetMovingImageContainer(movingImageContainer);
+    elastixMain->SetFixedMaskContainer(fixedMaskContainer);
+    elastixMain->SetMovingMaskContainer(movingMaskContainer);
+    elastixMain->SetResultImageContainer(resultImageContainer);
+    elastixMain->SetOriginalFixedImageDirectionFlat(fixedImageOriginalDirection);
 
     /** Set the current elastix-level. */
-    elastixMain->SetElastixLevel( i );
-    elastixMain->SetTotalNumberOfElastixLevels( nrOfParameterFiles );
+    elastixMain->SetElastixLevel(i);
+    elastixMain->SetTotalNumberOfElastixLevels(nrOfParameterFiles);
 
     /** Print a start message. */
-    elxout << "-------------------------------------------------------------------------" << "\n" << std::endl;
+    elxout << "-------------------------------------------------------------------------\n" << std::endl;
     elxout << "Running elastix with parameter map " << i << std::endl;
 
     /** Declare a timer, start it and print the start time. */
@@ -282,52 +279,50 @@ ELASTIX::RegisterImages(
     elxout << "Current time: " << GetCurrentDateAndTime() << "." << std::endl;
 
     /** Start registration. */
-    returndummy = elastixMain->Run( argMap, parameterMaps[ i ] );
+    returndummy = elastixMain->Run(argMap, parameterMaps[i]);
 
     /** Check for errors. */
-    if( returndummy != 0 )
+    if (returndummy != 0)
     {
-      xl::xout[ "error" ] << "Errors occurred!" << std::endl;
+      xl::xout["error"] << "Errors occurred!" << std::endl;
       return returndummy;
     }
 
     /** Get the transform, the fixedImage and the movingImage
      * in order to put it in the (possibly) next registration.
      */
-    transform                   = elastixMain->GetModifiableFinalTransform();
-    fixedImageContainer         = elastixMain->GetModifiableFixedImageContainer();
-    movingImageContainer        = elastixMain->GetModifiableMovingImageContainer();
-    fixedMaskContainer          = elastixMain->GetModifiableFixedMaskContainer();
-    movingMaskContainer         = elastixMain->GetModifiableMovingMaskContainer();
-    resultImageContainer        = elastixMain->GetModifiableResultImageContainer();
+    transform = elastixMain->GetModifiableFinalTransform();
+    fixedImageContainer = elastixMain->GetModifiableFixedImageContainer();
+    movingImageContainer = elastixMain->GetModifiableMovingImageContainer();
+    fixedMaskContainer = elastixMain->GetModifiableFixedMaskContainer();
+    movingMaskContainer = elastixMain->GetModifiableMovingMaskContainer();
+    resultImageContainer = elastixMain->GetModifiableResultImageContainer();
     fixedImageOriginalDirection = elastixMain->GetOriginalFixedImageDirectionFlat();
 
     /** Stop timer and print it. */
     timer.Stop();
     elxout << "\nCurrent time: " << GetCurrentDateAndTime() << "." << std::endl;
-    elxout << "Time used for running elastix with this parameter file: "
-           << ConvertSecondsToDHMS( timer.GetMean(), 1 ) << ".\n" << std::endl;
+    elxout << "Time used for running elastix with this parameter file: " << ConvertSecondsToDHMS(timer.GetMean(), 1)
+           << ".\n"
+           << std::endl;
 
     /** Get the transformation parameter map. */
-    this->m_TransformParametersList.push_back( elastixMain->GetTransformParametersMap() );
+    this->m_TransformParametersList.push_back(elastixMain->GetTransformParametersMap());
 
     /** Set initial transform to an index number instead of a parameter filename. */
-    if( i > 0 )
+    if (i > 0)
     {
-      std::stringstream toString;
-      toString << ( i - 1 );
-      this->m_TransformParametersList[ i ][ "InitialTransformParametersFileName" ][ 0 ]
-        = toString.str();
+      std::ostringstream toString;
+      toString << (i - 1);
+      this->m_TransformParametersList[i]["InitialTransformParametersFileName"][0] = toString.str();
     }
   } // end loop over registrations
 
-  elxout << "-------------------------------------------------------------------------"
-         << "\n" << std::endl;
+  elxout << "-------------------------------------------------------------------------\n" << std::endl;
 
   /** Stop totaltimer and print it. */
   totaltimer.Stop();
-  elxout << "Total time elapsed: "
-         << ConvertSecondsToDHMS( totaltimer.GetMean(), 1 ) << ".\n" << std::endl;
+  elxout << "Total time elapsed: " << ConvertSecondsToDHMS(totaltimer.GetMean(), 1) << ".\n" << std::endl;
 
   /************************************************************************
    *                                *
@@ -341,21 +336,19 @@ ELASTIX::RegisterImages(
    */
 
   /* Set result image for output */
-  if( resultImageContainer.IsNotNull() && resultImageContainer->Size() > 0 && resultImageContainer->ElementAt( 0 ).IsNotNull() )
+  if (resultImageContainer.IsNotNull() && resultImageContainer->Size() > 0 &&
+      resultImageContainer->ElementAt(0).IsNotNull())
   {
-    this->m_ResultImage = resultImageContainer->ElementAt( 0 );
+    this->m_ResultImage = resultImageContainer->ElementAt(0);
   }
 
-  transform            = nullptr;
-  fixedImageContainer  = nullptr;
+  transform = nullptr;
+  fixedImageContainer = nullptr;
   movingImageContainer = nullptr;
-  fixedMaskContainer   = nullptr;
-  movingMaskContainer  = nullptr;
+  fixedMaskContainer = nullptr;
+  movingMaskContainer = nullptr;
   resultImageContainer = nullptr;
 
-  /** Close the modules. */
-  ElastixMainType::UnloadComponents();
-
   /** Exit and return the error code. */
   return 0;
 
