@@ -28,19 +28,19 @@ namespace elastix
 
 ProgressCommand::ProgressCommand()
 {
-  this->m_StartString           = "Progress: ";
-  this->m_EndString             = "%";
-  this->m_Tag                   = 0;
-  this->m_TagIsSet              = false;
-  this->m_ObservedProcessObject = 0;
-  this->m_NumberOfVoxels        = 0;
-  this->m_NumberOfUpdates       = 0;
+  this->m_StartString = "Progress: ";
+  this->m_EndString = "%";
+  this->m_Tag = 0;
+  this->m_TagIsSet = false;
+  this->m_ObservedProcessObject = nullptr;
+  this->m_NumberOfVoxels = 0;
+  this->m_NumberOfUpdates = 0;
 
   /** Check if the output of the stream is a console. */
   this->m_StreamOutputIsConsole = false;
   std::string streamOutput = "cout";
-  int         currentPos   = xl::xout[ "coutonly" ].GetCOutputs().find( streamOutput )->second->tellp();
-  if( currentPos == -1 )
+  int         currentPos = xl::xout["coutonly"].GetCOutputs().find(streamOutput)->second->tellp();
+  if (currentPos == -1)
   {
     this->m_StreamOutputIsConsole = true;
   }
@@ -54,7 +54,7 @@ ProgressCommand::ProgressCommand()
 
 ProgressCommand::~ProgressCommand()
 {
-  this->DisconnectObserver( this->m_ObservedProcessObject );
+  this->DisconnectObserver(this->m_ObservedProcessObject);
 
 } // end Destructor()
 
@@ -64,29 +64,26 @@ ProgressCommand::~ProgressCommand()
  */
 
 void
-ProgressCommand
-::SetUpdateFrequency(
-  const unsigned long numberOfVoxels,
-  const unsigned long numberOfUpdates )
+ProgressCommand::SetUpdateFrequency(const unsigned long numberOfVoxels, const unsigned long numberOfUpdates)
 {
   /** Set the member variables. */
-  this->m_NumberOfVoxels  = numberOfVoxels;
+  this->m_NumberOfVoxels = numberOfVoxels;
   this->m_NumberOfUpdates = numberOfUpdates;
 
   /** Make sure we have at least one pixel. */
-  if( this->m_NumberOfVoxels < 1 )
+  if (this->m_NumberOfVoxels < 1)
   {
     this->m_NumberOfVoxels = 1;
   }
 
   /** We cannot update more times than there are pixels. */
-  if( this->m_NumberOfUpdates > this->m_NumberOfVoxels )
+  if (this->m_NumberOfUpdates > this->m_NumberOfVoxels)
   {
     this->m_NumberOfUpdates = this->m_NumberOfVoxels;
   }
 
   /** Make sure we update at least once. */
-  if( this->m_NumberOfUpdates < 1 )
+  if (this->m_NumberOfUpdates < 1)
   {
     this->m_NumberOfUpdates = 1;
   }
@@ -99,17 +96,16 @@ ProgressCommand
  */
 
 void
-ProgressCommand
-::ConnectObserver( itk::ProcessObject * filter )
+ProgressCommand::ConnectObserver(itk::ProcessObject * filter)
 {
   /** Disconnect from old observed filters. */
-  this->DisconnectObserver( this->m_ObservedProcessObject );
+  this->DisconnectObserver(this->m_ObservedProcessObject);
 
   /** Connect to the new filter. */
-  if( this->m_StreamOutputIsConsole )
+  if (this->m_StreamOutputIsConsole)
   {
-    this->m_Tag                   = filter->AddObserver( itk::ProgressEvent(), this );
-    this->m_TagIsSet              = true;
+    this->m_Tag = filter->AddObserver(itk::ProgressEvent(), this);
+    this->m_TagIsSet = true;
     this->m_ObservedProcessObject = filter;
   }
 
@@ -121,16 +117,15 @@ ProgressCommand
  */
 
 void
-ProgressCommand
-::DisconnectObserver( itk::ProcessObject * filter )
+ProgressCommand::DisconnectObserver(itk::ProcessObject * filter)
 {
-  if( this->m_StreamOutputIsConsole )
+  if (this->m_StreamOutputIsConsole)
   {
-    if( this->m_TagIsSet )
+    if (this->m_TagIsSet)
     {
-      filter->RemoveObserver( this->m_Tag );
-      this->m_TagIsSet              = false;
-      this->m_ObservedProcessObject = 0;
+      filter->RemoveObserver(this->m_Tag);
+      this->m_TagIsSet = false;
+      this->m_ObservedProcessObject = nullptr;
     }
   }
 
@@ -142,15 +137,17 @@ ProgressCommand
  */
 
 void
-ProgressCommand
-::Execute( itk::Object * caller, const itk::EventObject & event )
+ProgressCommand::Execute(itk::Object * caller, const itk::EventObject & event)
 {
-  itk::ProcessObject * po = dynamic_cast< itk::ProcessObject * >( caller );
-  if( !po ) { return; }
-
-  if( typeid( event ) == typeid( itk::ProgressEvent ) )
+  itk::ProcessObject * po = dynamic_cast<itk::ProcessObject *>(caller);
+  if (!po)
   {
-    this->PrintProgress( po->GetProgress() );
+    return;
+  }
+
+  if (typeid(event) == typeid(itk::ProgressEvent))
+  {
+    this->PrintProgress(po->GetProgress());
   }
 
 } // end Execute()
@@ -161,15 +158,17 @@ ProgressCommand
  */
 
 void
-ProgressCommand
-::Execute( const itk::Object * caller, const itk::EventObject & event )
+ProgressCommand::Execute(const itk::Object * caller, const itk::EventObject & event)
 {
-  const itk::ProcessObject * po = dynamic_cast< const itk::ProcessObject * >( caller );
-  if( !po ) { return; }
-
-  if( typeid( event ) == typeid( itk::ProgressEvent ) )
+  const itk::ProcessObject * po = dynamic_cast<const itk::ProcessObject *>(caller);
+  if (!po)
   {
-    this->PrintProgress( po->GetProgress() );
+    return;
+  }
+
+  if (typeid(event) == typeid(itk::ProgressEvent))
+  {
+    this->PrintProgress(po->GetProgress());
   }
 
 } // end Execute()
@@ -180,17 +179,12 @@ ProgressCommand
  */
 
 void
-ProgressCommand
-::PrintProgress( const float & progress ) const
+ProgressCommand::PrintProgress(const float progress) const
 {
   /** Print the progress to the screen. */
-  const int progressInt = itk::Math::Round< float >( 100 * progress );
-  xl::xout[ "coutonly" ]
-    << "\r"
-    << this->m_StartString
-    << progressInt
-    << this->m_EndString;
-  xl::xout[ "coutonly" ] << std::flush;
+  const int progressInt = itk::Math::Round<float>(100 * progress);
+  xl::xout["coutonly"] << "\r" << this->m_StartString << progressInt << this->m_EndString;
+  xl::xout["coutonly"] << std::flush;
 
   /** If the process is completed, print an end-of-line. *
   if ( progress > 0.99999 )
@@ -206,18 +200,14 @@ ProgressCommand
  */
 
 void
-ProgressCommand
-::UpdateAndPrintProgress( const unsigned long & currentVoxelNumber ) const
+ProgressCommand::UpdateAndPrintProgress(const unsigned long currentVoxelNumber) const
 {
-  if( this->m_StreamOutputIsConsole )
+  if (this->m_StreamOutputIsConsole)
   {
-    const unsigned long frac
-      = static_cast< unsigned long >( this->m_NumberOfVoxels / this->m_NumberOfUpdates );
-    if( currentVoxelNumber % frac == 0 )
+    const unsigned long frac = static_cast<unsigned long>(this->m_NumberOfVoxels / this->m_NumberOfUpdates);
+    if (currentVoxelNumber % frac == 0)
     {
-      this->PrintProgress(
-        static_cast< float >( currentVoxelNumber )
-        / static_cast< float >( this->m_NumberOfVoxels ) );
+      this->PrintProgress(static_cast<float>(currentVoxelNumber) / static_cast<float>(this->m_NumberOfVoxels));
     }
   }
 
@@ -225,8 +215,7 @@ ProgressCommand
 
 
 ProgressCommand::Pointer
-ProgressCommand
-::CreateAndSetUpdateFrequency( const unsigned long numberOfVoxels )
+ProgressCommand::CreateAndSetUpdateFrequency(const unsigned long numberOfVoxels)
 {
   const auto result = Self::New();
   result->Self::SetUpdateFrequency(numberOfVoxels, numberOfVoxels);
@@ -235,8 +224,7 @@ ProgressCommand
 }
 
 ProgressCommand::Pointer
-ProgressCommand
-::CreateAndConnect(itk::ProcessObject& processObject)
+ProgressCommand::CreateAndConnect(itk::ProcessObject & processObject)
 {
   const auto result = Self::New();
   result->Self::ConnectObserver(&processObject);
@@ -246,4 +234,4 @@ ProgressCommand
 }
 
 
-} // end namespace itk
+} // namespace elastix
