@@ -22,8 +22,8 @@
 // \note This work was funded by the Netherlands Organisation for
 // Scientific Research (NWO NRG-2010.02 and NWO 639.021.124).
 //
-#ifndef __itkTestOutputWindow_h
-#define __itkTestOutputWindow_h
+#ifndef itkTestOutputWindow_h
+#define itkTestOutputWindow_h
 
 // ITK include files
 #include "itkOutputWindow.h"
@@ -47,35 +47,31 @@ DisplayDebugText - <Debug>
 class TestOutputWindow : public OutputWindow
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(TestOutputWindow);
 
   /** Standard class typedefs. */
-  typedef TestOutputWindow           Self;
-  typedef OutputWindow               Superclass;
-  typedef SmartPointer< Self >       Pointer;
-  typedef SmartPointer< const Self > ConstPointer;
+  using Self = TestOutputWindow;
+  using Superclass = OutputWindow;
+  using Pointer = SmartPointer<Self>;
+  using ConstPointer = SmartPointer<const Self>;
 
   /** Method for creation through the object factory. */
-  itkNewMacro( Self );
+  itkNewMacro(Self);
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( TestOutputWindow, OutputWindow );
+  itkTypeMacro(TestOutputWindow, OutputWindow);
 
   /** Overloaded */
-  void DisplayText( const char * ) override;
+  void
+  DisplayText(const char *) override;
 
 protected:
-
   TestOutputWindow() {}
   ~TestOutputWindow() override {}
-  void PrintSelf( std::ostream & os, Indent indent ) const override;
-
-private:
-
-  TestOutputWindow( const Self & ); //purposely not implemented
-  void operator=( const Self & );   //purposely not implemented
-
+  void
+  PrintSelf(std::ostream & os, Indent indent) const override;
 };
 
 } // end namespace itk
 
-#endif // __itkTestOutputWindow_h
+#endif // itkTestOutputWindow_h
